/* ISessionStatus.c generated by valac 0.56.19, the Vala compiler
 * generated from ISessionStatus.vala, do not modify */

/* ISessionStatus.vala
 *
 * Copyright 2020 Dylan McCall <dylan@dylanmccall.ca>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "common.h"
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	BREAK_TIMER_COMMON_ISESSION_STATUS_LOCKED_SIGNAL,
	BREAK_TIMER_COMMON_ISESSION_STATUS_UNLOCKED_SIGNAL,
	BREAK_TIMER_COMMON_ISESSION_STATUS_NUM_SIGNALS
};
static guint break_timer_common_isession_status_signals[BREAK_TIMER_COMMON_ISESSION_STATUS_NUM_SIGNALS] = {0};

static GType break_timer_common_isession_status_get_type_once (void);

gboolean
break_timer_common_isession_status_is_locked (BreakTimerCommonISessionStatus* self)
{
	BreakTimerCommonISessionStatusIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = BREAK_TIMER_COMMON_ISESSION_STATUS_GET_INTERFACE (self);
	if (_iface_->is_locked) {
		return _iface_->is_locked (self);
	}
	return FALSE;
}

void
break_timer_common_isession_status_lock_screen (BreakTimerCommonISessionStatus* self)
{
	BreakTimerCommonISessionStatusIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BREAK_TIMER_COMMON_ISESSION_STATUS_GET_INTERFACE (self);
	if (_iface_->lock_screen) {
		_iface_->lock_screen (self);
	}
}

void
break_timer_common_isession_status_blank_screen (BreakTimerCommonISessionStatus* self)
{
	BreakTimerCommonISessionStatusIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BREAK_TIMER_COMMON_ISESSION_STATUS_GET_INTERFACE (self);
	if (_iface_->blank_screen) {
		_iface_->blank_screen (self);
	}
}

void
break_timer_common_isession_status_unblank_screen (BreakTimerCommonISessionStatus* self)
{
	BreakTimerCommonISessionStatusIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BREAK_TIMER_COMMON_ISESSION_STATUS_GET_INTERFACE (self);
	if (_iface_->unblank_screen) {
		_iface_->unblank_screen (self);
	}
}

static void
break_timer_common_isession_status_default_init (BreakTimerCommonISessionStatusIface * iface,
                                                 gpointer iface_data)
{
	break_timer_common_isession_status_signals[BREAK_TIMER_COMMON_ISESSION_STATUS_LOCKED_SIGNAL] = g_signal_new ("locked", BREAK_TIMER_COMMON_TYPE_ISESSION_STATUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
	break_timer_common_isession_status_signals[BREAK_TIMER_COMMON_ISESSION_STATUS_UNLOCKED_SIGNAL] = g_signal_new ("unlocked", BREAK_TIMER_COMMON_TYPE_ISESSION_STATUS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

static GType
break_timer_common_isession_status_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BreakTimerCommonISessionStatusIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) break_timer_common_isession_status_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType break_timer_common_isession_status_type_id;
	break_timer_common_isession_status_type_id = g_type_register_static (G_TYPE_INTERFACE, "BreakTimerCommonISessionStatus", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (break_timer_common_isession_status_type_id, G_TYPE_OBJECT);
	return break_timer_common_isession_status_type_id;
}

GType
break_timer_common_isession_status_get_type (void)
{
	static volatile gsize break_timer_common_isession_status_type_id__once = 0;
	if (g_once_init_enter (&break_timer_common_isession_status_type_id__once)) {
		GType break_timer_common_isession_status_type_id;
		break_timer_common_isession_status_type_id = break_timer_common_isession_status_get_type_once ();
		g_once_init_leave (&break_timer_common_isession_status_type_id__once, break_timer_common_isession_status_type_id);
	}
	return break_timer_common_isession_status_type_id__once;
}

