/* IBreakTimer_TimerBreak.c generated by valac 0.56.19, the Vala compiler
 * generated from IBreakTimer_TimerBreak.vala, do not modify */

/* IBreakTimer_TimerBreak.vala
 *
 * Copyright 2020 Dylan McCall <dylan@dylanmccall.ca>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "common.h"
#include <gio/gio.h>
#include <glib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

typedef GDBusProxy BreakTimerCommonIBreakTimer_TimerBreakProxy;
typedef GDBusProxyClass BreakTimerCommonIBreakTimer_TimerBreakProxyClass;

static GType break_timer_common_ibreaktimer_timerbreak_get_type_once (void);
static void break_timer_common_ibreaktimer_timerbreak_proxy_g_signal (GDBusProxy* proxy,
                                                               const gchar* sender_name,
                                                               const gchar* signal_name,
                                                               GVariant* parameters);
static void break_timer_common_ibreaktimer_timerbreak_proxy_get_status (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                                 BreakTimerCommonTimerBreakStatus* result,
                                                                 GError** error);
static void break_timer_common_ibreaktimer_timerbreak_proxy_activate (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                               GError** error);
static void break_timer_common_ibreaktimer_timerbreak_proxy_break_timer_common_ibreaktimer_timerbreak_interface_init (BreakTimerCommonIBreakTimer_TimerBreakIface* iface);
static void _dbus_break_timer_common_ibreaktimer_timerbreak_get_status (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                                 GVariant* _parameters_,
                                                                 GDBusMethodInvocation* invocation);
static void _dbus_break_timer_common_ibreaktimer_timerbreak_activate (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                               GVariant* _parameters_,
                                                               GDBusMethodInvocation* invocation);
static void break_timer_common_ibreaktimer_timerbreak_dbus_interface_method_call (GDBusConnection* connection,
                                                                           const gchar* sender,
                                                                           const gchar* object_path,
                                                                           const gchar* interface_name,
                                                                           const gchar* method_name,
                                                                           GVariant* parameters,
                                                                           GDBusMethodInvocation* invocation,
                                                                           gpointer user_data);
static GVariant* break_timer_common_ibreaktimer_timerbreak_dbus_interface_get_property (GDBusConnection* connection,
                                                                                 const gchar* sender,
                                                                                 const gchar* object_path,
                                                                                 const gchar* interface_name,
                                                                                 const gchar* property_name,
                                                                                 GError** error,
                                                                                 gpointer user_data);
static gboolean break_timer_common_ibreaktimer_timerbreak_dbus_interface_set_property (GDBusConnection* connection,
                                                                                const gchar* sender,
                                                                                const gchar* object_path,
                                                                                const gchar* interface_name,
                                                                                const gchar* property_name,
                                                                                GVariant* value,
                                                                                GError** error,
                                                                                gpointer user_data);
static void _break_timer_common_ibreaktimer_timerbreak_unregister_object (gpointer user_data);

static const GDBusArgInfo _break_timer_common_ibreaktimer_timerbreak_dbus_arg_info_get_status_result = {-1, "result", "(bbbiii)", NULL};
static const GDBusArgInfo * const _break_timer_common_ibreaktimer_timerbreak_dbus_arg_info_get_status_in[] = {NULL};
static const GDBusArgInfo * const _break_timer_common_ibreaktimer_timerbreak_dbus_arg_info_get_status_out[] = {&_break_timer_common_ibreaktimer_timerbreak_dbus_arg_info_get_status_result, NULL};
static const GDBusMethodInfo _break_timer_common_ibreaktimer_timerbreak_dbus_method_info_get_status = {-1, "GetStatus", (GDBusArgInfo **) (&_break_timer_common_ibreaktimer_timerbreak_dbus_arg_info_get_status_in), (GDBusArgInfo **) (&_break_timer_common_ibreaktimer_timerbreak_dbus_arg_info_get_status_out), NULL};
static const GDBusArgInfo * const _break_timer_common_ibreaktimer_timerbreak_dbus_arg_info_activate_in[] = {NULL};
static const GDBusArgInfo * const _break_timer_common_ibreaktimer_timerbreak_dbus_arg_info_activate_out[] = {NULL};
static const GDBusMethodInfo _break_timer_common_ibreaktimer_timerbreak_dbus_method_info_activate = {-1, "Activate", (GDBusArgInfo **) (&_break_timer_common_ibreaktimer_timerbreak_dbus_arg_info_activate_in), (GDBusArgInfo **) (&_break_timer_common_ibreaktimer_timerbreak_dbus_arg_info_activate_out), NULL};
static const GDBusMethodInfo * const _break_timer_common_ibreaktimer_timerbreak_dbus_method_info[] = {&_break_timer_common_ibreaktimer_timerbreak_dbus_method_info_get_status, &_break_timer_common_ibreaktimer_timerbreak_dbus_method_info_activate, NULL};
static const GDBusSignalInfo * const _break_timer_common_ibreaktimer_timerbreak_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo * const _break_timer_common_ibreaktimer_timerbreak_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _break_timer_common_ibreaktimer_timerbreak_dbus_interface_info = {-1, "org.gnome.BreakTimer.TimerBreak", (GDBusMethodInfo **) (&_break_timer_common_ibreaktimer_timerbreak_dbus_method_info), (GDBusSignalInfo **) (&_break_timer_common_ibreaktimer_timerbreak_dbus_signal_info), (GDBusPropertyInfo **) (&_break_timer_common_ibreaktimer_timerbreak_dbus_property_info), NULL};
static const GDBusInterfaceVTable _break_timer_common_ibreaktimer_timerbreak_dbus_interface_vtable = {break_timer_common_ibreaktimer_timerbreak_dbus_interface_method_call, break_timer_common_ibreaktimer_timerbreak_dbus_interface_get_property, break_timer_common_ibreaktimer_timerbreak_dbus_interface_set_property};

/** Get the break's current status, such as time remaining, or time until the break starts */
void
break_timer_common_ibreaktimer_timerbreak_get_status (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                      BreakTimerCommonTimerBreakStatus* result,
                                                      GError** error)
{
	BreakTimerCommonIBreakTimer_TimerBreakIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BREAK_TIMER_COMMON_IBREAKTIMER_TIMERBREAK_GET_INTERFACE (self);
	if (_iface_->get_status) {
		_iface_->get_status (self, result, error);
	}
}

/** Activate the break */
void
break_timer_common_ibreaktimer_timerbreak_activate (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                    GError** error)
{
	BreakTimerCommonIBreakTimer_TimerBreakIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BREAK_TIMER_COMMON_IBREAKTIMER_TIMERBREAK_GET_INTERFACE (self);
	if (_iface_->activate) {
		_iface_->activate (self, error);
	}
}

static void
break_timer_common_ibreaktimer_timerbreak_default_init (BreakTimerCommonIBreakTimer_TimerBreakIface * iface,
                                                        gpointer iface_data)
{
}

static GType
break_timer_common_ibreaktimer_timerbreak_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BreakTimerCommonIBreakTimer_TimerBreakIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) break_timer_common_ibreaktimer_timerbreak_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType break_timer_common_ibreaktimer_timerbreak_type_id;
	break_timer_common_ibreaktimer_timerbreak_type_id = g_type_register_static (G_TYPE_INTERFACE, "BreakTimerCommonIBreakTimer_TimerBreak", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (break_timer_common_ibreaktimer_timerbreak_type_id, G_TYPE_OBJECT);
	g_type_set_qdata (break_timer_common_ibreaktimer_timerbreak_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) break_timer_common_ibreaktimer_timerbreak_proxy_get_type);
	g_type_set_qdata (break_timer_common_ibreaktimer_timerbreak_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.gnome.BreakTimer.TimerBreak");
	g_type_set_qdata (break_timer_common_ibreaktimer_timerbreak_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_break_timer_common_ibreaktimer_timerbreak_dbus_interface_info));
	g_type_set_qdata (break_timer_common_ibreaktimer_timerbreak_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) break_timer_common_ibreaktimer_timerbreak_register_object);
	return break_timer_common_ibreaktimer_timerbreak_type_id;
}

GType
break_timer_common_ibreaktimer_timerbreak_get_type (void)
{
	static volatile gsize break_timer_common_ibreaktimer_timerbreak_type_id__once = 0;
	if (g_once_init_enter (&break_timer_common_ibreaktimer_timerbreak_type_id__once)) {
		GType break_timer_common_ibreaktimer_timerbreak_type_id;
		break_timer_common_ibreaktimer_timerbreak_type_id = break_timer_common_ibreaktimer_timerbreak_get_type_once ();
		g_once_init_leave (&break_timer_common_ibreaktimer_timerbreak_type_id__once, break_timer_common_ibreaktimer_timerbreak_type_id);
	}
	return break_timer_common_ibreaktimer_timerbreak_type_id__once;
}

G_DEFINE_TYPE_EXTENDED (BreakTimerCommonIBreakTimer_TimerBreakProxy, break_timer_common_ibreaktimer_timerbreak_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (BREAK_TIMER_COMMON_TYPE_IBREAKTIMER_TIMERBREAK, break_timer_common_ibreaktimer_timerbreak_proxy_break_timer_common_ibreaktimer_timerbreak_interface_init) )
static void
break_timer_common_ibreaktimer_timerbreak_proxy_class_init (BreakTimerCommonIBreakTimer_TimerBreakProxyClass* klass)
{
	G_DBUS_PROXY_CLASS (klass)->g_signal = break_timer_common_ibreaktimer_timerbreak_proxy_g_signal;
}

static void
break_timer_common_ibreaktimer_timerbreak_proxy_g_signal (GDBusProxy* proxy,
                                                          const gchar* sender_name,
                                                          const gchar* signal_name,
                                                          GVariant* parameters)
{
}

static void
break_timer_common_ibreaktimer_timerbreak_proxy_init (BreakTimerCommonIBreakTimer_TimerBreakProxy* self)
{
	g_dbus_proxy_set_interface_info (G_DBUS_PROXY (self), (GDBusInterfaceInfo *) (&_break_timer_common_ibreaktimer_timerbreak_dbus_interface_info));
}

static void
break_timer_common_ibreaktimer_timerbreak_proxy_get_status (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                            BreakTimerCommonTimerBreakStatus* result,
                                                            GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	GVariant *_reply;
	GVariantIter _reply_iter;
	GVariant* _tmp0_;
	BreakTimerCommonTimerBreakStatus _tmp1_;
	GVariantIter _tmp2_;
	GVariant* _tmp3_;
	GVariant* _tmp4_;
	GVariant* _tmp5_;
	GVariant* _tmp6_;
	GVariant* _tmp7_;
	GVariant* _tmp8_;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.BreakTimer.TimerBreak", "GetStatus");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	_reply = g_dbus_message_get_body (_reply_message);
	g_variant_iter_init (&_reply_iter, _reply);
	_tmp0_ = g_variant_iter_next_value (&_reply_iter);
	g_variant_iter_init (&_tmp2_, _tmp0_);
	_tmp3_ = g_variant_iter_next_value (&_tmp2_);
	_tmp1_.is_enabled = g_variant_get_boolean (_tmp3_);
	g_variant_unref (_tmp3_);
	_tmp4_ = g_variant_iter_next_value (&_tmp2_);
	_tmp1_.is_focused = g_variant_get_boolean (_tmp4_);
	g_variant_unref (_tmp4_);
	_tmp5_ = g_variant_iter_next_value (&_tmp2_);
	_tmp1_.is_active = g_variant_get_boolean (_tmp5_);
	g_variant_unref (_tmp5_);
	_tmp6_ = g_variant_iter_next_value (&_tmp2_);
	_tmp1_.starts_in = g_variant_get_int32 (_tmp6_);
	g_variant_unref (_tmp6_);
	_tmp7_ = g_variant_iter_next_value (&_tmp2_);
	_tmp1_.time_remaining = g_variant_get_int32 (_tmp7_);
	g_variant_unref (_tmp7_);
	_tmp8_ = g_variant_iter_next_value (&_tmp2_);
	_tmp1_.current_duration = g_variant_get_int32 (_tmp8_);
	g_variant_unref (_tmp8_);
	*result = _tmp1_;
	g_variant_unref (_tmp0_);
	g_object_unref (_reply_message);
}

static void
break_timer_common_ibreaktimer_timerbreak_proxy_activate (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                          GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.BreakTimer.TimerBreak", "Activate");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
break_timer_common_ibreaktimer_timerbreak_proxy_break_timer_common_ibreaktimer_timerbreak_interface_init (BreakTimerCommonIBreakTimer_TimerBreakIface* iface)
{
	iface->get_status = break_timer_common_ibreaktimer_timerbreak_proxy_get_status;
	iface->activate = break_timer_common_ibreaktimer_timerbreak_proxy_activate;
}

static void
_dbus_break_timer_common_ibreaktimer_timerbreak_get_status (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                            GVariant* _parameters_,
                                                            GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	BreakTimerCommonTimerBreakStatus result = {0};
	GVariantBuilder _tmp9_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	break_timer_common_ibreaktimer_timerbreak_get_status (self, &result, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_init (&_tmp9_, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_tmp9_, g_variant_new_boolean (result.is_enabled));
	g_variant_builder_add_value (&_tmp9_, g_variant_new_boolean (result.is_focused));
	g_variant_builder_add_value (&_tmp9_, g_variant_new_boolean (result.is_active));
	g_variant_builder_add_value (&_tmp9_, g_variant_new_int32 (result.starts_in));
	g_variant_builder_add_value (&_tmp9_, g_variant_new_int32 (result.time_remaining));
	g_variant_builder_add_value (&_tmp9_, g_variant_new_int32 (result.current_duration));
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp9_));
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_break_timer_common_ibreaktimer_timerbreak_activate (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                          GVariant* _parameters_,
                                                          GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	break_timer_common_ibreaktimer_timerbreak_activate (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
break_timer_common_ibreaktimer_timerbreak_dbus_interface_method_call (GDBusConnection* connection,
                                                                      const gchar* sender,
                                                                      const gchar* object_path,
                                                                      const gchar* interface_name,
                                                                      const gchar* method_name,
                                                                      GVariant* parameters,
                                                                      GDBusMethodInvocation* invocation,
                                                                      gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "GetStatus") == 0) {
		_dbus_break_timer_common_ibreaktimer_timerbreak_get_status (object, parameters, invocation);
	} else if (strcmp (method_name, "Activate") == 0) {
		_dbus_break_timer_common_ibreaktimer_timerbreak_activate (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}

static GVariant*
break_timer_common_ibreaktimer_timerbreak_dbus_interface_get_property (GDBusConnection* connection,
                                                                       const gchar* sender,
                                                                       const gchar* object_path,
                                                                       const gchar* interface_name,
                                                                       const gchar* property_name,
                                                                       GError** error,
                                                                       gpointer user_data)
{
	return NULL;
}

static gboolean
break_timer_common_ibreaktimer_timerbreak_dbus_interface_set_property (GDBusConnection* connection,
                                                                       const gchar* sender,
                                                                       const gchar* object_path,
                                                                       const gchar* interface_name,
                                                                       const gchar* property_name,
                                                                       GVariant* value,
                                                                       GError** error,
                                                                       gpointer user_data)
{
	return FALSE;
}

guint
break_timer_common_ibreaktimer_timerbreak_register_object (gpointer object,
                                                           GDBusConnection* connection,
                                                           const gchar* path,
                                                           GError** error)
{
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_break_timer_common_ibreaktimer_timerbreak_dbus_interface_info), &_break_timer_common_ibreaktimer_timerbreak_dbus_interface_vtable, data, _break_timer_common_ibreaktimer_timerbreak_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}

static void
_break_timer_common_ibreaktimer_timerbreak_unregister_object (gpointer user_data)
{
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}

BreakTimerCommonBreakStatus*
break_timer_common_break_status_dup (const BreakTimerCommonBreakStatus* self)
{
	BreakTimerCommonBreakStatus* dup;
	dup = g_new0 (BreakTimerCommonBreakStatus, 1);
	memcpy (dup, self, sizeof (BreakTimerCommonBreakStatus));
	return dup;
}

void
break_timer_common_break_status_free (BreakTimerCommonBreakStatus* self)
{
	g_free (self);
}

static GType
break_timer_common_break_status_get_type_once (void)
{
	GType break_timer_common_break_status_type_id;
	break_timer_common_break_status_type_id = g_boxed_type_register_static ("BreakTimerCommonBreakStatus", (GBoxedCopyFunc) break_timer_common_break_status_dup, (GBoxedFreeFunc) break_timer_common_break_status_free);
	return break_timer_common_break_status_type_id;
}

GType
break_timer_common_break_status_get_type (void)
{
	static volatile gsize break_timer_common_break_status_type_id__once = 0;
	if (g_once_init_enter (&break_timer_common_break_status_type_id__once)) {
		GType break_timer_common_break_status_type_id;
		break_timer_common_break_status_type_id = break_timer_common_break_status_get_type_once ();
		g_once_init_leave (&break_timer_common_break_status_type_id__once, break_timer_common_break_status_type_id);
	}
	return break_timer_common_break_status_type_id__once;
}

BreakTimerCommonTimerBreakStatus*
break_timer_common_timer_break_status_dup (const BreakTimerCommonTimerBreakStatus* self)
{
	BreakTimerCommonTimerBreakStatus* dup;
	dup = g_new0 (BreakTimerCommonTimerBreakStatus, 1);
	memcpy (dup, self, sizeof (BreakTimerCommonTimerBreakStatus));
	return dup;
}

void
break_timer_common_timer_break_status_free (BreakTimerCommonTimerBreakStatus* self)
{
	g_free (self);
}

static GType
break_timer_common_timer_break_status_get_type_once (void)
{
	GType break_timer_common_timer_break_status_type_id;
	break_timer_common_timer_break_status_type_id = g_boxed_type_register_static ("BreakTimerCommonTimerBreakStatus", (GBoxedCopyFunc) break_timer_common_timer_break_status_dup, (GBoxedFreeFunc) break_timer_common_timer_break_status_free);
	return break_timer_common_timer_break_status_type_id;
}

GType
break_timer_common_timer_break_status_get_type (void)
{
	static volatile gsize break_timer_common_timer_break_status_type_id__once = 0;
	if (g_once_init_enter (&break_timer_common_timer_break_status_type_id__once)) {
		GType break_timer_common_timer_break_status_type_id;
		break_timer_common_timer_break_status_type_id = break_timer_common_timer_break_status_get_type_once ();
		g_once_init_leave (&break_timer_common_timer_break_status_type_id__once, break_timer_common_timer_break_status_type_id);
	}
	return break_timer_common_timer_break_status_type_id__once;
}

