/* TimeUnit.c generated by valac 0.56.19, the Vala compiler
 * generated from TimeUnit.vala, do not modify */

/* TimeUnit.vala
 *
 * Copyright 2020 Dylan McCall <dylan@dylanmccall.ca>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "common.h"
#include <glib.h>
#include <glib-object.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

typedef struct _BreakTimerCommonParamSpecTimeUnit BreakTimerCommonParamSpecTimeUnit;

struct _BreakTimerCommonParamSpecTimeUnit {
	GParamSpec parent_instance;
};

static gpointer break_timer_common_time_unit_parent_class = NULL;
gboolean break_timer_common_time_unit__do_override_time = FALSE;
gint64 break_timer_common_time_unit__override_real_time = (gint64) 0;
gint64 break_timer_common_time_unit__override_monotonic_time = (gint64) 0;

static void break_timer_common_time_unit_finalize (BreakTimerCommonTimeUnit * obj);
static GType break_timer_common_time_unit_get_type_once (void);

inline gint64
break_timer_common_time_unit_get_real_time (void)
{
	gint64 result;
	if (break_timer_common_time_unit__do_override_time) {
		result = break_timer_common_time_unit__override_real_time;
		return result;
	} else {
		result = g_get_real_time ();
		return result;
	}
}

inline gint64
break_timer_common_time_unit_get_real_time_ms (void)
{
	gint64 result;
	result = break_timer_common_time_unit_get_real_time () / BREAK_TIMER_COMMON_TIME_UNIT_MILLISECONDS_IN_SECONDS;
	return result;
}

inline gint64
break_timer_common_time_unit_get_real_time_seconds (void)
{
	gint64 result;
	result = break_timer_common_time_unit_get_real_time () / BREAK_TIMER_COMMON_TIME_UNIT_MICROSECONDS_IN_SECONDS;
	return result;
}

inline gint64
break_timer_common_time_unit_get_monotonic_time (void)
{
	gint64 result;
	if (break_timer_common_time_unit__do_override_time) {
		result = break_timer_common_time_unit__override_monotonic_time;
		return result;
	} else {
		result = g_get_monotonic_time ();
		return result;
	}
}

inline gint64
break_timer_common_time_unit_get_monotonic_time_ms (void)
{
	gint64 result;
	result = break_timer_common_time_unit_get_monotonic_time () / BREAK_TIMER_COMMON_TIME_UNIT_MILLISECONDS_IN_SECONDS;
	return result;
}

inline gint64
break_timer_common_time_unit_get_monotonic_time_seconds (void)
{
	gint64 result;
	result = break_timer_common_time_unit_get_monotonic_time () / BREAK_TIMER_COMMON_TIME_UNIT_MICROSECONDS_IN_SECONDS;
	return result;
}

BreakTimerCommonTimeUnit*
break_timer_common_time_unit_construct (GType object_type)
{
	BreakTimerCommonTimeUnit* self = NULL;
	self = (BreakTimerCommonTimeUnit*) g_type_create_instance (object_type);
	return self;
}

static void
break_timer_common_value_time_unit_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
break_timer_common_value_time_unit_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		break_timer_common_time_unit_unref (value->data[0].v_pointer);
	}
}

static void
break_timer_common_value_time_unit_copy_value (const GValue* src_value,
                                               GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = break_timer_common_time_unit_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
break_timer_common_value_time_unit_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
break_timer_common_value_time_unit_collect_value (GValue* value,
                                                  guint n_collect_values,
                                                  GTypeCValue* collect_values,
                                                  guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		BreakTimerCommonTimeUnit * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = break_timer_common_time_unit_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
break_timer_common_value_time_unit_lcopy_value (const GValue* value,
                                                guint n_collect_values,
                                                GTypeCValue* collect_values,
                                                guint collect_flags)
{
	BreakTimerCommonTimeUnit ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = break_timer_common_time_unit_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
break_timer_common_param_spec_time_unit (const gchar* name,
                                         const gchar* nick,
                                         const gchar* blurb,
                                         GType object_type,
                                         GParamFlags flags)
{
	BreakTimerCommonParamSpecTimeUnit* spec;
	g_return_val_if_fail (g_type_is_a (object_type, BREAK_TIMER_COMMON_TYPE_TIME_UNIT), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
break_timer_common_value_get_time_unit (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BREAK_TIMER_COMMON_TYPE_TIME_UNIT), NULL);
	return value->data[0].v_pointer;
}

void
break_timer_common_value_set_time_unit (GValue* value,
                                        gpointer v_object)
{
	BreakTimerCommonTimeUnit * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BREAK_TIMER_COMMON_TYPE_TIME_UNIT));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BREAK_TIMER_COMMON_TYPE_TIME_UNIT));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		break_timer_common_time_unit_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		break_timer_common_time_unit_unref (old);
	}
}

void
break_timer_common_value_take_time_unit (GValue* value,
                                         gpointer v_object)
{
	BreakTimerCommonTimeUnit * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BREAK_TIMER_COMMON_TYPE_TIME_UNIT));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BREAK_TIMER_COMMON_TYPE_TIME_UNIT));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		break_timer_common_time_unit_unref (old);
	}
}

static void
break_timer_common_time_unit_class_init (BreakTimerCommonTimeUnitClass * klass,
                                         gpointer klass_data)
{
	break_timer_common_time_unit_parent_class = g_type_class_peek_parent (klass);
	((BreakTimerCommonTimeUnitClass *) klass)->finalize = break_timer_common_time_unit_finalize;
}

static void
break_timer_common_time_unit_instance_init (BreakTimerCommonTimeUnit * self,
                                            gpointer klass)
{
	self->ref_count = 1;
}

static void
break_timer_common_time_unit_finalize (BreakTimerCommonTimeUnit * obj)
{
	BreakTimerCommonTimeUnit * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BREAK_TIMER_COMMON_TYPE_TIME_UNIT, BreakTimerCommonTimeUnit);
	g_signal_handlers_destroy (self);
}

static GType
break_timer_common_time_unit_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { break_timer_common_value_time_unit_init, break_timer_common_value_time_unit_free_value, break_timer_common_value_time_unit_copy_value, break_timer_common_value_time_unit_peek_pointer, "p", break_timer_common_value_time_unit_collect_value, "p", break_timer_common_value_time_unit_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (BreakTimerCommonTimeUnitClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) break_timer_common_time_unit_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BreakTimerCommonTimeUnit), 0, (GInstanceInitFunc) break_timer_common_time_unit_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType break_timer_common_time_unit_type_id;
	break_timer_common_time_unit_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BreakTimerCommonTimeUnit", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
	return break_timer_common_time_unit_type_id;
}

GType
break_timer_common_time_unit_get_type (void)
{
	static volatile gsize break_timer_common_time_unit_type_id__once = 0;
	if (g_once_init_enter (&break_timer_common_time_unit_type_id__once)) {
		GType break_timer_common_time_unit_type_id;
		break_timer_common_time_unit_type_id = break_timer_common_time_unit_get_type_once ();
		g_once_init_leave (&break_timer_common_time_unit_type_id__once, break_timer_common_time_unit_type_id);
	}
	return break_timer_common_time_unit_type_id__once;
}

gpointer
break_timer_common_time_unit_ref (gpointer instance)
{
	BreakTimerCommonTimeUnit * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
break_timer_common_time_unit_unref (gpointer instance)
{
	BreakTimerCommonTimeUnit * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		BREAK_TIMER_COMMON_TIME_UNIT_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

