/* common.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __SRC_COMMON_COMMON_H__
#define __SRC_COMMON_COMMON_H__

#include <glib-object.h>
#include <gio/gio.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define BREAK_TIMER_COMMON_TIME_UNIT_MILLISECONDS_IN_SECONDS 1000
#define BREAK_TIMER_COMMON_TIME_UNIT_MICROSECONDS_IN_SECONDS (1000 * 1000)
#define BREAK_TIMER_COMMON_TIME_UNIT_MICROSECONDS_IN_MILLISECONDS 1000

#define BREAK_TIMER_COMMON_TYPE_IBREAKTIMER_TIMERBREAK (break_timer_common_ibreaktimer_timerbreak_get_type ())
#define BREAK_TIMER_COMMON_IBREAKTIMER_TIMERBREAK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_COMMON_TYPE_IBREAKTIMER_TIMERBREAK, BreakTimerCommonIBreakTimer_TimerBreak))
#define BREAK_TIMER_COMMON_IS_IBREAKTIMER_TIMERBREAK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_COMMON_TYPE_IBREAKTIMER_TIMERBREAK))
#define BREAK_TIMER_COMMON_IBREAKTIMER_TIMERBREAK_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BREAK_TIMER_COMMON_TYPE_IBREAKTIMER_TIMERBREAK, BreakTimerCommonIBreakTimer_TimerBreakIface))

typedef struct _BreakTimerCommonIBreakTimer_TimerBreak BreakTimerCommonIBreakTimer_TimerBreak;
typedef struct _BreakTimerCommonIBreakTimer_TimerBreakIface BreakTimerCommonIBreakTimer_TimerBreakIface;

#define BREAK_TIMER_COMMON_TYPE_IBREAKTIMER_TIMERBREAK_PROXY (break_timer_common_ibreaktimer_timerbreak_proxy_get_type ())

#define BREAK_TIMER_COMMON_TYPE_TIMER_BREAK_STATUS (break_timer_common_timer_break_status_get_type ())
typedef struct _BreakTimerCommonTimerBreakStatus BreakTimerCommonTimerBreakStatus;

#define BREAK_TIMER_COMMON_TYPE_BREAK_STATUS (break_timer_common_break_status_get_type ())
typedef struct _BreakTimerCommonBreakStatus BreakTimerCommonBreakStatus;

#define BREAK_TIMER_COMMON_TYPE_IBREAK_TIMER (break_timer_common_ibreak_timer_get_type ())
#define BREAK_TIMER_COMMON_IBREAK_TIMER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_COMMON_TYPE_IBREAK_TIMER, BreakTimerCommonIBreakTimer))
#define BREAK_TIMER_COMMON_IS_IBREAK_TIMER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_COMMON_TYPE_IBREAK_TIMER))
#define BREAK_TIMER_COMMON_IBREAK_TIMER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BREAK_TIMER_COMMON_TYPE_IBREAK_TIMER, BreakTimerCommonIBreakTimerIface))

typedef struct _BreakTimerCommonIBreakTimer BreakTimerCommonIBreakTimer;
typedef struct _BreakTimerCommonIBreakTimerIface BreakTimerCommonIBreakTimerIface;

#define BREAK_TIMER_COMMON_TYPE_IBREAK_TIMER_PROXY (break_timer_common_ibreak_timer_proxy_get_type ())

#define BREAK_TIMER_COMMON_TYPE_IFREEDESKTOP_APPLICATION (break_timer_common_ifreedesktop_application_get_type ())
#define BREAK_TIMER_COMMON_IFREEDESKTOP_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_COMMON_TYPE_IFREEDESKTOP_APPLICATION, BreakTimerCommonIFreedesktopApplication))
#define BREAK_TIMER_COMMON_IS_IFREEDESKTOP_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_COMMON_TYPE_IFREEDESKTOP_APPLICATION))
#define BREAK_TIMER_COMMON_IFREEDESKTOP_APPLICATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BREAK_TIMER_COMMON_TYPE_IFREEDESKTOP_APPLICATION, BreakTimerCommonIFreedesktopApplicationIface))

typedef struct _BreakTimerCommonIFreedesktopApplication BreakTimerCommonIFreedesktopApplication;
typedef struct _BreakTimerCommonIFreedesktopApplicationIface BreakTimerCommonIFreedesktopApplicationIface;

#define BREAK_TIMER_COMMON_TYPE_IFREEDESKTOP_APPLICATION_PROXY (break_timer_common_ifreedesktop_application_proxy_get_type ())

#define BREAK_TIMER_COMMON_TYPE_IGNOME_SCREEN_SAVER (break_timer_common_ignome_screen_saver_get_type ())
#define BREAK_TIMER_COMMON_IGNOME_SCREEN_SAVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_COMMON_TYPE_IGNOME_SCREEN_SAVER, BreakTimerCommonIGnomeScreenSaver))
#define BREAK_TIMER_COMMON_IS_IGNOME_SCREEN_SAVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_COMMON_TYPE_IGNOME_SCREEN_SAVER))
#define BREAK_TIMER_COMMON_IGNOME_SCREEN_SAVER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BREAK_TIMER_COMMON_TYPE_IGNOME_SCREEN_SAVER, BreakTimerCommonIGnomeScreenSaverIface))

typedef struct _BreakTimerCommonIGnomeScreenSaver BreakTimerCommonIGnomeScreenSaver;
typedef struct _BreakTimerCommonIGnomeScreenSaverIface BreakTimerCommonIGnomeScreenSaverIface;

#define BREAK_TIMER_COMMON_TYPE_IGNOME_SCREEN_SAVER_PROXY (break_timer_common_ignome_screen_saver_proxy_get_type ())

#define BREAK_TIMER_COMMON_TYPE_IMUTTER_IDLE_MONITOR (break_timer_common_imutter_idle_monitor_get_type ())
#define BREAK_TIMER_COMMON_IMUTTER_IDLE_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_COMMON_TYPE_IMUTTER_IDLE_MONITOR, BreakTimerCommonIMutterIdleMonitor))
#define BREAK_TIMER_COMMON_IS_IMUTTER_IDLE_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_COMMON_TYPE_IMUTTER_IDLE_MONITOR))
#define BREAK_TIMER_COMMON_IMUTTER_IDLE_MONITOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BREAK_TIMER_COMMON_TYPE_IMUTTER_IDLE_MONITOR, BreakTimerCommonIMutterIdleMonitorIface))

typedef struct _BreakTimerCommonIMutterIdleMonitor BreakTimerCommonIMutterIdleMonitor;
typedef struct _BreakTimerCommonIMutterIdleMonitorIface BreakTimerCommonIMutterIdleMonitorIface;

#define BREAK_TIMER_COMMON_TYPE_IMUTTER_IDLE_MONITOR_PROXY (break_timer_common_imutter_idle_monitor_proxy_get_type ())

#define BREAK_TIMER_COMMON_TYPE_IPORTAL_BACKGROUND (break_timer_common_iportal_background_get_type ())
#define BREAK_TIMER_COMMON_IPORTAL_BACKGROUND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_COMMON_TYPE_IPORTAL_BACKGROUND, BreakTimerCommonIPortalBackground))
#define BREAK_TIMER_COMMON_IS_IPORTAL_BACKGROUND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_COMMON_TYPE_IPORTAL_BACKGROUND))
#define BREAK_TIMER_COMMON_IPORTAL_BACKGROUND_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BREAK_TIMER_COMMON_TYPE_IPORTAL_BACKGROUND, BreakTimerCommonIPortalBackgroundIface))

typedef struct _BreakTimerCommonIPortalBackground BreakTimerCommonIPortalBackground;
typedef struct _BreakTimerCommonIPortalBackgroundIface BreakTimerCommonIPortalBackgroundIface;

#define BREAK_TIMER_COMMON_TYPE_IPORTAL_BACKGROUND_PROXY (break_timer_common_iportal_background_proxy_get_type ())

#define BREAK_TIMER_COMMON_TYPE_IPORTAL_REQUEST (break_timer_common_iportal_request_get_type ())
#define BREAK_TIMER_COMMON_IPORTAL_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_COMMON_TYPE_IPORTAL_REQUEST, BreakTimerCommonIPortalRequest))
#define BREAK_TIMER_COMMON_IS_IPORTAL_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_COMMON_TYPE_IPORTAL_REQUEST))
#define BREAK_TIMER_COMMON_IPORTAL_REQUEST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BREAK_TIMER_COMMON_TYPE_IPORTAL_REQUEST, BreakTimerCommonIPortalRequestIface))

typedef struct _BreakTimerCommonIPortalRequest BreakTimerCommonIPortalRequest;
typedef struct _BreakTimerCommonIPortalRequestIface BreakTimerCommonIPortalRequestIface;

#define BREAK_TIMER_COMMON_TYPE_IPORTAL_REQUEST_PROXY (break_timer_common_iportal_request_proxy_get_type ())

#define BREAK_TIMER_COMMON_TYPE_ISESSION_STATUS (break_timer_common_isession_status_get_type ())
#define BREAK_TIMER_COMMON_ISESSION_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_COMMON_TYPE_ISESSION_STATUS, BreakTimerCommonISessionStatus))
#define BREAK_TIMER_COMMON_IS_ISESSION_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_COMMON_TYPE_ISESSION_STATUS))
#define BREAK_TIMER_COMMON_ISESSION_STATUS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BREAK_TIMER_COMMON_TYPE_ISESSION_STATUS, BreakTimerCommonISessionStatusIface))

typedef struct _BreakTimerCommonISessionStatus BreakTimerCommonISessionStatus;
typedef struct _BreakTimerCommonISessionStatusIface BreakTimerCommonISessionStatusIface;

#define BREAK_TIMER_COMMON_TYPE_NATURAL_TIME (break_timer_common_natural_time_get_type ())
#define BREAK_TIMER_COMMON_NATURAL_TIME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_COMMON_TYPE_NATURAL_TIME, BreakTimerCommonNaturalTime))
#define BREAK_TIMER_COMMON_NATURAL_TIME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_COMMON_TYPE_NATURAL_TIME, BreakTimerCommonNaturalTimeClass))
#define BREAK_TIMER_COMMON_IS_NATURAL_TIME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_COMMON_TYPE_NATURAL_TIME))
#define BREAK_TIMER_COMMON_IS_NATURAL_TIME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_COMMON_TYPE_NATURAL_TIME))
#define BREAK_TIMER_COMMON_NATURAL_TIME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_COMMON_TYPE_NATURAL_TIME, BreakTimerCommonNaturalTimeClass))

typedef struct _BreakTimerCommonNaturalTime BreakTimerCommonNaturalTime;
typedef struct _BreakTimerCommonNaturalTimeClass BreakTimerCommonNaturalTimeClass;
typedef struct _BreakTimerCommonNaturalTimePrivate BreakTimerCommonNaturalTimePrivate;
typedef gchar* (*BreakTimerCommonNaturalTimeFormatTimeCb) (gint seconds, gpointer user_data);

#define BREAK_TIMER_COMMON_TYPE_TIME_UNIT (break_timer_common_time_unit_get_type ())
#define BREAK_TIMER_COMMON_TIME_UNIT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_COMMON_TYPE_TIME_UNIT, BreakTimerCommonTimeUnit))
#define BREAK_TIMER_COMMON_TIME_UNIT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_COMMON_TYPE_TIME_UNIT, BreakTimerCommonTimeUnitClass))
#define BREAK_TIMER_COMMON_IS_TIME_UNIT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_COMMON_TYPE_TIME_UNIT))
#define BREAK_TIMER_COMMON_IS_TIME_UNIT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_COMMON_TYPE_TIME_UNIT))
#define BREAK_TIMER_COMMON_TIME_UNIT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_COMMON_TYPE_TIME_UNIT, BreakTimerCommonTimeUnitClass))

typedef struct _BreakTimerCommonTimeUnit BreakTimerCommonTimeUnit;
typedef struct _BreakTimerCommonTimeUnitClass BreakTimerCommonTimeUnitClass;
typedef struct _BreakTimerCommonTimeUnitPrivate BreakTimerCommonTimeUnitPrivate;

struct _BreakTimerCommonTimerBreakStatus {
	gboolean is_enabled;
	gboolean is_focused;
	gboolean is_active;
	gint starts_in;
	gint time_remaining;
	gint current_duration;
};

struct _BreakTimerCommonIBreakTimer_TimerBreakIface {
	GTypeInterface parent_iface;
	void (*get_status) (BreakTimerCommonIBreakTimer_TimerBreak* self, BreakTimerCommonTimerBreakStatus* result, GError** error);
	void (*activate) (BreakTimerCommonIBreakTimer_TimerBreak* self, GError** error);
};

struct _BreakTimerCommonBreakStatus {
	gboolean is_enabled;
	gboolean is_focused;
	gboolean is_active;
};

struct _BreakTimerCommonIBreakTimerIface {
	GTypeInterface parent_iface;
	gchar** (*get_current_active_break) (BreakTimerCommonIBreakTimer* self, gint* result_length1, GError** error);
	gchar** (*get_break_ids) (BreakTimerCommonIBreakTimer* self, gint* result_length1, GError** error);
	gchar** (*get_status_messages) (BreakTimerCommonIBreakTimer* self, gint* result_length1, GError** error);
	void (*activate_break) (BreakTimerCommonIBreakTimer* self, const gchar* break_id, GError** error);
};

struct _BreakTimerCommonIFreedesktopApplicationIface {
	GTypeInterface parent_iface;
	void (*activate_action) (BreakTimerCommonIFreedesktopApplication* self, const gchar* action_name, GVariant** parameter, gint parameter_length1, GHashTable* platform_data, GError** error);
};

struct _BreakTimerCommonIGnomeScreenSaverIface {
	GTypeInterface parent_iface;
	gboolean (*get_active) (BreakTimerCommonIGnomeScreenSaver* self, GError** error);
	guint32 (*get_active_time) (BreakTimerCommonIGnomeScreenSaver* self, GError** error);
	void (*lock) (BreakTimerCommonIGnomeScreenSaver* self, GError** error);
	void (*set_active) (BreakTimerCommonIGnomeScreenSaver* self, gboolean active, GError** error);
};

struct _BreakTimerCommonIMutterIdleMonitorIface {
	GTypeInterface parent_iface;
	guint32 (*add_idle_watch) (BreakTimerCommonIMutterIdleMonitor* self, guint64 interval_ms, GError** error);
	guint32 (*add_user_active_watch) (BreakTimerCommonIMutterIdleMonitor* self, GError** error);
	guint64 (*get_idletime) (BreakTimerCommonIMutterIdleMonitor* self, GError** error);
	void (*remove_watch) (BreakTimerCommonIMutterIdleMonitor* self, guint32 id, GError** error);
	void (*reset_idletime) (BreakTimerCommonIMutterIdleMonitor* self, GError** error);
};

struct _BreakTimerCommonIPortalBackgroundIface {
	GTypeInterface parent_iface;
	char* (*request_background) (BreakTimerCommonIPortalBackground* self, const gchar* parent_window, GHashTable* options, GError** error);
	void (*set_status) (BreakTimerCommonIPortalBackground* self, GHashTable* options, GError** error);
};

struct _BreakTimerCommonIPortalRequestIface {
	GTypeInterface parent_iface;
	void (*close) (BreakTimerCommonIPortalRequest* self, GError** error);
};

struct _BreakTimerCommonISessionStatusIface {
	GTypeInterface parent_iface;
	gboolean (*is_locked) (BreakTimerCommonISessionStatus* self);
	void (*lock_screen) (BreakTimerCommonISessionStatus* self);
	void (*blank_screen) (BreakTimerCommonISessionStatus* self);
	void (*unblank_screen) (BreakTimerCommonISessionStatus* self);
};

struct _BreakTimerCommonNaturalTime {
	GObject parent_instance;
	BreakTimerCommonNaturalTimePrivate * priv;
};

struct _BreakTimerCommonNaturalTimeClass {
	GObjectClass parent_class;
};

struct _BreakTimerCommonTimeUnit {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BreakTimerCommonTimeUnitPrivate * priv;
};

struct _BreakTimerCommonTimeUnitClass {
	GTypeClass parent_class;
	void (*finalize) (BreakTimerCommonTimeUnit *self);
};

VALA_EXTERN GType break_timer_common_ibreaktimer_timerbreak_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint break_timer_common_ibreaktimer_timerbreak_register_object (void* object,
                                                                 GDBusConnection* connection,
                                                                 const gchar* path,
                                                                 GError** error);
VALA_EXTERN GType break_timer_common_timer_break_status_get_type (void) G_GNUC_CONST ;
VALA_EXTERN BreakTimerCommonTimerBreakStatus* break_timer_common_timer_break_status_dup (const BreakTimerCommonTimerBreakStatus* self);
VALA_EXTERN void break_timer_common_timer_break_status_free (BreakTimerCommonTimerBreakStatus* self);
VALA_EXTERN GType break_timer_common_ibreaktimer_timerbreak_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerCommonIBreakTimer_TimerBreak, g_object_unref)
VALA_EXTERN void break_timer_common_ibreaktimer_timerbreak_get_status (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                           BreakTimerCommonTimerBreakStatus* result,
                                                           GError** error);
VALA_EXTERN void break_timer_common_ibreaktimer_timerbreak_activate (BreakTimerCommonIBreakTimer_TimerBreak* self,
                                                         GError** error);
VALA_EXTERN GType break_timer_common_break_status_get_type (void) G_GNUC_CONST ;
VALA_EXTERN BreakTimerCommonBreakStatus* break_timer_common_break_status_dup (const BreakTimerCommonBreakStatus* self);
VALA_EXTERN void break_timer_common_break_status_free (BreakTimerCommonBreakStatus* self);
VALA_EXTERN GType break_timer_common_ibreak_timer_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint break_timer_common_ibreak_timer_register_object (void* object,
                                                       GDBusConnection* connection,
                                                       const gchar* path,
                                                       GError** error);
VALA_EXTERN GType break_timer_common_ibreak_timer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerCommonIBreakTimer, g_object_unref)
VALA_EXTERN gchar** break_timer_common_ibreak_timer_get_current_active_break (BreakTimerCommonIBreakTimer* self,
                                                                  gint* result_length1,
                                                                  GError** error);
VALA_EXTERN gchar** break_timer_common_ibreak_timer_get_break_ids (BreakTimerCommonIBreakTimer* self,
                                                       gint* result_length1,
                                                       GError** error);
VALA_EXTERN gchar** break_timer_common_ibreak_timer_get_status_messages (BreakTimerCommonIBreakTimer* self,
                                                             gint* result_length1,
                                                             GError** error);
VALA_EXTERN void break_timer_common_ibreak_timer_activate_break (BreakTimerCommonIBreakTimer* self,
                                                     const gchar* break_id,
                                                     GError** error);
VALA_EXTERN GType break_timer_common_ifreedesktop_application_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint break_timer_common_ifreedesktop_application_register_object (void* object,
                                                                   GDBusConnection* connection,
                                                                   const gchar* path,
                                                                   GError** error);
VALA_EXTERN GType break_timer_common_ifreedesktop_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerCommonIFreedesktopApplication, g_object_unref)
VALA_EXTERN void break_timer_common_ifreedesktop_application_activate_action (BreakTimerCommonIFreedesktopApplication* self,
                                                                  const gchar* action_name,
                                                                  GVariant** parameter,
                                                                  gint parameter_length1,
                                                                  GHashTable* platform_data,
                                                                  GError** error);
VALA_EXTERN GType break_timer_common_ignome_screen_saver_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint break_timer_common_ignome_screen_saver_register_object (void* object,
                                                              GDBusConnection* connection,
                                                              const gchar* path,
                                                              GError** error);
VALA_EXTERN GType break_timer_common_ignome_screen_saver_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerCommonIGnomeScreenSaver, g_object_unref)
VALA_EXTERN gboolean break_timer_common_ignome_screen_saver_get_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                            GError** error);
VALA_EXTERN guint32 break_timer_common_ignome_screen_saver_get_active_time (BreakTimerCommonIGnomeScreenSaver* self,
                                                                GError** error);
VALA_EXTERN void break_timer_common_ignome_screen_saver_lock (BreakTimerCommonIGnomeScreenSaver* self,
                                                  GError** error);
VALA_EXTERN void break_timer_common_ignome_screen_saver_set_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                        gboolean active,
                                                        GError** error);
VALA_EXTERN GType break_timer_common_imutter_idle_monitor_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint break_timer_common_imutter_idle_monitor_register_object (void* object,
                                                               GDBusConnection* connection,
                                                               const gchar* path,
                                                               GError** error);
VALA_EXTERN GType break_timer_common_imutter_idle_monitor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerCommonIMutterIdleMonitor, g_object_unref)
VALA_EXTERN guint32 break_timer_common_imutter_idle_monitor_add_idle_watch (BreakTimerCommonIMutterIdleMonitor* self,
                                                                guint64 interval_ms,
                                                                GError** error);
VALA_EXTERN guint32 break_timer_common_imutter_idle_monitor_add_user_active_watch (BreakTimerCommonIMutterIdleMonitor* self,
                                                                       GError** error);
VALA_EXTERN guint64 break_timer_common_imutter_idle_monitor_get_idletime (BreakTimerCommonIMutterIdleMonitor* self,
                                                              GError** error);
VALA_EXTERN void break_timer_common_imutter_idle_monitor_remove_watch (BreakTimerCommonIMutterIdleMonitor* self,
                                                           guint32 id,
                                                           GError** error);
VALA_EXTERN void break_timer_common_imutter_idle_monitor_reset_idletime (BreakTimerCommonIMutterIdleMonitor* self,
                                                             GError** error);
VALA_EXTERN GType break_timer_common_iportal_background_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint break_timer_common_iportal_background_register_object (void* object,
                                                             GDBusConnection* connection,
                                                             const gchar* path,
                                                             GError** error);
VALA_EXTERN GType break_timer_common_iportal_background_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerCommonIPortalBackground, g_object_unref)
VALA_EXTERN char* break_timer_common_iportal_background_request_background (BreakTimerCommonIPortalBackground* self,
                                                                const gchar* parent_window,
                                                                GHashTable* options,
                                                                GError** error);
VALA_EXTERN void break_timer_common_iportal_background_set_status (BreakTimerCommonIPortalBackground* self,
                                                       GHashTable* options,
                                                       GError** error);
VALA_EXTERN GType break_timer_common_iportal_request_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint break_timer_common_iportal_request_register_object (void* object,
                                                          GDBusConnection* connection,
                                                          const gchar* path,
                                                          GError** error);
VALA_EXTERN GType break_timer_common_iportal_request_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerCommonIPortalRequest, g_object_unref)
VALA_EXTERN void break_timer_common_iportal_request_close (BreakTimerCommonIPortalRequest* self,
                                               GError** error);
VALA_EXTERN GType break_timer_common_isession_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerCommonISessionStatus, g_object_unref)
VALA_EXTERN gboolean break_timer_common_isession_status_is_locked (BreakTimerCommonISessionStatus* self);
VALA_EXTERN void break_timer_common_isession_status_lock_screen (BreakTimerCommonISessionStatus* self);
VALA_EXTERN void break_timer_common_isession_status_blank_screen (BreakTimerCommonISessionStatus* self);
VALA_EXTERN void break_timer_common_isession_status_unblank_screen (BreakTimerCommonISessionStatus* self);
VALA_EXTERN GType break_timer_common_natural_time_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerCommonNaturalTime, g_object_unref)
VALA_EXTERN gchar* break_timer_common_natural_time_get_label_for_seconds (BreakTimerCommonNaturalTime* self,
                                                              gint seconds,
                                                              gint* output_value);
VALA_EXTERN gchar* break_timer_common_natural_time_get_simplest_label_for_seconds (BreakTimerCommonNaturalTime* self,
                                                                       gint seconds,
                                                                       gint* output_value);
VALA_EXTERN gchar* break_timer_common_natural_time_get_countdown_for_seconds (BreakTimerCommonNaturalTime* self,
                                                                  gint seconds,
                                                                  gint* output_value);
VALA_EXTERN gchar* break_timer_common_natural_time_get_countdown_for_seconds_with_start (BreakTimerCommonNaturalTime* self,
                                                                             gint seconds,
                                                                             gint start,
                                                                             gint* output_value);
VALA_EXTERN BreakTimerCommonNaturalTime* break_timer_common_natural_time_get_instance (void);
VALA_EXTERN gpointer break_timer_common_time_unit_ref (gpointer instance);
VALA_EXTERN void break_timer_common_time_unit_unref (gpointer instance);
VALA_EXTERN GParamSpec* break_timer_common_param_spec_time_unit (const gchar* name,
                                                     const gchar* nick,
                                                     const gchar* blurb,
                                                     GType object_type,
                                                     GParamFlags flags);
VALA_EXTERN void break_timer_common_value_set_time_unit (GValue* value,
                                             gpointer v_object);
VALA_EXTERN void break_timer_common_value_take_time_unit (GValue* value,
                                              gpointer v_object);
VALA_EXTERN gpointer break_timer_common_value_get_time_unit (const GValue* value);
VALA_EXTERN GType break_timer_common_time_unit_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerCommonTimeUnit, break_timer_common_time_unit_unref)
VALA_EXTERN gboolean break_timer_common_time_unit__do_override_time;
VALA_EXTERN gint64 break_timer_common_time_unit__override_real_time;
VALA_EXTERN gint64 break_timer_common_time_unit__override_monotonic_time;
VALA_EXTERN gint64 break_timer_common_time_unit_get_real_time (void);
VALA_EXTERN gint64 break_timer_common_time_unit_get_real_time_ms (void);
VALA_EXTERN gint64 break_timer_common_time_unit_get_real_time_seconds (void);
VALA_EXTERN gint64 break_timer_common_time_unit_get_monotonic_time (void);
VALA_EXTERN gint64 break_timer_common_time_unit_get_monotonic_time_ms (void);
VALA_EXTERN gint64 break_timer_common_time_unit_get_monotonic_time_seconds (void);
VALA_EXTERN BreakTimerCommonTimeUnit* break_timer_common_time_unit_construct (GType object_type);

G_END_DECLS

#endif
