/* MicroBreakStatusWidget.c generated by valac 0.56.19, the Vala compiler
 * generated from MicroBreakStatusWidget.vala, do not modify */

/* MicroBreakStatusWidget.vala
 *
 * Copyright 2020 Dylan McCall <dylan@dylanmccall.ca>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "settings.h"
#include <glib-object.h>
#include <glib.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_STATUS_WIDGET (break_timer_settings_micro_break_micro_break_status_widget_get_type ())
#define BREAK_TIMER_SETTINGS_MICRO_BREAK_MICRO_BREAK_STATUS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_STATUS_WIDGET, BreakTimerSettingsMicroBreakMicroBreakStatusWidget))
#define BREAK_TIMER_SETTINGS_MICRO_BREAK_MICRO_BREAK_STATUS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_STATUS_WIDGET, BreakTimerSettingsMicroBreakMicroBreakStatusWidgetClass))
#define BREAK_TIMER_SETTINGS_MICRO_BREAK_IS_MICRO_BREAK_STATUS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_STATUS_WIDGET))
#define BREAK_TIMER_SETTINGS_MICRO_BREAK_IS_MICRO_BREAK_STATUS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_STATUS_WIDGET))
#define BREAK_TIMER_SETTINGS_MICRO_BREAK_MICRO_BREAK_STATUS_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_STATUS_WIDGET, BreakTimerSettingsMicroBreakMicroBreakStatusWidgetClass))

typedef struct _BreakTimerSettingsMicroBreakMicroBreakStatusWidget BreakTimerSettingsMicroBreakMicroBreakStatusWidget;
typedef struct _BreakTimerSettingsMicroBreakMicroBreakStatusWidgetClass BreakTimerSettingsMicroBreakMicroBreakStatusWidgetClass;
typedef struct _BreakTimerSettingsMicroBreakMicroBreakStatusWidgetPrivate BreakTimerSettingsMicroBreakMicroBreakStatusWidgetPrivate;
enum  {
	BREAK_TIMER_SETTINGS_MICRO_BREAK_MICRO_BREAK_STATUS_WIDGET_0_PROPERTY,
	BREAK_TIMER_SETTINGS_MICRO_BREAK_MICRO_BREAK_STATUS_WIDGET_NUM_PROPERTIES
};
static GParamSpec* break_timer_settings_micro_break_micro_break_status_widget_properties[BREAK_TIMER_SETTINGS_MICRO_BREAK_MICRO_BREAK_STATUS_WIDGET_NUM_PROPERTIES];

struct _BreakTimerSettingsMicroBreakMicroBreakStatusWidget {
	BreakTimerSettingsTimerBreakTimerBreakStatusWidget parent_instance;
	BreakTimerSettingsMicroBreakMicroBreakStatusWidgetPrivate * priv;
};

struct _BreakTimerSettingsMicroBreakMicroBreakStatusWidgetClass {
	BreakTimerSettingsTimerBreakTimerBreakStatusWidgetClass parent_class;
};

static gpointer break_timer_settings_micro_break_micro_break_status_widget_parent_class = NULL;

VALA_EXTERN GType break_timer_settings_micro_break_micro_break_status_widget_get_type (void) G_GNUC_CONST ;
VALA_EXTERN BreakTimerSettingsMicroBreakMicroBreakStatusWidget* break_timer_settings_micro_break_micro_break_status_widget_new (BreakTimerSettingsMicroBreakMicroBreakType* break_type);
VALA_EXTERN BreakTimerSettingsMicroBreakMicroBreakStatusWidget* break_timer_settings_micro_break_micro_break_status_widget_construct (GType object_type,
                                                                                                                          BreakTimerSettingsMicroBreakMicroBreakType* break_type);
static GType break_timer_settings_micro_break_micro_break_status_widget_get_type_once (void);

BreakTimerSettingsMicroBreakMicroBreakStatusWidget*
break_timer_settings_micro_break_micro_break_status_widget_construct (GType object_type,
                                                                      BreakTimerSettingsMicroBreakMicroBreakType* break_type)
{
	BreakTimerSettingsMicroBreakMicroBreakStatusWidget * self = NULL;
	g_return_val_if_fail (break_type != NULL, NULL);
	self = (BreakTimerSettingsMicroBreakMicroBreakStatusWidget*) break_timer_settings_timer_break_timer_break_status_widget_construct (object_type, (BreakTimerSettingsTimerBreakTimerBreakType*) break_type, _ ("Your next microbreak is in"), _ ("It's time for a microbreak"));
	return self;
}

BreakTimerSettingsMicroBreakMicroBreakStatusWidget*
break_timer_settings_micro_break_micro_break_status_widget_new (BreakTimerSettingsMicroBreakMicroBreakType* break_type)
{
	return break_timer_settings_micro_break_micro_break_status_widget_construct (BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_STATUS_WIDGET, break_type);
}

static void
break_timer_settings_micro_break_micro_break_status_widget_class_init (BreakTimerSettingsMicroBreakMicroBreakStatusWidgetClass * klass,
                                                                       gpointer klass_data)
{
	break_timer_settings_micro_break_micro_break_status_widget_parent_class = g_type_class_peek_parent (klass);
}

static void
break_timer_settings_micro_break_micro_break_status_widget_instance_init (BreakTimerSettingsMicroBreakMicroBreakStatusWidget * self,
                                                                          gpointer klass)
{
}

static GType
break_timer_settings_micro_break_micro_break_status_widget_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BreakTimerSettingsMicroBreakMicroBreakStatusWidgetClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) break_timer_settings_micro_break_micro_break_status_widget_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BreakTimerSettingsMicroBreakMicroBreakStatusWidget), 0, (GInstanceInitFunc) break_timer_settings_micro_break_micro_break_status_widget_instance_init, NULL };
	GType break_timer_settings_micro_break_micro_break_status_widget_type_id;
	break_timer_settings_micro_break_micro_break_status_widget_type_id = g_type_register_static (BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_STATUS_WIDGET, "BreakTimerSettingsMicroBreakMicroBreakStatusWidget", &g_define_type_info, 0);
	return break_timer_settings_micro_break_micro_break_status_widget_type_id;
}

GType
break_timer_settings_micro_break_micro_break_status_widget_get_type (void)
{
	static volatile gsize break_timer_settings_micro_break_micro_break_status_widget_type_id__once = 0;
	if (g_once_init_enter (&break_timer_settings_micro_break_micro_break_status_widget_type_id__once)) {
		GType break_timer_settings_micro_break_micro_break_status_widget_type_id;
		break_timer_settings_micro_break_micro_break_status_widget_type_id = break_timer_settings_micro_break_micro_break_status_widget_get_type_once ();
		g_once_init_leave (&break_timer_settings_micro_break_micro_break_status_widget_type_id__once, break_timer_settings_micro_break_micro_break_status_widget_type_id);
	}
	return break_timer_settings_micro_break_micro_break_status_widget_type_id__once;
}

