/* BreakType.c generated by valac 0.56.19, the Vala compiler
 * generated from BreakType.vala, do not modify */

/* BreakType.vala
 *
 * Copyright 2020 Dylan McCall <dylan@dylanmccall.ca>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "settings.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include "common.h"
#include <gio/gio.h>
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_0_PROPERTY,
	BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_ID_PROPERTY,
	BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_PROPERTY,
	BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_INFO_WIDGET_PROPERTY,
	BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_WIDGET_PROPERTY,
	BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_SETTINGS_WIDGET_PROPERTY,
	BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_NUM_PROPERTIES
};
static GParamSpec* break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
enum  {
	BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_CHANGED_SIGNAL,
	BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_NUM_SIGNALS
};
static guint break_timer_settings_break_break_type_signals[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_NUM_SIGNALS] = {0};

struct _BreakTimerSettingsBreakBreakTypePrivate {
	gchar* _id;
	BreakTimerCommonBreakStatus* _status;
	BreakTimerSettingsBreakBreakInfoWidget* _info_widget;
	BreakTimerSettingsBreakBreakStatusWidget* _status_widget;
	BreakTimerSettingsBreakBreakSettingsWidget* _settings_widget;
};

static gint BreakTimerSettingsBreakBreakType_private_offset;
static gpointer break_timer_settings_break_break_type_parent_class = NULL;
static GInitableIface * break_timer_settings_break_break_type_g_initable_parent_iface = NULL;

static void break_timer_settings_break_break_type_set_id (BreakTimerSettingsBreakBreakType* self,
                                                   const gchar* value);
static gboolean break_timer_settings_break_break_type_real_init (BreakTimerSettingsBreakBreakType* self,
                                                          GCancellable* cancellable,
                                                          GError** error);
static void break_timer_settings_break_break_type_set_info_widget (BreakTimerSettingsBreakBreakType* self,
                                                            BreakTimerSettingsBreakBreakInfoWidget* value);
static void break_timer_settings_break_break_type_set_status_widget (BreakTimerSettingsBreakBreakType* self,
                                                              BreakTimerSettingsBreakBreakStatusWidget* value);
static void break_timer_settings_break_break_type_set_settings_widget (BreakTimerSettingsBreakBreakType* self,
                                                                BreakTimerSettingsBreakBreakSettingsWidget* value);
static void break_timer_settings_break_break_type_set_status (BreakTimerSettingsBreakBreakType* self,
                                                       BreakTimerCommonBreakStatus* value);
static BreakTimerSettingsBreakBreakInfoWidget* break_timer_settings_break_break_type_real_create_info_widget (BreakTimerSettingsBreakBreakType* self);
static BreakTimerSettingsBreakBreakStatusWidget* break_timer_settings_break_break_type_real_create_status_widget (BreakTimerSettingsBreakBreakType* self);
static BreakTimerSettingsBreakBreakSettingsWidget* break_timer_settings_break_break_type_real_create_settings_widget (BreakTimerSettingsBreakBreakType* self);
static gboolean _break_timer_common_break_status_equal (const BreakTimerCommonBreakStatus * s1,
                                                 const BreakTimerCommonBreakStatus * s2);
static BreakTimerCommonBreakStatus* _break_timer_common_break_status_dup (BreakTimerCommonBreakStatus* self);
static void break_timer_settings_break_break_type_finalize (GObject * obj);
static GType break_timer_settings_break_break_type_get_type_once (void);
static void _vala_break_timer_settings_break_break_type_get_property (GObject * object,
                                                               guint property_id,
                                                               GValue * value,
                                                               GParamSpec * pspec);
static void _vala_break_timer_settings_break_break_type_set_property (GObject * object,
                                                               guint property_id,
                                                               const GValue * value,
                                                               GParamSpec * pspec);

static inline gpointer
break_timer_settings_break_break_type_get_instance_private (BreakTimerSettingsBreakBreakType* self)
{
	return G_STRUCT_MEMBER_P (self, BreakTimerSettingsBreakBreakType_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

BreakTimerSettingsBreakBreakType*
break_timer_settings_break_break_type_construct (GType object_type,
                                                 const gchar* id,
                                                 GSettings* settings)
{
	BreakTimerSettingsBreakBreakType * self = NULL;
	GSettings* _tmp0_;
	g_return_val_if_fail (id != NULL, NULL);
	g_return_val_if_fail (settings != NULL, NULL);
	self = (BreakTimerSettingsBreakBreakType*) g_object_new (object_type, NULL);
	break_timer_settings_break_break_type_set_id (self, id);
	_tmp0_ = _g_object_ref0 (settings);
	_g_object_unref0 (self->settings);
	self->settings = _tmp0_;
	return self;
}

static gboolean
break_timer_settings_break_break_type_real_init (BreakTimerSettingsBreakBreakType* self,
                                                 GCancellable* cancellable,
                                                 GError** error)
{
	BreakTimerSettingsBreakBreakInfoWidget* _tmp0_;
	BreakTimerSettingsBreakBreakInfoWidget* _tmp1_;
	BreakTimerSettingsBreakBreakStatusWidget* _tmp2_;
	BreakTimerSettingsBreakBreakStatusWidget* _tmp3_;
	BreakTimerSettingsBreakBreakSettingsWidget* _tmp4_;
	BreakTimerSettingsBreakBreakSettingsWidget* _tmp5_;
	gboolean result;
	_tmp0_ = break_timer_settings_break_break_type_create_info_widget (self);
	_tmp1_ = _tmp0_;
	break_timer_settings_break_break_type_set_info_widget (self, _tmp1_);
	_g_object_unref0 (_tmp1_);
	_tmp2_ = break_timer_settings_break_break_type_create_status_widget (self);
	_tmp3_ = _tmp2_;
	break_timer_settings_break_break_type_set_status_widget (self, _tmp3_);
	_g_object_unref0 (_tmp3_);
	_tmp4_ = break_timer_settings_break_break_type_create_settings_widget (self);
	_tmp5_ = _tmp4_;
	break_timer_settings_break_break_type_set_settings_widget (self, _tmp5_);
	_g_object_unref0 (_tmp5_);
	result = TRUE;
	return result;
}

gboolean
break_timer_settings_break_break_type_init (BreakTimerSettingsBreakBreakType* self,
                                            GCancellable* cancellable,
                                            GError** error)
{
	BreakTimerSettingsBreakBreakTypeClass* _klass_;
	g_return_val_if_fail (self != NULL, FALSE);
	_klass_ = BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_GET_CLASS (self);
	if (_klass_->init) {
		return _klass_->init (self, cancellable, error);
	}
	return FALSE;
}

void
break_timer_settings_break_break_type_update_status (BreakTimerSettingsBreakBreakType* self,
                                                     BreakTimerCommonBreakStatus* status)
{
	g_return_if_fail (self != NULL);
	break_timer_settings_break_break_type_set_status (self, status);
	g_signal_emit (self, break_timer_settings_break_break_type_signals[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_CHANGED_SIGNAL], 0, status);
}

static BreakTimerSettingsBreakBreakInfoWidget*
break_timer_settings_break_break_type_real_create_info_widget (BreakTimerSettingsBreakBreakType* self)
{
	g_critical ("Type `%s' does not implement abstract method `break_timer_settings_break_break_type_create_info_widget'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

BreakTimerSettingsBreakBreakInfoWidget*
break_timer_settings_break_break_type_create_info_widget (BreakTimerSettingsBreakBreakType* self)
{
	BreakTimerSettingsBreakBreakTypeClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_GET_CLASS (self);
	if (_klass_->create_info_widget) {
		return _klass_->create_info_widget (self);
	}
	return NULL;
}

static BreakTimerSettingsBreakBreakStatusWidget*
break_timer_settings_break_break_type_real_create_status_widget (BreakTimerSettingsBreakBreakType* self)
{
	g_critical ("Type `%s' does not implement abstract method `break_timer_settings_break_break_type_create_status_widget'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

BreakTimerSettingsBreakBreakStatusWidget*
break_timer_settings_break_break_type_create_status_widget (BreakTimerSettingsBreakBreakType* self)
{
	BreakTimerSettingsBreakBreakTypeClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_GET_CLASS (self);
	if (_klass_->create_status_widget) {
		return _klass_->create_status_widget (self);
	}
	return NULL;
}

static BreakTimerSettingsBreakBreakSettingsWidget*
break_timer_settings_break_break_type_real_create_settings_widget (BreakTimerSettingsBreakBreakType* self)
{
	g_critical ("Type `%s' does not implement abstract method `break_timer_settings_break_break_type_create_settings_widget'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
	return NULL;
}

BreakTimerSettingsBreakBreakSettingsWidget*
break_timer_settings_break_break_type_create_settings_widget (BreakTimerSettingsBreakBreakType* self)
{
	BreakTimerSettingsBreakBreakTypeClass* _klass_;
	g_return_val_if_fail (self != NULL, NULL);
	_klass_ = BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_GET_CLASS (self);
	if (_klass_->create_settings_widget) {
		return _klass_->create_settings_widget (self);
	}
	return NULL;
}

const gchar*
break_timer_settings_break_break_type_get_id (BreakTimerSettingsBreakBreakType* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

static void
break_timer_settings_break_break_type_set_id (BreakTimerSettingsBreakBreakType* self,
                                              const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = break_timer_settings_break_break_type_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_ID_PROPERTY]);
	}
}

BreakTimerCommonBreakStatus*
break_timer_settings_break_break_type_get_status (BreakTimerSettingsBreakBreakType* self)
{
	BreakTimerCommonBreakStatus* result;
	BreakTimerCommonBreakStatus* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_status;
	result = _tmp0_;
	return result;
}

static gboolean
_break_timer_common_break_status_equal (const BreakTimerCommonBreakStatus * s1,
                                        const BreakTimerCommonBreakStatus * s2)
{
	if (s1 == s2) {
		return TRUE;
	}
	if (s1 == NULL) {
		return FALSE;
	}
	if (s2 == NULL) {
		return FALSE;
	}
	if (s1->is_enabled != s2->is_enabled) {
		return FALSE;
	}
	if (s1->is_focused != s2->is_focused) {
		return FALSE;
	}
	if (s1->is_active != s2->is_active) {
		return FALSE;
	}
	return TRUE;
}

static BreakTimerCommonBreakStatus*
_break_timer_common_break_status_dup (BreakTimerCommonBreakStatus* self)
{
	BreakTimerCommonBreakStatus* dup;
	dup = g_new0 (BreakTimerCommonBreakStatus, 1);
	memcpy (dup, self, sizeof (BreakTimerCommonBreakStatus));
	return dup;
}

static gpointer
__break_timer_common_break_status_dup0 (gpointer self)
{
	return self ? _break_timer_common_break_status_dup (self) : NULL;
}

static void
break_timer_settings_break_break_type_set_status (BreakTimerSettingsBreakBreakType* self,
                                                  BreakTimerCommonBreakStatus* value)
{
	BreakTimerCommonBreakStatus* old_value;
	g_return_if_fail (self != NULL);
	old_value = break_timer_settings_break_break_type_get_status (self);
	if (_break_timer_common_break_status_equal (value, old_value) != TRUE) {
		BreakTimerCommonBreakStatus* _tmp0_;
		_tmp0_ = __break_timer_common_break_status_dup0 (value);
		_g_free0 (self->priv->_status);
		self->priv->_status = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_PROPERTY]);
	}
}

BreakTimerSettingsBreakBreakInfoWidget*
break_timer_settings_break_break_type_get_info_widget (BreakTimerSettingsBreakBreakType* self)
{
	BreakTimerSettingsBreakBreakInfoWidget* result;
	BreakTimerSettingsBreakBreakInfoWidget* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_info_widget;
	result = _tmp0_;
	return result;
}

static void
break_timer_settings_break_break_type_set_info_widget (BreakTimerSettingsBreakBreakType* self,
                                                       BreakTimerSettingsBreakBreakInfoWidget* value)
{
	BreakTimerSettingsBreakBreakInfoWidget* old_value;
	g_return_if_fail (self != NULL);
	old_value = break_timer_settings_break_break_type_get_info_widget (self);
	if (old_value != value) {
		BreakTimerSettingsBreakBreakInfoWidget* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_info_widget);
		self->priv->_info_widget = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_INFO_WIDGET_PROPERTY]);
	}
}

BreakTimerSettingsBreakBreakStatusWidget*
break_timer_settings_break_break_type_get_status_widget (BreakTimerSettingsBreakBreakType* self)
{
	BreakTimerSettingsBreakBreakStatusWidget* result;
	BreakTimerSettingsBreakBreakStatusWidget* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_status_widget;
	result = _tmp0_;
	return result;
}

static void
break_timer_settings_break_break_type_set_status_widget (BreakTimerSettingsBreakBreakType* self,
                                                         BreakTimerSettingsBreakBreakStatusWidget* value)
{
	BreakTimerSettingsBreakBreakStatusWidget* old_value;
	g_return_if_fail (self != NULL);
	old_value = break_timer_settings_break_break_type_get_status_widget (self);
	if (old_value != value) {
		BreakTimerSettingsBreakBreakStatusWidget* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_status_widget);
		self->priv->_status_widget = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_WIDGET_PROPERTY]);
	}
}

BreakTimerSettingsBreakBreakSettingsWidget*
break_timer_settings_break_break_type_get_settings_widget (BreakTimerSettingsBreakBreakType* self)
{
	BreakTimerSettingsBreakBreakSettingsWidget* result;
	BreakTimerSettingsBreakBreakSettingsWidget* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_settings_widget;
	result = _tmp0_;
	return result;
}

static void
break_timer_settings_break_break_type_set_settings_widget (BreakTimerSettingsBreakBreakType* self,
                                                           BreakTimerSettingsBreakBreakSettingsWidget* value)
{
	BreakTimerSettingsBreakBreakSettingsWidget* old_value;
	g_return_if_fail (self != NULL);
	old_value = break_timer_settings_break_break_type_get_settings_widget (self);
	if (old_value != value) {
		BreakTimerSettingsBreakBreakSettingsWidget* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_settings_widget);
		self->priv->_settings_widget = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_SETTINGS_WIDGET_PROPERTY]);
	}
}

static void
break_timer_settings_break_break_type_class_init (BreakTimerSettingsBreakBreakTypeClass * klass,
                                                  gpointer klass_data)
{
	break_timer_settings_break_break_type_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &BreakTimerSettingsBreakBreakType_private_offset);
	((BreakTimerSettingsBreakBreakTypeClass *) klass)->init = (gboolean (*) (BreakTimerSettingsBreakBreakType*, GCancellable*, GError**)) break_timer_settings_break_break_type_real_init;
	((BreakTimerSettingsBreakBreakTypeClass *) klass)->create_info_widget = (BreakTimerSettingsBreakBreakInfoWidget* (*) (BreakTimerSettingsBreakBreakType*)) break_timer_settings_break_break_type_real_create_info_widget;
	((BreakTimerSettingsBreakBreakTypeClass *) klass)->create_status_widget = (BreakTimerSettingsBreakBreakStatusWidget* (*) (BreakTimerSettingsBreakBreakType*)) break_timer_settings_break_break_type_real_create_status_widget;
	((BreakTimerSettingsBreakBreakTypeClass *) klass)->create_settings_widget = (BreakTimerSettingsBreakBreakSettingsWidget* (*) (BreakTimerSettingsBreakBreakType*)) break_timer_settings_break_break_type_real_create_settings_widget;
	G_OBJECT_CLASS (klass)->get_property = _vala_break_timer_settings_break_break_type_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_break_timer_settings_break_break_type_set_property;
	G_OBJECT_CLASS (klass)->finalize = break_timer_settings_break_break_type_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_ID_PROPERTY, break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_PROPERTY, break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_PROPERTY] = g_param_spec_boxed ("status", "status", "status", BREAK_TIMER_COMMON_TYPE_BREAK_STATUS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_INFO_WIDGET_PROPERTY, break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_INFO_WIDGET_PROPERTY] = g_param_spec_object ("info-widget", "info-widget", "info-widget", BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_INFO_WIDGET, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_WIDGET_PROPERTY, break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_WIDGET_PROPERTY] = g_param_spec_object ("status-widget", "status-widget", "status-widget", BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_STATUS_WIDGET, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_SETTINGS_WIDGET_PROPERTY, break_timer_settings_break_break_type_properties[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_SETTINGS_WIDGET_PROPERTY] = g_param_spec_object ("settings-widget", "settings-widget", "settings-widget", BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_SETTINGS_WIDGET, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	break_timer_settings_break_break_type_signals[BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_CHANGED_SIGNAL] = g_signal_new ("status-changed", BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_TYPE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE, 1, G_TYPE_POINTER);
}

static void
break_timer_settings_break_break_type_g_initable_interface_init (GInitableIface * iface,
                                                                 gpointer iface_data)
{
	break_timer_settings_break_break_type_g_initable_parent_iface = g_type_interface_peek_parent (iface);
	iface->init = (gboolean (*) (GInitable*, GCancellable*, GError**)) break_timer_settings_break_break_type_init;
}

static void
break_timer_settings_break_break_type_instance_init (BreakTimerSettingsBreakBreakType * self,
                                                     gpointer klass)
{
	self->priv = break_timer_settings_break_break_type_get_instance_private (self);
}

static void
break_timer_settings_break_break_type_finalize (GObject * obj)
{
	BreakTimerSettingsBreakBreakType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_TYPE, BreakTimerSettingsBreakBreakType);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_status);
	_g_object_unref0 (self->priv->_info_widget);
	_g_object_unref0 (self->priv->_status_widget);
	_g_object_unref0 (self->priv->_settings_widget);
	_g_object_unref0 (self->settings);
	G_OBJECT_CLASS (break_timer_settings_break_break_type_parent_class)->finalize (obj);
}

static GType
break_timer_settings_break_break_type_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BreakTimerSettingsBreakBreakTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) break_timer_settings_break_break_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BreakTimerSettingsBreakBreakType), 0, (GInstanceInitFunc) break_timer_settings_break_break_type_instance_init, NULL };
	static const GInterfaceInfo g_initable_info = { (GInterfaceInitFunc) break_timer_settings_break_break_type_g_initable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType break_timer_settings_break_break_type_type_id;
	break_timer_settings_break_break_type_type_id = g_type_register_static (G_TYPE_OBJECT, "BreakTimerSettingsBreakBreakType", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
	g_type_add_interface_static (break_timer_settings_break_break_type_type_id, g_initable_get_type (), &g_initable_info);
	BreakTimerSettingsBreakBreakType_private_offset = g_type_add_instance_private (break_timer_settings_break_break_type_type_id, sizeof (BreakTimerSettingsBreakBreakTypePrivate));
	return break_timer_settings_break_break_type_type_id;
}

GType
break_timer_settings_break_break_type_get_type (void)
{
	static volatile gsize break_timer_settings_break_break_type_type_id__once = 0;
	if (g_once_init_enter (&break_timer_settings_break_break_type_type_id__once)) {
		GType break_timer_settings_break_break_type_type_id;
		break_timer_settings_break_break_type_type_id = break_timer_settings_break_break_type_get_type_once ();
		g_once_init_leave (&break_timer_settings_break_break_type_type_id__once, break_timer_settings_break_break_type_type_id);
	}
	return break_timer_settings_break_break_type_type_id__once;
}

static void
_vala_break_timer_settings_break_break_type_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec)
{
	BreakTimerSettingsBreakBreakType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_TYPE, BreakTimerSettingsBreakBreakType);
	switch (property_id) {
		case BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_ID_PROPERTY:
		g_value_set_string (value, break_timer_settings_break_break_type_get_id (self));
		break;
		case BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_PROPERTY:
		{
			BreakTimerCommonBreakStatus* boxed;
			boxed = break_timer_settings_break_break_type_get_status (self);
			g_value_set_boxed (value, boxed);
		}
		break;
		case BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_INFO_WIDGET_PROPERTY:
		g_value_set_object (value, break_timer_settings_break_break_type_get_info_widget (self));
		break;
		case BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_WIDGET_PROPERTY:
		g_value_set_object (value, break_timer_settings_break_break_type_get_status_widget (self));
		break;
		case BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_SETTINGS_WIDGET_PROPERTY:
		g_value_set_object (value, break_timer_settings_break_break_type_get_settings_widget (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_break_timer_settings_break_break_type_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec)
{
	BreakTimerSettingsBreakBreakType * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_TYPE, BreakTimerSettingsBreakBreakType);
	switch (property_id) {
		case BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_ID_PROPERTY:
		break_timer_settings_break_break_type_set_id (self, g_value_get_string (value));
		break;
		case BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_PROPERTY:
		break_timer_settings_break_break_type_set_status (self, g_value_get_boxed (value));
		break;
		case BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_INFO_WIDGET_PROPERTY:
		break_timer_settings_break_break_type_set_info_widget (self, g_value_get_object (value));
		break;
		case BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_STATUS_WIDGET_PROPERTY:
		break_timer_settings_break_break_type_set_status_widget (self, g_value_get_object (value));
		break;
		case BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_SETTINGS_WIDGET_PROPERTY:
		break_timer_settings_break_break_type_set_settings_widget (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

