/* TimerBreakDBusObject.c generated by valac 0.56.19, the Vala compiler
 * generated from TimerBreakDBusObject.vala, do not modify */

/* TimerBreakDBusObject.vala
 *
 * Copyright 2020 Dylan McCall <dylan@dylanmccall.ca>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include <glib-object.h>
#include "common.h"
#include <gio/gio.h>
#include "daemon.h"
#include <glib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

#define BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_DBUS_OBJECT (break_timer_daemon_timer_break_timer_break_dbus_object_get_type ())
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_DBUS_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_DBUS_OBJECT, BreakTimerDaemonTimerBreakTimerBreakDBusObject))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_DBUS_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_DBUS_OBJECT, BreakTimerDaemonTimerBreakTimerBreakDBusObjectClass))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_IS_TIMER_BREAK_DBUS_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_DBUS_OBJECT))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_IS_TIMER_BREAK_DBUS_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_DBUS_OBJECT))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_DBUS_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_DBUS_OBJECT, BreakTimerDaemonTimerBreakTimerBreakDBusObjectClass))

typedef struct _BreakTimerDaemonTimerBreakTimerBreakDBusObject BreakTimerDaemonTimerBreakTimerBreakDBusObject;
typedef struct _BreakTimerDaemonTimerBreakTimerBreakDBusObjectClass BreakTimerDaemonTimerBreakTimerBreakDBusObjectClass;
typedef struct _BreakTimerDaemonTimerBreakTimerBreakDBusObjectPrivate BreakTimerDaemonTimerBreakTimerBreakDBusObjectPrivate;
enum  {
	BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_DBUS_OBJECT_0_PROPERTY,
	BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_DBUS_OBJECT_NUM_PROPERTIES
};
static GParamSpec* break_timer_daemon_timer_break_timer_break_dbus_object_properties[BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_DBUS_OBJECT_NUM_PROPERTIES];

struct _BreakTimerDaemonTimerBreakTimerBreakDBusObject {
	GObject parent_instance;
	BreakTimerDaemonTimerBreakTimerBreakDBusObjectPrivate * priv;
};

struct _BreakTimerDaemonTimerBreakTimerBreakDBusObjectClass {
	GObjectClass parent_class;
};

struct _BreakTimerDaemonTimerBreakTimerBreakDBusObjectPrivate {
	BreakTimerDaemonTimerBreakTimerBreakController* break_controller;
	BreakTimerDaemonTimerBreakTimerBreakView* break_view;
};

static gint BreakTimerDaemonTimerBreakTimerBreakDBusObject_private_offset;
static gpointer break_timer_daemon_timer_break_timer_break_dbus_object_parent_class = NULL;
static BreakTimerCommonIBreakTimer_TimerBreakIface * break_timer_daemon_timer_break_timer_break_dbus_object_break_timer_common_ibreaktimer_timerbreak_parent_iface = NULL;

VALA_EXTERN GType break_timer_daemon_timer_break_timer_break_dbus_object_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint break_timer_daemon_timer_break_timer_break_dbus_object_register_object (void* object,
                                                                              GDBusConnection* connection,
                                                                              const gchar* path,
                                                                              GError** error);
VALA_EXTERN BreakTimerDaemonTimerBreakTimerBreakDBusObject* break_timer_daemon_timer_break_timer_break_dbus_object_new (BreakTimerDaemonTimerBreakTimerBreakController* break_controller,
                                                                                                            BreakTimerDaemonTimerBreakTimerBreakView* break_view);
VALA_EXTERN BreakTimerDaemonTimerBreakTimerBreakDBusObject* break_timer_daemon_timer_break_timer_break_dbus_object_construct (GType object_type,
                                                                                                                  BreakTimerDaemonTimerBreakTimerBreakController* break_controller,
                                                                                                                  BreakTimerDaemonTimerBreakTimerBreakView* break_view);
static void break_timer_daemon_timer_break_timer_break_dbus_object_real_get_status (BreakTimerCommonIBreakTimer_TimerBreak* base,
                                                                             BreakTimerCommonTimerBreakStatus* result,
                                                                             GError** error);
static void break_timer_daemon_timer_break_timer_break_dbus_object_real_activate (BreakTimerCommonIBreakTimer_TimerBreak* base,
                                                                           GError** error);
static void break_timer_daemon_timer_break_timer_break_dbus_object_finalize (GObject * obj);
static GType break_timer_daemon_timer_break_timer_break_dbus_object_get_type_once (void);
static void _dbus_break_timer_daemon_timer_break_timer_break_dbus_object_get_status (BreakTimerDaemonTimerBreakTimerBreakDBusObject* self,
                                                                              GVariant* _parameters_,
                                                                              GDBusMethodInvocation* invocation);
static void _dbus_break_timer_daemon_timer_break_timer_break_dbus_object_activate (BreakTimerDaemonTimerBreakTimerBreakDBusObject* self,
                                                                            GVariant* _parameters_,
                                                                            GDBusMethodInvocation* invocation);
static void break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_method_call (GDBusConnection* connection,
                                                                                        const gchar* sender,
                                                                                        const gchar* object_path,
                                                                                        const gchar* interface_name,
                                                                                        const gchar* method_name,
                                                                                        GVariant* parameters,
                                                                                        GDBusMethodInvocation* invocation,
                                                                                        gpointer user_data);
static GVariant* break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_get_property (GDBusConnection* connection,
                                                                                              const gchar* sender,
                                                                                              const gchar* object_path,
                                                                                              const gchar* interface_name,
                                                                                              const gchar* property_name,
                                                                                              GError** error,
                                                                                              gpointer user_data);
static gboolean break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_set_property (GDBusConnection* connection,
                                                                                             const gchar* sender,
                                                                                             const gchar* object_path,
                                                                                             const gchar* interface_name,
                                                                                             const gchar* property_name,
                                                                                             GVariant* value,
                                                                                             GError** error,
                                                                                             gpointer user_data);
static void _break_timer_daemon_timer_break_timer_break_dbus_object_unregister_object (gpointer user_data);

static const GDBusArgInfo _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_arg_info_get_status_result = {-1, "result", "(bbbiii)", NULL};
static const GDBusArgInfo * const _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_arg_info_get_status_in[] = {NULL};
static const GDBusArgInfo * const _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_arg_info_get_status_out[] = {&_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_arg_info_get_status_result, NULL};
static const GDBusMethodInfo _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_method_info_get_status = {-1, "GetStatus", (GDBusArgInfo **) (&_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_arg_info_get_status_in), (GDBusArgInfo **) (&_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_arg_info_get_status_out), NULL};
static const GDBusArgInfo * const _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_arg_info_activate_in[] = {NULL};
static const GDBusArgInfo * const _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_arg_info_activate_out[] = {NULL};
static const GDBusMethodInfo _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_method_info_activate = {-1, "Activate", (GDBusArgInfo **) (&_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_arg_info_activate_in), (GDBusArgInfo **) (&_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_arg_info_activate_out), NULL};
static const GDBusMethodInfo * const _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_method_info[] = {&_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_method_info_get_status, &_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_method_info_activate, NULL};
static const GDBusSignalInfo * const _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo * const _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_info = {-1, "org.gnome.BreakTimer.TimerBreak", (GDBusMethodInfo **) (&_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_method_info), (GDBusSignalInfo **) (&_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_signal_info), (GDBusPropertyInfo **) (&_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_property_info), NULL};
static const GDBusInterfaceVTable _break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_vtable = {break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_method_call, break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_get_property, break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_set_property};

static inline gpointer
break_timer_daemon_timer_break_timer_break_dbus_object_get_instance_private (BreakTimerDaemonTimerBreakTimerBreakDBusObject* self)
{
	return G_STRUCT_MEMBER_P (self, BreakTimerDaemonTimerBreakTimerBreakDBusObject_private_offset);
}

BreakTimerDaemonTimerBreakTimerBreakDBusObject*
break_timer_daemon_timer_break_timer_break_dbus_object_construct (GType object_type,
                                                                  BreakTimerDaemonTimerBreakTimerBreakController* break_controller,
                                                                  BreakTimerDaemonTimerBreakTimerBreakView* break_view)
{
	BreakTimerDaemonTimerBreakTimerBreakDBusObject * self = NULL;
	g_return_val_if_fail (break_controller != NULL, NULL);
	g_return_val_if_fail (break_view != NULL, NULL);
	self = (BreakTimerDaemonTimerBreakTimerBreakDBusObject*) g_object_new (object_type, NULL);
	self->priv->break_controller = break_controller;
	self->priv->break_view = break_view;
	return self;
}

BreakTimerDaemonTimerBreakTimerBreakDBusObject*
break_timer_daemon_timer_break_timer_break_dbus_object_new (BreakTimerDaemonTimerBreakTimerBreakController* break_controller,
                                                            BreakTimerDaemonTimerBreakTimerBreakView* break_view)
{
	return break_timer_daemon_timer_break_timer_break_dbus_object_construct (BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_DBUS_OBJECT, break_controller, break_view);
}

static void
break_timer_daemon_timer_break_timer_break_dbus_object_real_get_status (BreakTimerCommonIBreakTimer_TimerBreak* base,
                                                                        BreakTimerCommonTimerBreakStatus* result,
                                                                        GError** error)
{
	BreakTimerDaemonTimerBreakTimerBreakDBusObject * self;
	BreakTimerDaemonTimerBreakTimerBreakController* _tmp0_;
	BreakTimerDaemonTimerBreakTimerBreakView* _tmp1_;
	BreakTimerDaemonTimerBreakTimerBreakController* _tmp2_;
	BreakTimerDaemonTimerBreakTimerBreakController* _tmp3_;
	BreakTimerDaemonTimerBreakTimerBreakController* _tmp4_;
	BreakTimerDaemonTimerBreakTimerBreakController* _tmp5_;
	BreakTimerCommonTimerBreakStatus _tmp6_ = {0};
	self = (BreakTimerDaemonTimerBreakTimerBreakDBusObject*) base;
	_tmp0_ = self->priv->break_controller;
	_tmp1_ = self->priv->break_view;
	_tmp2_ = self->priv->break_controller;
	_tmp3_ = self->priv->break_controller;
	_tmp4_ = self->priv->break_controller;
	_tmp5_ = self->priv->break_controller;
	memset (&_tmp6_, 0, sizeof (BreakTimerCommonTimerBreakStatus));
	_tmp6_.is_enabled = break_timer_daemon_break_break_controller_is_enabled ((BreakTimerDaemonBreakBreakController*) _tmp0_);
	_tmp6_.is_focused = break_timer_daemon_ui_fragment_has_ui_focus ((BreakTimerDaemonUIFragment*) _tmp1_);
	_tmp6_.is_active = break_timer_daemon_break_break_controller_is_active ((BreakTimerDaemonBreakBreakController*) _tmp2_);
	_tmp6_.starts_in = break_timer_daemon_timer_break_timer_break_controller_starts_in (_tmp3_);
	_tmp6_.time_remaining = break_timer_daemon_timer_break_timer_break_controller_get_time_remaining (_tmp4_);
	_tmp6_.current_duration = break_timer_daemon_timer_break_timer_break_controller_get_current_duration (_tmp5_);
	*result = _tmp6_;
	return;
}

static void
break_timer_daemon_timer_break_timer_break_dbus_object_real_activate (BreakTimerCommonIBreakTimer_TimerBreak* base,
                                                                      GError** error)
{
	BreakTimerDaemonTimerBreakTimerBreakDBusObject * self;
	BreakTimerDaemonTimerBreakTimerBreakController* _tmp0_;
	self = (BreakTimerDaemonTimerBreakTimerBreakDBusObject*) base;
	_tmp0_ = self->priv->break_controller;
	break_timer_daemon_break_break_controller_activate ((BreakTimerDaemonBreakBreakController*) _tmp0_);
}

static void
break_timer_daemon_timer_break_timer_break_dbus_object_class_init (BreakTimerDaemonTimerBreakTimerBreakDBusObjectClass * klass,
                                                                   gpointer klass_data)
{
	break_timer_daemon_timer_break_timer_break_dbus_object_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &BreakTimerDaemonTimerBreakTimerBreakDBusObject_private_offset);
	G_OBJECT_CLASS (klass)->finalize = break_timer_daemon_timer_break_timer_break_dbus_object_finalize;
}

static void
break_timer_daemon_timer_break_timer_break_dbus_object_break_timer_common_ibreaktimer_timerbreak_interface_init (BreakTimerCommonIBreakTimer_TimerBreakIface * iface,
                                                                                                                 gpointer iface_data)
{
	break_timer_daemon_timer_break_timer_break_dbus_object_break_timer_common_ibreaktimer_timerbreak_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_status = (void (*) (BreakTimerCommonIBreakTimer_TimerBreak*, BreakTimerCommonTimerBreakStatus*, GError**)) break_timer_daemon_timer_break_timer_break_dbus_object_real_get_status;
	iface->activate = (void (*) (BreakTimerCommonIBreakTimer_TimerBreak*, GError**)) break_timer_daemon_timer_break_timer_break_dbus_object_real_activate;
}

static void
break_timer_daemon_timer_break_timer_break_dbus_object_instance_init (BreakTimerDaemonTimerBreakTimerBreakDBusObject * self,
                                                                      gpointer klass)
{
	self->priv = break_timer_daemon_timer_break_timer_break_dbus_object_get_instance_private (self);
}

static void
break_timer_daemon_timer_break_timer_break_dbus_object_finalize (GObject * obj)
{
	BreakTimerDaemonTimerBreakTimerBreakDBusObject * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_DBUS_OBJECT, BreakTimerDaemonTimerBreakTimerBreakDBusObject);
	G_OBJECT_CLASS (break_timer_daemon_timer_break_timer_break_dbus_object_parent_class)->finalize (obj);
}

static GType
break_timer_daemon_timer_break_timer_break_dbus_object_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BreakTimerDaemonTimerBreakTimerBreakDBusObjectClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) break_timer_daemon_timer_break_timer_break_dbus_object_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BreakTimerDaemonTimerBreakTimerBreakDBusObject), 0, (GInstanceInitFunc) break_timer_daemon_timer_break_timer_break_dbus_object_instance_init, NULL };
	static const GInterfaceInfo break_timer_common_ibreaktimer_timerbreak_info = { (GInterfaceInitFunc) break_timer_daemon_timer_break_timer_break_dbus_object_break_timer_common_ibreaktimer_timerbreak_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType break_timer_daemon_timer_break_timer_break_dbus_object_type_id;
	break_timer_daemon_timer_break_timer_break_dbus_object_type_id = g_type_register_static (G_TYPE_OBJECT, "BreakTimerDaemonTimerBreakTimerBreakDBusObject", &g_define_type_info, 0);
	g_type_add_interface_static (break_timer_daemon_timer_break_timer_break_dbus_object_type_id, BREAK_TIMER_COMMON_TYPE_IBREAKTIMER_TIMERBREAK, &break_timer_common_ibreaktimer_timerbreak_info);
	g_type_set_qdata (break_timer_daemon_timer_break_timer_break_dbus_object_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) break_timer_daemon_timer_break_timer_break_dbus_object_register_object);
	BreakTimerDaemonTimerBreakTimerBreakDBusObject_private_offset = g_type_add_instance_private (break_timer_daemon_timer_break_timer_break_dbus_object_type_id, sizeof (BreakTimerDaemonTimerBreakTimerBreakDBusObjectPrivate));
	return break_timer_daemon_timer_break_timer_break_dbus_object_type_id;
}

GType
break_timer_daemon_timer_break_timer_break_dbus_object_get_type (void)
{
	static volatile gsize break_timer_daemon_timer_break_timer_break_dbus_object_type_id__once = 0;
	if (g_once_init_enter (&break_timer_daemon_timer_break_timer_break_dbus_object_type_id__once)) {
		GType break_timer_daemon_timer_break_timer_break_dbus_object_type_id;
		break_timer_daemon_timer_break_timer_break_dbus_object_type_id = break_timer_daemon_timer_break_timer_break_dbus_object_get_type_once ();
		g_once_init_leave (&break_timer_daemon_timer_break_timer_break_dbus_object_type_id__once, break_timer_daemon_timer_break_timer_break_dbus_object_type_id);
	}
	return break_timer_daemon_timer_break_timer_break_dbus_object_type_id__once;
}

static void
_dbus_break_timer_daemon_timer_break_timer_break_dbus_object_get_status (BreakTimerDaemonTimerBreakTimerBreakDBusObject* self,
                                                                         GVariant* _parameters_,
                                                                         GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	BreakTimerCommonTimerBreakStatus result = {0};
	GVariantBuilder _tmp10_;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	break_timer_common_ibreaktimer_timerbreak_get_status (self, &result, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_init (&_tmp10_, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_tmp10_, g_variant_new_boolean (result.is_enabled));
	g_variant_builder_add_value (&_tmp10_, g_variant_new_boolean (result.is_focused));
	g_variant_builder_add_value (&_tmp10_, g_variant_new_boolean (result.is_active));
	g_variant_builder_add_value (&_tmp10_, g_variant_new_int32 (result.starts_in));
	g_variant_builder_add_value (&_tmp10_, g_variant_new_int32 (result.time_remaining));
	g_variant_builder_add_value (&_tmp10_, g_variant_new_int32 (result.current_duration));
	g_variant_builder_add_value (&_reply_builder, g_variant_builder_end (&_tmp10_));
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_break_timer_daemon_timer_break_timer_break_dbus_object_activate (BreakTimerDaemonTimerBreakTimerBreakDBusObject* self,
                                                                       GVariant* _parameters_,
                                                                       GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	break_timer_common_ibreaktimer_timerbreak_activate (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_method_call (GDBusConnection* connection,
                                                                                   const gchar* sender,
                                                                                   const gchar* object_path,
                                                                                   const gchar* interface_name,
                                                                                   const gchar* method_name,
                                                                                   GVariant* parameters,
                                                                                   GDBusMethodInvocation* invocation,
                                                                                   gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "GetStatus") == 0) {
		_dbus_break_timer_daemon_timer_break_timer_break_dbus_object_get_status (object, parameters, invocation);
	} else if (strcmp (method_name, "Activate") == 0) {
		_dbus_break_timer_daemon_timer_break_timer_break_dbus_object_activate (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}

static GVariant*
break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_get_property (GDBusConnection* connection,
                                                                                    const gchar* sender,
                                                                                    const gchar* object_path,
                                                                                    const gchar* interface_name,
                                                                                    const gchar* property_name,
                                                                                    GError** error,
                                                                                    gpointer user_data)
{
	return NULL;
}

static gboolean
break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_set_property (GDBusConnection* connection,
                                                                                    const gchar* sender,
                                                                                    const gchar* object_path,
                                                                                    const gchar* interface_name,
                                                                                    const gchar* property_name,
                                                                                    GVariant* value,
                                                                                    GError** error,
                                                                                    gpointer user_data)
{
	return FALSE;
}

guint
break_timer_daemon_timer_break_timer_break_dbus_object_register_object (gpointer object,
                                                                        GDBusConnection* connection,
                                                                        const gchar* path,
                                                                        GError** error)
{
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_info), &_break_timer_daemon_timer_break_timer_break_dbus_object_dbus_interface_vtable, data, _break_timer_daemon_timer_break_timer_break_dbus_object_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}

static void
_break_timer_daemon_timer_break_timer_break_dbus_object_unregister_object (gpointer user_data)
{
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}

