/* settings.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __SRC_SETTINGS_SETTINGS_H__
#define __SRC_SETTINGS_SETTINGS_H__

#include <adwaita.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gio/gio.h>
#include "common.h"
#include <float.h>
#include <math.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define BREAK_TIMER_SETTINGS_WIDGETS_CIRCLE_COUNTER_LINE_WIDTH 5.0
#define BREAK_TIMER_SETTINGS_WIDGETS_CIRCLE_COUNTER_DEFAULT_RADIUS 48

#define BREAK_TIMER_SETTINGS_TYPE_APPLICATION (break_timer_settings_application_get_type ())
#define BREAK_TIMER_SETTINGS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_TYPE_APPLICATION, BreakTimerSettingsApplication))
#define BREAK_TIMER_SETTINGS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_TYPE_APPLICATION, BreakTimerSettingsApplicationClass))
#define BREAK_TIMER_SETTINGS_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_TYPE_APPLICATION))
#define BREAK_TIMER_SETTINGS_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_TYPE_APPLICATION))
#define BREAK_TIMER_SETTINGS_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_TYPE_APPLICATION, BreakTimerSettingsApplicationClass))

typedef struct _BreakTimerSettingsApplication BreakTimerSettingsApplication;
typedef struct _BreakTimerSettingsApplicationClass BreakTimerSettingsApplicationClass;
typedef struct _BreakTimerSettingsApplicationPrivate BreakTimerSettingsApplicationPrivate;

#define BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_INFO_WIDGET (break_timer_settings_break_break_info_widget_get_type ())
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_INFO_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_INFO_WIDGET, BreakTimerSettingsBreakBreakInfoWidget))
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_INFO_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_INFO_WIDGET, BreakTimerSettingsBreakBreakInfoWidgetClass))
#define BREAK_TIMER_SETTINGS_BREAK_IS_BREAK_INFO_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_INFO_WIDGET))
#define BREAK_TIMER_SETTINGS_BREAK_IS_BREAK_INFO_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_INFO_WIDGET))
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_INFO_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_INFO_WIDGET, BreakTimerSettingsBreakBreakInfoWidgetClass))

typedef struct _BreakTimerSettingsBreakBreakInfoWidget BreakTimerSettingsBreakBreakInfoWidget;
typedef struct _BreakTimerSettingsBreakBreakInfoWidgetClass BreakTimerSettingsBreakBreakInfoWidgetClass;
typedef struct _BreakTimerSettingsBreakBreakInfoWidgetPrivate BreakTimerSettingsBreakBreakInfoWidgetPrivate;

#define BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_TYPE (break_timer_settings_break_break_type_get_type ())
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_TYPE, BreakTimerSettingsBreakBreakType))
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_TYPE, BreakTimerSettingsBreakBreakTypeClass))
#define BREAK_TIMER_SETTINGS_BREAK_IS_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_TYPE))
#define BREAK_TIMER_SETTINGS_BREAK_IS_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_TYPE))
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_TYPE, BreakTimerSettingsBreakBreakTypeClass))

typedef struct _BreakTimerSettingsBreakBreakType BreakTimerSettingsBreakBreakType;
typedef struct _BreakTimerSettingsBreakBreakTypeClass BreakTimerSettingsBreakBreakTypeClass;

#define BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_SETTINGS_WIDGET (break_timer_settings_break_break_settings_widget_get_type ())
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_SETTINGS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_SETTINGS_WIDGET, BreakTimerSettingsBreakBreakSettingsWidget))
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_SETTINGS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_SETTINGS_WIDGET, BreakTimerSettingsBreakBreakSettingsWidgetClass))
#define BREAK_TIMER_SETTINGS_BREAK_IS_BREAK_SETTINGS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_SETTINGS_WIDGET))
#define BREAK_TIMER_SETTINGS_BREAK_IS_BREAK_SETTINGS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_SETTINGS_WIDGET))
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_SETTINGS_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_SETTINGS_WIDGET, BreakTimerSettingsBreakBreakSettingsWidgetClass))

typedef struct _BreakTimerSettingsBreakBreakSettingsWidget BreakTimerSettingsBreakBreakSettingsWidget;
typedef struct _BreakTimerSettingsBreakBreakSettingsWidgetClass BreakTimerSettingsBreakBreakSettingsWidgetClass;
typedef struct _BreakTimerSettingsBreakBreakSettingsWidgetPrivate BreakTimerSettingsBreakBreakSettingsWidgetPrivate;

#define BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_STATUS_WIDGET (break_timer_settings_break_break_status_widget_get_type ())
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_STATUS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_STATUS_WIDGET, BreakTimerSettingsBreakBreakStatusWidget))
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_STATUS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_STATUS_WIDGET, BreakTimerSettingsBreakBreakStatusWidgetClass))
#define BREAK_TIMER_SETTINGS_BREAK_IS_BREAK_STATUS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_STATUS_WIDGET))
#define BREAK_TIMER_SETTINGS_BREAK_IS_BREAK_STATUS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_STATUS_WIDGET))
#define BREAK_TIMER_SETTINGS_BREAK_BREAK_STATUS_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_BREAK_TYPE_BREAK_STATUS_WIDGET, BreakTimerSettingsBreakBreakStatusWidgetClass))

typedef struct _BreakTimerSettingsBreakBreakStatusWidget BreakTimerSettingsBreakBreakStatusWidget;
typedef struct _BreakTimerSettingsBreakBreakStatusWidgetClass BreakTimerSettingsBreakBreakStatusWidgetClass;
typedef struct _BreakTimerSettingsBreakBreakStatusWidgetPrivate BreakTimerSettingsBreakBreakStatusWidgetPrivate;
typedef struct _BreakTimerSettingsBreakBreakTypePrivate BreakTimerSettingsBreakBreakTypePrivate;

#define BREAK_TIMER_SETTINGS_TYPE_BREAK_MANAGER (break_timer_settings_break_manager_get_type ())
#define BREAK_TIMER_SETTINGS_BREAK_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_TYPE_BREAK_MANAGER, BreakTimerSettingsBreakManager))
#define BREAK_TIMER_SETTINGS_BREAK_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_TYPE_BREAK_MANAGER, BreakTimerSettingsBreakManagerClass))
#define BREAK_TIMER_SETTINGS_IS_BREAK_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_TYPE_BREAK_MANAGER))
#define BREAK_TIMER_SETTINGS_IS_BREAK_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_TYPE_BREAK_MANAGER))
#define BREAK_TIMER_SETTINGS_BREAK_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_TYPE_BREAK_MANAGER, BreakTimerSettingsBreakManagerClass))

typedef struct _BreakTimerSettingsBreakManager BreakTimerSettingsBreakManager;
typedef struct _BreakTimerSettingsBreakManagerClass BreakTimerSettingsBreakManagerClass;
typedef struct _BreakTimerSettingsBreakManagerPrivate BreakTimerSettingsBreakManagerPrivate;
typedef enum  {
	BREAK_TIMER_SETTINGS_BREAK_MANAGER_PERMISSIONS_ERROR_NONE = 0,
	BREAK_TIMER_SETTINGS_BREAK_MANAGER_PERMISSIONS_ERROR_AUTOSTART_NOT_ALLOWED = 1 << 0,
	BREAK_TIMER_SETTINGS_BREAK_MANAGER_PERMISSIONS_ERROR_BACKGROUND_NOT_ALLOWED = 1 << 1
} BreakTimerSettingsBreakManagerPermissionsError;

#define BREAK_TIMER_SETTINGS_BREAK_MANAGER_TYPE_PERMISSIONS_ERROR (break_timer_settings_break_manager_permissions_error_get_type ())

#define BREAK_TIMER_SETTINGS_TYPE_BREAK_SETTINGS_DIALOG (break_timer_settings_break_settings_dialog_get_type ())
#define BREAK_TIMER_SETTINGS_BREAK_SETTINGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_TYPE_BREAK_SETTINGS_DIALOG, BreakTimerSettingsBreakSettingsDialog))
#define BREAK_TIMER_SETTINGS_BREAK_SETTINGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_TYPE_BREAK_SETTINGS_DIALOG, BreakTimerSettingsBreakSettingsDialogClass))
#define BREAK_TIMER_SETTINGS_IS_BREAK_SETTINGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_TYPE_BREAK_SETTINGS_DIALOG))
#define BREAK_TIMER_SETTINGS_IS_BREAK_SETTINGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_TYPE_BREAK_SETTINGS_DIALOG))
#define BREAK_TIMER_SETTINGS_BREAK_SETTINGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_TYPE_BREAK_SETTINGS_DIALOG, BreakTimerSettingsBreakSettingsDialogClass))

typedef struct _BreakTimerSettingsBreakSettingsDialog BreakTimerSettingsBreakSettingsDialog;
typedef struct _BreakTimerSettingsBreakSettingsDialogClass BreakTimerSettingsBreakSettingsDialogClass;
typedef struct _BreakTimerSettingsBreakSettingsDialogPrivate BreakTimerSettingsBreakSettingsDialogPrivate;

#define BREAK_TIMER_SETTINGS_TYPE_MAIN_WINDOW (break_timer_settings_main_window_get_type ())
#define BREAK_TIMER_SETTINGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_TYPE_MAIN_WINDOW, BreakTimerSettingsMainWindow))
#define BREAK_TIMER_SETTINGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_TYPE_MAIN_WINDOW, BreakTimerSettingsMainWindowClass))
#define BREAK_TIMER_SETTINGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_TYPE_MAIN_WINDOW))
#define BREAK_TIMER_SETTINGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_TYPE_MAIN_WINDOW))
#define BREAK_TIMER_SETTINGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_TYPE_MAIN_WINDOW, BreakTimerSettingsMainWindowClass))

typedef struct _BreakTimerSettingsMainWindow BreakTimerSettingsMainWindow;
typedef struct _BreakTimerSettingsMainWindowClass BreakTimerSettingsMainWindowClass;
typedef struct _BreakTimerSettingsMainWindowPrivate BreakTimerSettingsMainWindowPrivate;

#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE (break_timer_settings_timer_break_timer_break_type_get_type ())
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TIMER_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE, BreakTimerSettingsTimerBreakTimerBreakType))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TIMER_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE, BreakTimerSettingsTimerBreakTimerBreakTypeClass))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_IS_TIMER_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_IS_TIMER_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TIMER_BREAK_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE, BreakTimerSettingsTimerBreakTimerBreakTypeClass))

typedef struct _BreakTimerSettingsTimerBreakTimerBreakType BreakTimerSettingsTimerBreakTimerBreakType;
typedef struct _BreakTimerSettingsTimerBreakTimerBreakTypeClass BreakTimerSettingsTimerBreakTimerBreakTypeClass;
typedef struct _BreakTimerSettingsTimerBreakTimerBreakTypePrivate BreakTimerSettingsTimerBreakTimerBreakTypePrivate;

#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_BREAK_TIME_OPTION (break_timer_settings_timer_break_break_time_option_get_type ())
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_BREAK_TIME_OPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_BREAK_TIME_OPTION, BreakTimerSettingsTimerBreakBreakTimeOption))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_BREAK_TIME_OPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_BREAK_TIME_OPTION, BreakTimerSettingsTimerBreakBreakTimeOptionClass))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_IS_BREAK_TIME_OPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_BREAK_TIME_OPTION))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_IS_BREAK_TIME_OPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_BREAK_TIME_OPTION))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_BREAK_TIME_OPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_BREAK_TIME_OPTION, BreakTimerSettingsTimerBreakBreakTimeOptionClass))

typedef struct _BreakTimerSettingsTimerBreakBreakTimeOption BreakTimerSettingsTimerBreakBreakTimeOption;
typedef struct _BreakTimerSettingsTimerBreakBreakTimeOptionClass BreakTimerSettingsTimerBreakBreakTimeOptionClass;

#define BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE (break_timer_settings_micro_break_micro_break_type_get_type ())
#define BREAK_TIMER_SETTINGS_MICRO_BREAK_MICRO_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE, BreakTimerSettingsMicroBreakMicroBreakType))
#define BREAK_TIMER_SETTINGS_MICRO_BREAK_MICRO_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE, BreakTimerSettingsMicroBreakMicroBreakTypeClass))
#define BREAK_TIMER_SETTINGS_MICRO_BREAK_IS_MICRO_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE))
#define BREAK_TIMER_SETTINGS_MICRO_BREAK_IS_MICRO_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE))
#define BREAK_TIMER_SETTINGS_MICRO_BREAK_MICRO_BREAK_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE, BreakTimerSettingsMicroBreakMicroBreakTypeClass))

typedef struct _BreakTimerSettingsMicroBreakMicroBreakType BreakTimerSettingsMicroBreakMicroBreakType;
typedef struct _BreakTimerSettingsMicroBreakMicroBreakTypeClass BreakTimerSettingsMicroBreakMicroBreakTypeClass;
typedef struct _BreakTimerSettingsMicroBreakMicroBreakTypePrivate BreakTimerSettingsMicroBreakMicroBreakTypePrivate;

#define BREAK_TIMER_SETTINGS_REST_BREAK_TYPE_REST_BREAK_TYPE (break_timer_settings_rest_break_rest_break_type_get_type ())
#define BREAK_TIMER_SETTINGS_REST_BREAK_REST_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_REST_BREAK_TYPE_REST_BREAK_TYPE, BreakTimerSettingsRestBreakRestBreakType))
#define BREAK_TIMER_SETTINGS_REST_BREAK_REST_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_REST_BREAK_TYPE_REST_BREAK_TYPE, BreakTimerSettingsRestBreakRestBreakTypeClass))
#define BREAK_TIMER_SETTINGS_REST_BREAK_IS_REST_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_REST_BREAK_TYPE_REST_BREAK_TYPE))
#define BREAK_TIMER_SETTINGS_REST_BREAK_IS_REST_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_REST_BREAK_TYPE_REST_BREAK_TYPE))
#define BREAK_TIMER_SETTINGS_REST_BREAK_REST_BREAK_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_REST_BREAK_TYPE_REST_BREAK_TYPE, BreakTimerSettingsRestBreakRestBreakTypeClass))

typedef struct _BreakTimerSettingsRestBreakRestBreakType BreakTimerSettingsRestBreakRestBreakType;
typedef struct _BreakTimerSettingsRestBreakRestBreakTypeClass BreakTimerSettingsRestBreakRestBreakTypeClass;
typedef struct _BreakTimerSettingsRestBreakRestBreakTypePrivate BreakTimerSettingsRestBreakRestBreakTypePrivate;

#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_SETTINGS_WIDGET (break_timer_settings_timer_break_timer_break_settings_widget_get_type ())
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TIMER_BREAK_SETTINGS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_SETTINGS_WIDGET, BreakTimerSettingsTimerBreakTimerBreakSettingsWidget))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TIMER_BREAK_SETTINGS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_SETTINGS_WIDGET, BreakTimerSettingsTimerBreakTimerBreakSettingsWidgetClass))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_IS_TIMER_BREAK_SETTINGS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_SETTINGS_WIDGET))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_IS_TIMER_BREAK_SETTINGS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_SETTINGS_WIDGET))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TIMER_BREAK_SETTINGS_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_SETTINGS_WIDGET, BreakTimerSettingsTimerBreakTimerBreakSettingsWidgetClass))

typedef struct _BreakTimerSettingsTimerBreakTimerBreakSettingsWidget BreakTimerSettingsTimerBreakTimerBreakSettingsWidget;
typedef struct _BreakTimerSettingsTimerBreakTimerBreakSettingsWidgetClass BreakTimerSettingsTimerBreakTimerBreakSettingsWidgetClass;
typedef struct _BreakTimerSettingsTimerBreakTimerBreakSettingsWidgetPrivate BreakTimerSettingsTimerBreakTimerBreakSettingsWidgetPrivate;

#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_STATUS_WIDGET (break_timer_settings_timer_break_timer_break_status_widget_get_type ())
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TIMER_BREAK_STATUS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_STATUS_WIDGET, BreakTimerSettingsTimerBreakTimerBreakStatusWidget))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TIMER_BREAK_STATUS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_STATUS_WIDGET, BreakTimerSettingsTimerBreakTimerBreakStatusWidgetClass))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_IS_TIMER_BREAK_STATUS_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_STATUS_WIDGET))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_IS_TIMER_BREAK_STATUS_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_STATUS_WIDGET))
#define BREAK_TIMER_SETTINGS_TIMER_BREAK_TIMER_BREAK_STATUS_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_TIMER_BREAK_TYPE_TIMER_BREAK_STATUS_WIDGET, BreakTimerSettingsTimerBreakTimerBreakStatusWidgetClass))

typedef struct _BreakTimerSettingsTimerBreakTimerBreakStatusWidget BreakTimerSettingsTimerBreakTimerBreakStatusWidget;
typedef struct _BreakTimerSettingsTimerBreakTimerBreakStatusWidgetClass BreakTimerSettingsTimerBreakTimerBreakStatusWidgetClass;
typedef struct _BreakTimerSettingsTimerBreakTimerBreakStatusWidgetPrivate BreakTimerSettingsTimerBreakTimerBreakStatusWidgetPrivate;
typedef struct _BreakTimerSettingsTimerBreakBreakTimeOptionPrivate BreakTimerSettingsTimerBreakBreakTimeOptionPrivate;

#define BREAK_TIMER_SETTINGS_WIDGETS_TYPE_CIRCLE_COUNTER (break_timer_settings_widgets_circle_counter_get_type ())
#define BREAK_TIMER_SETTINGS_WIDGETS_CIRCLE_COUNTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_CIRCLE_COUNTER, BreakTimerSettingsWidgetsCircleCounter))
#define BREAK_TIMER_SETTINGS_WIDGETS_CIRCLE_COUNTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_CIRCLE_COUNTER, BreakTimerSettingsWidgetsCircleCounterClass))
#define BREAK_TIMER_SETTINGS_WIDGETS_IS_CIRCLE_COUNTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_CIRCLE_COUNTER))
#define BREAK_TIMER_SETTINGS_WIDGETS_IS_CIRCLE_COUNTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_CIRCLE_COUNTER))
#define BREAK_TIMER_SETTINGS_WIDGETS_CIRCLE_COUNTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_CIRCLE_COUNTER, BreakTimerSettingsWidgetsCircleCounterClass))

typedef struct _BreakTimerSettingsWidgetsCircleCounter BreakTimerSettingsWidgetsCircleCounter;
typedef struct _BreakTimerSettingsWidgetsCircleCounterClass BreakTimerSettingsWidgetsCircleCounterClass;
typedef struct _BreakTimerSettingsWidgetsCircleCounterPrivate BreakTimerSettingsWidgetsCircleCounterPrivate;
typedef enum  {
	BREAK_TIMER_SETTINGS_WIDGETS_CIRCLE_COUNTER_DIRECTION_COUNT_DOWN,
	BREAK_TIMER_SETTINGS_WIDGETS_CIRCLE_COUNTER_DIRECTION_COUNT_UP
} BreakTimerSettingsWidgetsCircleCounterDirection;

#define BREAK_TIMER_SETTINGS_WIDGETS_CIRCLE_COUNTER_TYPE_DIRECTION (break_timer_settings_widgets_circle_counter_direction_get_type ())

#define BREAK_TIMER_SETTINGS_WIDGETS_TYPE_OVERLAY_ARROW (break_timer_settings_widgets_overlay_arrow_get_type ())
#define BREAK_TIMER_SETTINGS_WIDGETS_OVERLAY_ARROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_OVERLAY_ARROW, BreakTimerSettingsWidgetsOverlayArrow))
#define BREAK_TIMER_SETTINGS_WIDGETS_OVERLAY_ARROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_OVERLAY_ARROW, BreakTimerSettingsWidgetsOverlayArrowClass))
#define BREAK_TIMER_SETTINGS_WIDGETS_IS_OVERLAY_ARROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_OVERLAY_ARROW))
#define BREAK_TIMER_SETTINGS_WIDGETS_IS_OVERLAY_ARROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_OVERLAY_ARROW))
#define BREAK_TIMER_SETTINGS_WIDGETS_OVERLAY_ARROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_OVERLAY_ARROW, BreakTimerSettingsWidgetsOverlayArrowClass))

typedef struct _BreakTimerSettingsWidgetsOverlayArrow BreakTimerSettingsWidgetsOverlayArrow;
typedef struct _BreakTimerSettingsWidgetsOverlayArrowClass BreakTimerSettingsWidgetsOverlayArrowClass;
typedef struct _BreakTimerSettingsWidgetsOverlayArrowPrivate BreakTimerSettingsWidgetsOverlayArrowPrivate;

#define BREAK_TIMER_SETTINGS_WIDGETS_TYPE_TIME_CHOOSER_ROW (break_timer_settings_widgets_time_chooser_row_get_type ())
#define BREAK_TIMER_SETTINGS_WIDGETS_TIME_CHOOSER_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_TIME_CHOOSER_ROW, BreakTimerSettingsWidgetsTimeChooserRow))
#define BREAK_TIMER_SETTINGS_WIDGETS_TIME_CHOOSER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_TIME_CHOOSER_ROW, BreakTimerSettingsWidgetsTimeChooserRowClass))
#define BREAK_TIMER_SETTINGS_WIDGETS_IS_TIME_CHOOSER_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_TIME_CHOOSER_ROW))
#define BREAK_TIMER_SETTINGS_WIDGETS_IS_TIME_CHOOSER_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_TIME_CHOOSER_ROW))
#define BREAK_TIMER_SETTINGS_WIDGETS_TIME_CHOOSER_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_TIME_CHOOSER_ROW, BreakTimerSettingsWidgetsTimeChooserRowClass))

typedef struct _BreakTimerSettingsWidgetsTimeChooserRow BreakTimerSettingsWidgetsTimeChooserRow;
typedef struct _BreakTimerSettingsWidgetsTimeChooserRowClass BreakTimerSettingsWidgetsTimeChooserRowClass;
typedef struct _BreakTimerSettingsWidgetsTimeChooserRowPrivate BreakTimerSettingsWidgetsTimeChooserRowPrivate;

#define BREAK_TIMER_SETTINGS_WIDGETS_TYPE_PROPERTY_TRANSITION (break_timer_settings_widgets_property_transition_get_type ())
#define BREAK_TIMER_SETTINGS_WIDGETS_PROPERTY_TRANSITION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_PROPERTY_TRANSITION, BreakTimerSettingsWidgetsPropertyTransition))
#define BREAK_TIMER_SETTINGS_WIDGETS_PROPERTY_TRANSITION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_PROPERTY_TRANSITION, BreakTimerSettingsWidgetsPropertyTransitionClass))
#define BREAK_TIMER_SETTINGS_WIDGETS_IS_PROPERTY_TRANSITION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_PROPERTY_TRANSITION))
#define BREAK_TIMER_SETTINGS_WIDGETS_IS_PROPERTY_TRANSITION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_PROPERTY_TRANSITION))
#define BREAK_TIMER_SETTINGS_WIDGETS_PROPERTY_TRANSITION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_SETTINGS_WIDGETS_TYPE_PROPERTY_TRANSITION, BreakTimerSettingsWidgetsPropertyTransitionClass))

typedef struct _BreakTimerSettingsWidgetsPropertyTransition BreakTimerSettingsWidgetsPropertyTransition;
typedef struct _BreakTimerSettingsWidgetsPropertyTransitionClass BreakTimerSettingsWidgetsPropertyTransitionClass;
typedef struct _BreakTimerSettingsWidgetsPropertyTransitionPrivate BreakTimerSettingsWidgetsPropertyTransitionPrivate;
typedef enum  {
	BREAK_TIMER_SETTINGS_WIDGETS_PROPERTY_TRANSITION_EASING_FUNCTION_LINEAR,
	BREAK_TIMER_SETTINGS_WIDGETS_PROPERTY_TRANSITION_EASING_FUNCTION_EASE_OUT_CUBIC
} BreakTimerSettingsWidgetsPropertyTransitionEasingFunction;

#define BREAK_TIMER_SETTINGS_WIDGETS_PROPERTY_TRANSITION_TYPE_EASING_FUNCTION (break_timer_settings_widgets_property_transition_easing_function_get_type ())
typedef void (*BreakTimerSettingsWidgetsPropertyTransitionCalculateValue) (GValue* start_value, GValue* end_value, gdouble ease, GValue* result, gpointer user_data);

struct _BreakTimerSettingsApplication {
	AdwApplication parent_instance;
	BreakTimerSettingsApplicationPrivate * priv;
};

struct _BreakTimerSettingsApplicationClass {
	AdwApplicationClass parent_class;
};

struct _BreakTimerSettingsBreakBreakInfoWidget {
	GtkBox parent_instance;
	BreakTimerSettingsBreakBreakInfoWidgetPrivate * priv;
};

struct _BreakTimerSettingsBreakBreakInfoWidgetClass {
	GtkBoxClass parent_class;
};

struct _BreakTimerSettingsBreakBreakSettingsWidget {
	AdwPreferencesGroup parent_instance;
	BreakTimerSettingsBreakBreakSettingsWidgetPrivate * priv;
};

struct _BreakTimerSettingsBreakBreakSettingsWidgetClass {
	AdwPreferencesGroupClass parent_class;
};

struct _BreakTimerSettingsBreakBreakStatusWidget {
	GtkBox parent_instance;
	BreakTimerSettingsBreakBreakStatusWidgetPrivate * priv;
};

struct _BreakTimerSettingsBreakBreakStatusWidgetClass {
	GtkBoxClass parent_class;
};

struct _BreakTimerSettingsBreakBreakType {
	GObject parent_instance;
	BreakTimerSettingsBreakBreakTypePrivate * priv;
	GSettings* settings;
};

struct _BreakTimerSettingsBreakBreakTypeClass {
	GObjectClass parent_class;
	gboolean (*init) (BreakTimerSettingsBreakBreakType* self, GCancellable* cancellable, GError** error);
	BreakTimerSettingsBreakBreakInfoWidget* (*create_info_widget) (BreakTimerSettingsBreakBreakType* self);
	BreakTimerSettingsBreakBreakStatusWidget* (*create_status_widget) (BreakTimerSettingsBreakBreakType* self);
	BreakTimerSettingsBreakBreakSettingsWidget* (*create_settings_widget) (BreakTimerSettingsBreakBreakType* self);
};

struct _BreakTimerSettingsBreakManager {
	GObject parent_instance;
	BreakTimerSettingsBreakManagerPrivate * priv;
};

struct _BreakTimerSettingsBreakManagerClass {
	GObjectClass parent_class;
};

struct _BreakTimerSettingsBreakSettingsDialog {
	AdwPreferencesWindow parent_instance;
	BreakTimerSettingsBreakSettingsDialogPrivate * priv;
};

struct _BreakTimerSettingsBreakSettingsDialogClass {
	AdwPreferencesWindowClass parent_class;
};

struct _BreakTimerSettingsMainWindow {
	AdwApplicationWindow parent_instance;
	BreakTimerSettingsMainWindowPrivate * priv;
};

struct _BreakTimerSettingsMainWindowClass {
	AdwApplicationWindowClass parent_class;
};

struct _BreakTimerSettingsTimerBreakTimerBreakType {
	BreakTimerSettingsBreakBreakType parent_instance;
	BreakTimerSettingsTimerBreakTimerBreakTypePrivate * priv;
	BreakTimerSettingsTimerBreakBreakTimeOption** interval_options;
	gint interval_options_length1;
	BreakTimerSettingsTimerBreakBreakTimeOption** duration_options;
	gint duration_options_length1;
};

struct _BreakTimerSettingsTimerBreakTimerBreakTypeClass {
	BreakTimerSettingsBreakBreakTypeClass parent_class;
};

struct _BreakTimerSettingsMicroBreakMicroBreakType {
	BreakTimerSettingsTimerBreakTimerBreakType parent_instance;
	BreakTimerSettingsMicroBreakMicroBreakTypePrivate * priv;
};

struct _BreakTimerSettingsMicroBreakMicroBreakTypeClass {
	BreakTimerSettingsTimerBreakTimerBreakTypeClass parent_class;
};

struct _BreakTimerSettingsRestBreakRestBreakType {
	BreakTimerSettingsTimerBreakTimerBreakType parent_instance;
	BreakTimerSettingsRestBreakRestBreakTypePrivate * priv;
};

struct _BreakTimerSettingsRestBreakRestBreakTypeClass {
	BreakTimerSettingsTimerBreakTimerBreakTypeClass parent_class;
};

struct _BreakTimerSettingsTimerBreakTimerBreakSettingsWidget {
	BreakTimerSettingsBreakBreakSettingsWidget parent_instance;
	BreakTimerSettingsTimerBreakTimerBreakSettingsWidgetPrivate * priv;
};

struct _BreakTimerSettingsTimerBreakTimerBreakSettingsWidgetClass {
	BreakTimerSettingsBreakBreakSettingsWidgetClass parent_class;
};

struct _BreakTimerSettingsTimerBreakTimerBreakStatusWidget {
	BreakTimerSettingsBreakBreakStatusWidget parent_instance;
	BreakTimerSettingsTimerBreakTimerBreakStatusWidgetPrivate * priv;
};

struct _BreakTimerSettingsTimerBreakTimerBreakStatusWidgetClass {
	BreakTimerSettingsBreakBreakStatusWidgetClass parent_class;
};

struct _BreakTimerSettingsTimerBreakBreakTimeOption {
	GObject parent_instance;
	BreakTimerSettingsTimerBreakBreakTimeOptionPrivate * priv;
};

struct _BreakTimerSettingsTimerBreakBreakTimeOptionClass {
	GObjectClass parent_class;
};

struct _BreakTimerSettingsWidgetsCircleCounter {
	GtkWidget parent_instance;
	BreakTimerSettingsWidgetsCircleCounterPrivate * priv;
};

struct _BreakTimerSettingsWidgetsCircleCounterClass {
	GtkWidgetClass parent_class;
};

struct _BreakTimerSettingsWidgetsOverlayArrow {
	GtkDrawingArea parent_instance;
	BreakTimerSettingsWidgetsOverlayArrowPrivate * priv;
};

struct _BreakTimerSettingsWidgetsOverlayArrowClass {
	GtkDrawingAreaClass parent_class;
};

struct _BreakTimerSettingsWidgetsTimeChooserRow {
	AdwComboRow parent_instance;
	BreakTimerSettingsWidgetsTimeChooserRowPrivate * priv;
};

struct _BreakTimerSettingsWidgetsTimeChooserRowClass {
	AdwComboRowClass parent_class;
};

struct _BreakTimerSettingsWidgetsPropertyTransition {
	GObject parent_instance;
	BreakTimerSettingsWidgetsPropertyTransitionPrivate * priv;
};

struct _BreakTimerSettingsWidgetsPropertyTransitionClass {
	GObjectClass parent_class;
};

VALA_EXTERN GType break_timer_settings_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsApplication, g_object_unref)
VALA_EXTERN BreakTimerSettingsApplication* break_timer_settings_application_new (void);
VALA_EXTERN BreakTimerSettingsApplication* break_timer_settings_application_construct (GType object_type);
VALA_EXTERN GType break_timer_settings_break_break_info_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsBreakBreakInfoWidget, g_object_unref)
VALA_EXTERN GType break_timer_settings_break_break_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsBreakBreakType, g_object_unref)
VALA_EXTERN BreakTimerSettingsBreakBreakInfoWidget* break_timer_settings_break_break_info_widget_construct (GType object_type,
                                                                                                BreakTimerSettingsBreakBreakType* break_type,
                                                                                                const gchar* title);
VALA_EXTERN void break_timer_settings_break_break_info_widget_set_heading (BreakTimerSettingsBreakBreakInfoWidget* self,
                                                               const gchar* heading);
VALA_EXTERN void break_timer_settings_break_break_info_widget_set_description (BreakTimerSettingsBreakBreakInfoWidget* self,
                                                                   const gchar* description);
VALA_EXTERN void break_timer_settings_break_break_info_widget_set_detail (BreakTimerSettingsBreakBreakInfoWidget* self,
                                                              const gchar* detail);
VALA_EXTERN BreakTimerSettingsBreakBreakType* break_timer_settings_break_break_info_widget_get_break_type (BreakTimerSettingsBreakBreakInfoWidget* self);
VALA_EXTERN const gchar* break_timer_settings_break_break_info_widget_get_title (BreakTimerSettingsBreakBreakInfoWidget* self);
VALA_EXTERN GType break_timer_settings_break_break_settings_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsBreakBreakSettingsWidget, g_object_unref)
VALA_EXTERN BreakTimerSettingsBreakBreakSettingsWidget* break_timer_settings_break_break_settings_widget_construct (GType object_type,
                                                                                                        const gchar* title,
                                                                                                        const gchar* description);
VALA_EXTERN GType break_timer_settings_break_break_status_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsBreakBreakStatusWidget, g_object_unref)
VALA_EXTERN BreakTimerSettingsBreakBreakStatusWidget* break_timer_settings_break_break_status_widget_construct (GType object_type,
                                                                                                    BreakTimerSettingsBreakBreakType* break_type);
VALA_EXTERN BreakTimerSettingsBreakBreakType* break_timer_settings_break_break_status_widget_get_break_type (BreakTimerSettingsBreakBreakStatusWidget* self);
VALA_EXTERN gboolean break_timer_settings_break_break_status_widget_get_is_enabled (BreakTimerSettingsBreakBreakStatusWidget* self);
VALA_EXTERN void break_timer_settings_break_break_status_widget_set_is_enabled (BreakTimerSettingsBreakBreakStatusWidget* self,
                                                                    gboolean value);
VALA_EXTERN BreakTimerSettingsBreakBreakType* break_timer_settings_break_break_type_construct (GType object_type,
                                                                                   const gchar* id,
                                                                                   GSettings* settings);
VALA_EXTERN gboolean break_timer_settings_break_break_type_init (BreakTimerSettingsBreakBreakType* self,
                                                     GCancellable* cancellable,
                                                     GError** error);
VALA_EXTERN void break_timer_settings_break_break_type_update_status (BreakTimerSettingsBreakBreakType* self,
                                                          BreakTimerCommonBreakStatus* status);
VALA_EXTERN BreakTimerSettingsBreakBreakInfoWidget* break_timer_settings_break_break_type_create_info_widget (BreakTimerSettingsBreakBreakType* self);
VALA_EXTERN BreakTimerSettingsBreakBreakStatusWidget* break_timer_settings_break_break_type_create_status_widget (BreakTimerSettingsBreakBreakType* self);
VALA_EXTERN BreakTimerSettingsBreakBreakSettingsWidget* break_timer_settings_break_break_type_create_settings_widget (BreakTimerSettingsBreakBreakType* self);
VALA_EXTERN const gchar* break_timer_settings_break_break_type_get_id (BreakTimerSettingsBreakBreakType* self);
VALA_EXTERN BreakTimerCommonBreakStatus* break_timer_settings_break_break_type_get_status (BreakTimerSettingsBreakBreakType* self);
VALA_EXTERN BreakTimerSettingsBreakBreakInfoWidget* break_timer_settings_break_break_type_get_info_widget (BreakTimerSettingsBreakBreakType* self);
VALA_EXTERN BreakTimerSettingsBreakBreakStatusWidget* break_timer_settings_break_break_type_get_status_widget (BreakTimerSettingsBreakBreakType* self);
VALA_EXTERN BreakTimerSettingsBreakBreakSettingsWidget* break_timer_settings_break_break_type_get_settings_widget (BreakTimerSettingsBreakBreakType* self);
VALA_EXTERN GType break_timer_settings_break_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsBreakManager, g_object_unref)
VALA_EXTERN GType break_timer_settings_break_manager_permissions_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gint break_timer_settings_break_manager_CURRENT_AUTOSTART_VERSION;
VALA_EXTERN BreakTimerSettingsBreakManager* break_timer_settings_break_manager_new (void);
VALA_EXTERN BreakTimerSettingsBreakManager* break_timer_settings_break_manager_construct (GType object_type);
VALA_EXTERN gboolean break_timer_settings_break_manager_init (BreakTimerSettingsBreakManager* self,
                                                  GCancellable* cancellable,
                                                  GError** error);
VALA_EXTERN void break_timer_settings_break_manager_refresh_permissions (BreakTimerSettingsBreakManager* self);
VALA_EXTERN GList* break_timer_settings_break_manager_all_breaks (BreakTimerSettingsBreakManager* self);
VALA_EXTERN gboolean break_timer_settings_break_manager_is_working (BreakTimerSettingsBreakManager* self);
VALA_EXTERN gint break_timer_settings_break_manager_get_autostart_version (BreakTimerSettingsBreakManager* self);
VALA_EXTERN void break_timer_settings_break_manager_set_autostart_version (BreakTimerSettingsBreakManager* self,
                                                               gint value);
VALA_EXTERN gboolean break_timer_settings_break_manager_get_master_enabled (BreakTimerSettingsBreakManager* self);
VALA_EXTERN void break_timer_settings_break_manager_set_master_enabled (BreakTimerSettingsBreakManager* self,
                                                            gboolean value);
VALA_EXTERN gchar** break_timer_settings_break_manager_get_selected_break_ids (BreakTimerSettingsBreakManager* self,
                                                                   gint* result_length1);
VALA_EXTERN void break_timer_settings_break_manager_set_selected_break_ids (BreakTimerSettingsBreakManager* self,
                                                                gchar** value,
                                                                gint value_length1);
VALA_EXTERN BreakTimerSettingsBreakBreakType* break_timer_settings_break_manager_get_foreground_break (BreakTimerSettingsBreakManager* self);
VALA_EXTERN BreakTimerSettingsBreakManagerPermissionsError break_timer_settings_break_manager_get_permissions_error (BreakTimerSettingsBreakManager* self);
VALA_EXTERN GType break_timer_settings_break_settings_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsBreakSettingsDialog, g_object_unref)
VALA_EXTERN BreakTimerSettingsBreakSettingsDialog* break_timer_settings_break_settings_dialog_new (BreakTimerSettingsBreakManager* break_manager);
VALA_EXTERN BreakTimerSettingsBreakSettingsDialog* break_timer_settings_break_settings_dialog_construct (GType object_type,
                                                                                             BreakTimerSettingsBreakManager* break_manager);
VALA_EXTERN gboolean break_timer_settings_break_settings_dialog_init (BreakTimerSettingsBreakSettingsDialog* self,
                                                          GCancellable* cancellable,
                                                          GError** error);
VALA_EXTERN GType break_timer_settings_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsMainWindow, g_object_unref)
VALA_EXTERN BreakTimerSettingsMainWindow* break_timer_settings_main_window_new (BreakTimerSettingsApplication* application,
                                                                    BreakTimerSettingsBreakManager* break_manager);
VALA_EXTERN BreakTimerSettingsMainWindow* break_timer_settings_main_window_construct (GType object_type,
                                                                          BreakTimerSettingsApplication* application,
                                                                          BreakTimerSettingsBreakManager* break_manager);
VALA_EXTERN GtkWidget* break_timer_settings_main_window_get_master_switch (BreakTimerSettingsMainWindow* self);
VALA_EXTERN GtkWidget* break_timer_settings_main_window_get_settings_button (BreakTimerSettingsMainWindow* self);
VALA_EXTERN GType break_timer_settings_timer_break_timer_break_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsTimerBreakTimerBreakType, g_object_unref)
VALA_EXTERN GType break_timer_settings_timer_break_break_time_option_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsTimerBreakBreakTimeOption, g_object_unref)
VALA_EXTERN GType break_timer_settings_micro_break_micro_break_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsMicroBreakMicroBreakType, g_object_unref)
VALA_EXTERN BreakTimerSettingsMicroBreakMicroBreakType* break_timer_settings_micro_break_micro_break_type_new (void);
VALA_EXTERN BreakTimerSettingsMicroBreakMicroBreakType* break_timer_settings_micro_break_micro_break_type_construct (GType object_type);
VALA_EXTERN GType break_timer_settings_rest_break_rest_break_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsRestBreakRestBreakType, g_object_unref)
VALA_EXTERN BreakTimerSettingsRestBreakRestBreakType* break_timer_settings_rest_break_rest_break_type_new (void);
VALA_EXTERN BreakTimerSettingsRestBreakRestBreakType* break_timer_settings_rest_break_rest_break_type_construct (GType object_type);
VALA_EXTERN GType break_timer_settings_timer_break_timer_break_settings_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsTimerBreakTimerBreakSettingsWidget, g_object_unref)
VALA_EXTERN BreakTimerSettingsTimerBreakTimerBreakSettingsWidget* break_timer_settings_timer_break_timer_break_settings_widget_construct (GType object_type,
                                                                                                                              BreakTimerSettingsTimerBreakTimerBreakType* break_type,
                                                                                                                              const gchar* title,
                                                                                                                              const gchar* description);
VALA_EXTERN GType break_timer_settings_timer_break_timer_break_status_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsTimerBreakTimerBreakStatusWidget, g_object_unref)
VALA_EXTERN BreakTimerSettingsTimerBreakTimerBreakStatusWidget* break_timer_settings_timer_break_timer_break_status_widget_construct (GType object_type,
                                                                                                                          BreakTimerSettingsTimerBreakTimerBreakType* break_type,
                                                                                                                          const gchar* upcoming_text,
                                                                                                                          const gchar* ongoing_text);
VALA_EXTERN BreakTimerSettingsTimerBreakBreakTimeOption* break_timer_settings_timer_break_break_time_option_new (gint time_seconds);
VALA_EXTERN BreakTimerSettingsTimerBreakBreakTimeOption* break_timer_settings_timer_break_break_time_option_construct (GType object_type,
                                                                                                           gint time_seconds);
VALA_EXTERN gboolean break_timer_settings_timer_break_break_time_option_equals (BreakTimerSettingsTimerBreakBreakTimeOption* self,
                                                                    BreakTimerSettingsTimerBreakBreakTimeOption* other);
VALA_EXTERN gint break_timer_settings_timer_break_break_time_option_get_time_seconds (BreakTimerSettingsTimerBreakBreakTimeOption* self);
VALA_EXTERN void break_timer_settings_timer_break_break_time_option_set_time_seconds (BreakTimerSettingsTimerBreakBreakTimeOption* self,
                                                                          gint value);
VALA_EXTERN gboolean break_timer_settings_timer_break_break_time_option_get_is_custom (BreakTimerSettingsTimerBreakBreakTimeOption* self);
VALA_EXTERN void break_timer_settings_timer_break_break_time_option_set_is_custom (BreakTimerSettingsTimerBreakBreakTimeOption* self,
                                                                       gboolean value);
VALA_EXTERN const gchar* break_timer_settings_timer_break_break_time_option_get_label (BreakTimerSettingsTimerBreakBreakTimeOption* self);
VALA_EXTERN void break_timer_settings_timer_break_break_time_option_set_label (BreakTimerSettingsTimerBreakBreakTimeOption* self,
                                                                   const gchar* value);
VALA_EXTERN BreakTimerSettingsTimerBreakTimerBreakType* break_timer_settings_timer_break_timer_break_type_construct (GType object_type,
                                                                                                         const gchar* name,
                                                                                                         GSettings* settings);
VALA_EXTERN void break_timer_settings_timer_break_timer_break_type_update_status (BreakTimerSettingsTimerBreakTimerBreakType* self,
                                                                      BreakTimerCommonTimerBreakStatus* status);
VALA_EXTERN gint break_timer_settings_timer_break_timer_break_type_get_interval (BreakTimerSettingsTimerBreakTimerBreakType* self);
VALA_EXTERN void break_timer_settings_timer_break_timer_break_type_set_interval (BreakTimerSettingsTimerBreakTimerBreakType* self,
                                                                     gint value);
VALA_EXTERN gint break_timer_settings_timer_break_timer_break_type_get_duration (BreakTimerSettingsTimerBreakTimerBreakType* self);
VALA_EXTERN void break_timer_settings_timer_break_timer_break_type_set_duration (BreakTimerSettingsTimerBreakTimerBreakType* self,
                                                                     gint value);
VALA_EXTERN GType break_timer_settings_widgets_circle_counter_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsWidgetsCircleCounter, g_object_unref)
VALA_EXTERN GType break_timer_settings_widgets_circle_counter_direction_get_type (void) G_GNUC_CONST ;
VALA_EXTERN BreakTimerSettingsWidgetsCircleCounter* break_timer_settings_widgets_circle_counter_new (void);
VALA_EXTERN BreakTimerSettingsWidgetsCircleCounter* break_timer_settings_widgets_circle_counter_construct (GType object_type);
VALA_EXTERN BreakTimerSettingsWidgetsCircleCounterDirection break_timer_settings_widgets_circle_counter_get_direction (BreakTimerSettingsWidgetsCircleCounter* self);
VALA_EXTERN void break_timer_settings_widgets_circle_counter_set_direction (BreakTimerSettingsWidgetsCircleCounter* self,
                                                                BreakTimerSettingsWidgetsCircleCounterDirection value);
VALA_EXTERN gdouble break_timer_settings_widgets_circle_counter_get_progress (BreakTimerSettingsWidgetsCircleCounter* self);
VALA_EXTERN void break_timer_settings_widgets_circle_counter_set_progress (BreakTimerSettingsWidgetsCircleCounter* self,
                                                               gdouble value);
VALA_EXTERN gdouble break_timer_settings_widgets_circle_counter_get_draw_angle (BreakTimerSettingsWidgetsCircleCounter* self);
VALA_EXTERN void break_timer_settings_widgets_circle_counter_set_draw_angle (BreakTimerSettingsWidgetsCircleCounter* self,
                                                                 gdouble value);
VALA_EXTERN GType break_timer_settings_widgets_overlay_arrow_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsWidgetsOverlayArrow, g_object_unref)
VALA_EXTERN BreakTimerSettingsWidgetsOverlayArrow* break_timer_settings_widgets_overlay_arrow_new (GtkWidget* from_widget,
                                                                                       GtkWidget* to_widget,
                                                                                       GtkWidget* align_widget);
VALA_EXTERN BreakTimerSettingsWidgetsOverlayArrow* break_timer_settings_widgets_overlay_arrow_construct (GType object_type,
                                                                                             GtkWidget* from_widget,
                                                                                             GtkWidget* to_widget,
                                                                                             GtkWidget* align_widget);
VALA_EXTERN gint break_timer_settings_widgets_overlay_arrow_get_spacing (BreakTimerSettingsWidgetsOverlayArrow* self);
VALA_EXTERN void break_timer_settings_widgets_overlay_arrow_set_spacing (BreakTimerSettingsWidgetsOverlayArrow* self,
                                                             gint value);
VALA_EXTERN GType break_timer_settings_widgets_time_chooser_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsWidgetsTimeChooserRow, g_object_unref)
VALA_EXTERN BreakTimerSettingsWidgetsTimeChooserRow* break_timer_settings_widgets_time_chooser_row_new (BreakTimerSettingsTimerBreakBreakTimeOption** default_options,
                                                                                            gint default_options_length1);
VALA_EXTERN BreakTimerSettingsWidgetsTimeChooserRow* break_timer_settings_widgets_time_chooser_row_construct (GType object_type,
                                                                                                  BreakTimerSettingsTimerBreakBreakTimeOption** default_options,
                                                                                                  gint default_options_length1);
VALA_EXTERN gint break_timer_settings_widgets_time_chooser_row_get_time_seconds (BreakTimerSettingsWidgetsTimeChooserRow* self);
VALA_EXTERN void break_timer_settings_widgets_time_chooser_row_set_time_seconds (BreakTimerSettingsWidgetsTimeChooserRow* self,
                                                                     gint value);
VALA_EXTERN GType break_timer_settings_widgets_property_transition_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerSettingsWidgetsPropertyTransition, g_object_unref)
VALA_EXTERN GType break_timer_settings_widgets_property_transition_easing_function_get_type (void) G_GNUC_CONST ;
VALA_EXTERN gdouble break_timer_settings_widgets_property_transition_easing_function_calculate (BreakTimerSettingsWidgetsPropertyTransitionEasingFunction self,
                                                                                    gdouble time);
VALA_EXTERN BreakTimerSettingsWidgetsPropertyTransition* break_timer_settings_widgets_property_transition_new (GtkWidget* widget,
                                                                                                   const gchar* property_name,
                                                                                                   BreakTimerSettingsWidgetsPropertyTransitionCalculateValue calculate_value,
                                                                                                   gpointer calculate_value_target);
VALA_EXTERN BreakTimerSettingsWidgetsPropertyTransition* break_timer_settings_widgets_property_transition_construct (GType object_type,
                                                                                                         GtkWidget* widget,
                                                                                                         const gchar* property_name,
                                                                                                         BreakTimerSettingsWidgetsPropertyTransitionCalculateValue calculate_value,
                                                                                                         gpointer calculate_value_target);
VALA_EXTERN gboolean break_timer_settings_widgets_property_transition_start (BreakTimerSettingsWidgetsPropertyTransition* self,
                                                                 GValue* target_value,
                                                                 BreakTimerSettingsWidgetsPropertyTransitionEasingFunction easing_function,
                                                                 gint64 duration_microseconds);
VALA_EXTERN gboolean break_timer_settings_widgets_property_transition_skip (BreakTimerSettingsWidgetsPropertyTransition* self,
                                                                GValue* target_value);
VALA_EXTERN void break_timer_settings_widgets_property_transition_calculate_value_double (GValue* start_value,
                                                                              GValue* end_value,
                                                                              gdouble ease,
                                                                              GValue* result);

G_END_DECLS

#endif
