/* daemon.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __SRC_DAEMON_DAEMON_H__
#define __SRC_DAEMON_DAEMON_H__

#include <glib-object.h>
#include <gio/gio.h>
#include <glib.h>
#include <json-glib/json-glib.h>
#include "common.h"
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <float.h>
#include <math.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_MONITOR_SLEEP_TIME_CORRECTION_THRESHOLD 10

#define BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR_BACKEND (break_timer_daemon_activity_activity_monitor_backend_get_type ())
#define BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_MONITOR_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR_BACKEND, BreakTimerDaemonActivityActivityMonitorBackend))
#define BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_MONITOR_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR_BACKEND, BreakTimerDaemonActivityActivityMonitorBackendClass))
#define BREAK_TIMER_DAEMON_ACTIVITY_IS_ACTIVITY_MONITOR_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR_BACKEND))
#define BREAK_TIMER_DAEMON_ACTIVITY_IS_ACTIVITY_MONITOR_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR_BACKEND))
#define BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_MONITOR_BACKEND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR_BACKEND, BreakTimerDaemonActivityActivityMonitorBackendClass))

typedef struct _BreakTimerDaemonActivityActivityMonitorBackend BreakTimerDaemonActivityActivityMonitorBackend;
typedef struct _BreakTimerDaemonActivityActivityMonitorBackendClass BreakTimerDaemonActivityActivityMonitorBackendClass;
typedef struct _BreakTimerDaemonActivityActivityMonitorBackendPrivate BreakTimerDaemonActivityActivityMonitorBackendPrivate;

#define BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR (break_timer_daemon_activity_activity_monitor_get_type ())
#define BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR, BreakTimerDaemonActivityActivityMonitor))
#define BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR, BreakTimerDaemonActivityActivityMonitorClass))
#define BREAK_TIMER_DAEMON_ACTIVITY_IS_ACTIVITY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR))
#define BREAK_TIMER_DAEMON_ACTIVITY_IS_ACTIVITY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR))
#define BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_MONITOR, BreakTimerDaemonActivityActivityMonitorClass))

typedef struct _BreakTimerDaemonActivityActivityMonitor BreakTimerDaemonActivityActivityMonitor;
typedef struct _BreakTimerDaemonActivityActivityMonitorClass BreakTimerDaemonActivityActivityMonitorClass;
typedef struct _BreakTimerDaemonActivityActivityMonitorPrivate BreakTimerDaemonActivityActivityMonitorPrivate;

#define BREAK_TIMER_DAEMON_ACTIVITY_TYPE_MUTTER_ACTIVITY_MONITOR_BACKEND (break_timer_daemon_activity_mutter_activity_monitor_backend_get_type ())
#define BREAK_TIMER_DAEMON_ACTIVITY_MUTTER_ACTIVITY_MONITOR_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_MUTTER_ACTIVITY_MONITOR_BACKEND, BreakTimerDaemonActivityMutterActivityMonitorBackend))
#define BREAK_TIMER_DAEMON_ACTIVITY_MUTTER_ACTIVITY_MONITOR_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_MUTTER_ACTIVITY_MONITOR_BACKEND, BreakTimerDaemonActivityMutterActivityMonitorBackendClass))
#define BREAK_TIMER_DAEMON_ACTIVITY_IS_MUTTER_ACTIVITY_MONITOR_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_MUTTER_ACTIVITY_MONITOR_BACKEND))
#define BREAK_TIMER_DAEMON_ACTIVITY_IS_MUTTER_ACTIVITY_MONITOR_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_MUTTER_ACTIVITY_MONITOR_BACKEND))
#define BREAK_TIMER_DAEMON_ACTIVITY_MUTTER_ACTIVITY_MONITOR_BACKEND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_ACTIVITY_TYPE_MUTTER_ACTIVITY_MONITOR_BACKEND, BreakTimerDaemonActivityMutterActivityMonitorBackendClass))

typedef struct _BreakTimerDaemonActivityMutterActivityMonitorBackend BreakTimerDaemonActivityMutterActivityMonitorBackend;
typedef struct _BreakTimerDaemonActivityMutterActivityMonitorBackendClass BreakTimerDaemonActivityMutterActivityMonitorBackendClass;
typedef struct _BreakTimerDaemonActivityMutterActivityMonitorBackendPrivate BreakTimerDaemonActivityMutterActivityMonitorBackendPrivate;

#define BREAK_TIMER_DAEMON_ACTIVITY_TYPE_USER_ACTIVITY (break_timer_daemon_activity_user_activity_get_type ())
typedef struct _BreakTimerDaemonActivityUserActivity BreakTimerDaemonActivityUserActivity;
typedef enum  {
	BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_TYPE_SLEEP,
	BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_TYPE_LOCKED,
	BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_TYPE_NONE,
	BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_TYPE_INPUT,
	BREAK_TIMER_DAEMON_ACTIVITY_ACTIVITY_TYPE_UNLOCK
} BreakTimerDaemonActivityActivityType;

#define BREAK_TIMER_DAEMON_ACTIVITY_TYPE_ACTIVITY_TYPE (break_timer_daemon_activity_activity_type_get_type ())

#define BREAK_TIMER_DAEMON_TYPE_APPLICATION (break_timer_daemon_application_get_type ())
#define BREAK_TIMER_DAEMON_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_TYPE_APPLICATION, BreakTimerDaemonApplication))
#define BREAK_TIMER_DAEMON_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_TYPE_APPLICATION, BreakTimerDaemonApplicationClass))
#define BREAK_TIMER_DAEMON_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_TYPE_APPLICATION))
#define BREAK_TIMER_DAEMON_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_TYPE_APPLICATION))
#define BREAK_TIMER_DAEMON_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_TYPE_APPLICATION, BreakTimerDaemonApplicationClass))

typedef struct _BreakTimerDaemonApplication BreakTimerDaemonApplication;
typedef struct _BreakTimerDaemonApplicationClass BreakTimerDaemonApplicationClass;
typedef struct _BreakTimerDaemonApplicationPrivate BreakTimerDaemonApplicationPrivate;

#define BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_CONTROLLER (break_timer_daemon_break_break_controller_get_type ())
#define BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_CONTROLLER, BreakTimerDaemonBreakBreakController))
#define BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_CONTROLLER, BreakTimerDaemonBreakBreakControllerClass))
#define BREAK_TIMER_DAEMON_BREAK_IS_BREAK_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_CONTROLLER))
#define BREAK_TIMER_DAEMON_BREAK_IS_BREAK_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_CONTROLLER))
#define BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_CONTROLLER, BreakTimerDaemonBreakBreakControllerClass))

typedef struct _BreakTimerDaemonBreakBreakController BreakTimerDaemonBreakBreakController;
typedef struct _BreakTimerDaemonBreakBreakControllerClass BreakTimerDaemonBreakBreakControllerClass;
typedef struct _BreakTimerDaemonBreakBreakControllerPrivate BreakTimerDaemonBreakBreakControllerPrivate;
typedef enum  {
	BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER_STATE_WAITING,
	BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER_STATE_ACTIVE,
	BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER_STATE_DISABLED
} BreakTimerDaemonBreakBreakControllerState;

#define BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER_TYPE_STATE (break_timer_daemon_break_break_controller_state_get_type ())
typedef enum  {
	BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER_FINISHED_REASON_DISABLED,
	BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER_FINISHED_REASON_SKIPPED,
	BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER_FINISHED_REASON_SATISFIED
} BreakTimerDaemonBreakBreakControllerFinishedReason;

#define BREAK_TIMER_DAEMON_BREAK_BREAK_CONTROLLER_TYPE_FINISHED_REASON (break_timer_daemon_break_break_controller_finished_reason_get_type ())

#define BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_TYPE (break_timer_daemon_break_break_type_get_type ())
#define BREAK_TIMER_DAEMON_BREAK_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_TYPE, BreakTimerDaemonBreakBreakType))
#define BREAK_TIMER_DAEMON_BREAK_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_TYPE, BreakTimerDaemonBreakBreakTypeClass))
#define BREAK_TIMER_DAEMON_BREAK_IS_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_TYPE))
#define BREAK_TIMER_DAEMON_BREAK_IS_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_TYPE))
#define BREAK_TIMER_DAEMON_BREAK_BREAK_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_TYPE, BreakTimerDaemonBreakBreakTypeClass))

typedef struct _BreakTimerDaemonBreakBreakType BreakTimerDaemonBreakBreakType;
typedef struct _BreakTimerDaemonBreakBreakTypeClass BreakTimerDaemonBreakBreakTypeClass;
typedef struct _BreakTimerDaemonBreakBreakTypePrivate BreakTimerDaemonBreakBreakTypePrivate;

#define BREAK_TIMER_DAEMON_TYPE_UI_FRAGMENT (break_timer_daemon_ui_fragment_get_type ())
#define BREAK_TIMER_DAEMON_UI_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_TYPE_UI_FRAGMENT, BreakTimerDaemonUIFragment))
#define BREAK_TIMER_DAEMON_UI_FRAGMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_TYPE_UI_FRAGMENT, BreakTimerDaemonUIFragmentClass))
#define BREAK_TIMER_DAEMON_IS_UI_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_TYPE_UI_FRAGMENT))
#define BREAK_TIMER_DAEMON_IS_UI_FRAGMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_TYPE_UI_FRAGMENT))
#define BREAK_TIMER_DAEMON_UI_FRAGMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_TYPE_UI_FRAGMENT, BreakTimerDaemonUIFragmentClass))

typedef struct _BreakTimerDaemonUIFragment BreakTimerDaemonUIFragment;
typedef struct _BreakTimerDaemonUIFragmentClass BreakTimerDaemonUIFragmentClass;

#define BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_VIEW (break_timer_daemon_break_break_view_get_type ())
#define BREAK_TIMER_DAEMON_BREAK_BREAK_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_VIEW, BreakTimerDaemonBreakBreakView))
#define BREAK_TIMER_DAEMON_BREAK_BREAK_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_VIEW, BreakTimerDaemonBreakBreakViewClass))
#define BREAK_TIMER_DAEMON_BREAK_IS_BREAK_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_VIEW))
#define BREAK_TIMER_DAEMON_BREAK_IS_BREAK_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_VIEW))
#define BREAK_TIMER_DAEMON_BREAK_BREAK_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_BREAK_TYPE_BREAK_VIEW, BreakTimerDaemonBreakBreakViewClass))

typedef struct _BreakTimerDaemonBreakBreakView BreakTimerDaemonBreakBreakView;
typedef struct _BreakTimerDaemonBreakBreakViewClass BreakTimerDaemonBreakBreakViewClass;

#define BREAK_TIMER_DAEMON_UTIL_TYPE_IFOCUSABLE (break_timer_daemon_util_ifocusable_get_type ())
#define BREAK_TIMER_DAEMON_UTIL_IFOCUSABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_IFOCUSABLE, BreakTimerDaemonUtilIFocusable))
#define BREAK_TIMER_DAEMON_UTIL_IS_IFOCUSABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_IFOCUSABLE))
#define BREAK_TIMER_DAEMON_UTIL_IFOCUSABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_IFOCUSABLE, BreakTimerDaemonUtilIFocusableIface))

typedef struct _BreakTimerDaemonUtilIFocusable BreakTimerDaemonUtilIFocusable;
typedef struct _BreakTimerDaemonUtilIFocusableIface BreakTimerDaemonUtilIFocusableIface;
typedef struct _BreakTimerDaemonUIFragmentPrivate BreakTimerDaemonUIFragmentPrivate;
typedef enum  {
	BREAK_TIMER_DAEMON_UTIL_FOCUS_PRIORITY_NONE,
	BREAK_TIMER_DAEMON_UTIL_FOCUS_PRIORITY_LOW,
	BREAK_TIMER_DAEMON_UTIL_FOCUS_PRIORITY_HIGH
} BreakTimerDaemonUtilFocusPriority;

#define BREAK_TIMER_DAEMON_UTIL_TYPE_FOCUS_PRIORITY (break_timer_daemon_util_focus_priority_get_type ())

#define BREAK_TIMER_DAEMON_UTIL_TYPE_SIMPLE_FOCUS_MANAGER (break_timer_daemon_util_simple_focus_manager_get_type ())
#define BREAK_TIMER_DAEMON_UTIL_SIMPLE_FOCUS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_SIMPLE_FOCUS_MANAGER, BreakTimerDaemonUtilSimpleFocusManager))
#define BREAK_TIMER_DAEMON_UTIL_SIMPLE_FOCUS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_UTIL_TYPE_SIMPLE_FOCUS_MANAGER, BreakTimerDaemonUtilSimpleFocusManagerClass))
#define BREAK_TIMER_DAEMON_UTIL_IS_SIMPLE_FOCUS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_SIMPLE_FOCUS_MANAGER))
#define BREAK_TIMER_DAEMON_UTIL_IS_SIMPLE_FOCUS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_UTIL_TYPE_SIMPLE_FOCUS_MANAGER))
#define BREAK_TIMER_DAEMON_UTIL_SIMPLE_FOCUS_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_SIMPLE_FOCUS_MANAGER, BreakTimerDaemonUtilSimpleFocusManagerClass))

typedef struct _BreakTimerDaemonUtilSimpleFocusManager BreakTimerDaemonUtilSimpleFocusManager;
typedef struct _BreakTimerDaemonUtilSimpleFocusManagerClass BreakTimerDaemonUtilSimpleFocusManagerClass;

#define BREAK_TIMER_DAEMON_TYPE_UI_MANAGER (break_timer_daemon_ui_manager_get_type ())
#define BREAK_TIMER_DAEMON_UI_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_TYPE_UI_MANAGER, BreakTimerDaemonUIManager))
#define BREAK_TIMER_DAEMON_UI_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_TYPE_UI_MANAGER, BreakTimerDaemonUIManagerClass))
#define BREAK_TIMER_DAEMON_IS_UI_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_TYPE_UI_MANAGER))
#define BREAK_TIMER_DAEMON_IS_UI_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_TYPE_UI_MANAGER))
#define BREAK_TIMER_DAEMON_UI_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_TYPE_UI_MANAGER, BreakTimerDaemonUIManagerClass))

typedef struct _BreakTimerDaemonUIManager BreakTimerDaemonUIManager;
typedef struct _BreakTimerDaemonUIManagerClass BreakTimerDaemonUIManagerClass;
typedef struct _BreakTimerDaemonBreakBreakViewPrivate BreakTimerDaemonBreakBreakViewPrivate;

#define BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER_DBUS_OBJECT (break_timer_daemon_break_manager_dbus_object_get_type ())
#define BREAK_TIMER_DAEMON_BREAK_MANAGER_DBUS_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER_DBUS_OBJECT, BreakTimerDaemonBreakManagerDBusObject))
#define BREAK_TIMER_DAEMON_BREAK_MANAGER_DBUS_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER_DBUS_OBJECT, BreakTimerDaemonBreakManagerDBusObjectClass))
#define BREAK_TIMER_DAEMON_IS_BREAK_MANAGER_DBUS_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER_DBUS_OBJECT))
#define BREAK_TIMER_DAEMON_IS_BREAK_MANAGER_DBUS_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER_DBUS_OBJECT))
#define BREAK_TIMER_DAEMON_BREAK_MANAGER_DBUS_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER_DBUS_OBJECT, BreakTimerDaemonBreakManagerDBusObjectClass))

typedef struct _BreakTimerDaemonBreakManagerDBusObject BreakTimerDaemonBreakManagerDBusObject;
typedef struct _BreakTimerDaemonBreakManagerDBusObjectClass BreakTimerDaemonBreakManagerDBusObjectClass;
typedef struct _BreakTimerDaemonBreakManagerDBusObjectPrivate BreakTimerDaemonBreakManagerDBusObjectPrivate;

#define BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER (break_timer_daemon_break_manager_get_type ())
#define BREAK_TIMER_DAEMON_BREAK_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER, BreakTimerDaemonBreakManager))
#define BREAK_TIMER_DAEMON_BREAK_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER, BreakTimerDaemonBreakManagerClass))
#define BREAK_TIMER_DAEMON_IS_BREAK_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER))
#define BREAK_TIMER_DAEMON_IS_BREAK_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER))
#define BREAK_TIMER_DAEMON_BREAK_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_TYPE_BREAK_MANAGER, BreakTimerDaemonBreakManagerClass))

typedef struct _BreakTimerDaemonBreakManager BreakTimerDaemonBreakManager;
typedef struct _BreakTimerDaemonBreakManagerClass BreakTimerDaemonBreakManagerClass;
typedef struct _BreakTimerDaemonBreakManagerPrivate BreakTimerDaemonBreakManagerPrivate;

#define BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_CONTROLLER (break_timer_daemon_timer_break_timer_break_controller_get_type ())
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_CONTROLLER, BreakTimerDaemonTimerBreakTimerBreakController))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_CONTROLLER, BreakTimerDaemonTimerBreakTimerBreakControllerClass))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_IS_TIMER_BREAK_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_CONTROLLER))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_IS_TIMER_BREAK_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_CONTROLLER))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_CONTROLLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_CONTROLLER, BreakTimerDaemonTimerBreakTimerBreakControllerClass))

typedef struct _BreakTimerDaemonTimerBreakTimerBreakController BreakTimerDaemonTimerBreakTimerBreakController;
typedef struct _BreakTimerDaemonTimerBreakTimerBreakControllerClass BreakTimerDaemonTimerBreakTimerBreakControllerClass;
typedef struct _BreakTimerDaemonTimerBreakTimerBreakControllerPrivate BreakTimerDaemonTimerBreakTimerBreakControllerPrivate;

#define BREAK_TIMER_DAEMON_UTIL_TYPE_COUNTDOWN (break_timer_daemon_util_countdown_get_type ())
#define BREAK_TIMER_DAEMON_UTIL_COUNTDOWN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_COUNTDOWN, BreakTimerDaemonUtilCountdown))
#define BREAK_TIMER_DAEMON_UTIL_COUNTDOWN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_UTIL_TYPE_COUNTDOWN, BreakTimerDaemonUtilCountdownClass))
#define BREAK_TIMER_DAEMON_UTIL_IS_COUNTDOWN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_COUNTDOWN))
#define BREAK_TIMER_DAEMON_UTIL_IS_COUNTDOWN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_UTIL_TYPE_COUNTDOWN))
#define BREAK_TIMER_DAEMON_UTIL_COUNTDOWN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_COUNTDOWN, BreakTimerDaemonUtilCountdownClass))

typedef struct _BreakTimerDaemonUtilCountdown BreakTimerDaemonUtilCountdown;
typedef struct _BreakTimerDaemonUtilCountdownClass BreakTimerDaemonUtilCountdownClass;

#define BREAK_TIMER_DAEMON_UTIL_TYPE_PAUSABLE_TIMEOUT (break_timer_daemon_util_pausable_timeout_get_type ())
#define BREAK_TIMER_DAEMON_UTIL_PAUSABLE_TIMEOUT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_PAUSABLE_TIMEOUT, BreakTimerDaemonUtilPausableTimeout))
#define BREAK_TIMER_DAEMON_UTIL_PAUSABLE_TIMEOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_UTIL_TYPE_PAUSABLE_TIMEOUT, BreakTimerDaemonUtilPausableTimeoutClass))
#define BREAK_TIMER_DAEMON_UTIL_IS_PAUSABLE_TIMEOUT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_PAUSABLE_TIMEOUT))
#define BREAK_TIMER_DAEMON_UTIL_IS_PAUSABLE_TIMEOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_UTIL_TYPE_PAUSABLE_TIMEOUT))
#define BREAK_TIMER_DAEMON_UTIL_PAUSABLE_TIMEOUT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_PAUSABLE_TIMEOUT, BreakTimerDaemonUtilPausableTimeoutClass))

typedef struct _BreakTimerDaemonUtilPausableTimeout BreakTimerDaemonUtilPausableTimeout;
typedef struct _BreakTimerDaemonUtilPausableTimeoutClass BreakTimerDaemonUtilPausableTimeoutClass;

#define BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_CONTROLLER (break_timer_daemon_micro_break_micro_break_controller_get_type ())
#define BREAK_TIMER_DAEMON_MICRO_BREAK_MICRO_BREAK_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_CONTROLLER, BreakTimerDaemonMicroBreakMicroBreakController))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_MICRO_BREAK_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_CONTROLLER, BreakTimerDaemonMicroBreakMicroBreakControllerClass))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_IS_MICRO_BREAK_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_CONTROLLER))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_IS_MICRO_BREAK_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_CONTROLLER))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_MICRO_BREAK_CONTROLLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_CONTROLLER, BreakTimerDaemonMicroBreakMicroBreakControllerClass))

typedef struct _BreakTimerDaemonMicroBreakMicroBreakController BreakTimerDaemonMicroBreakMicroBreakController;
typedef struct _BreakTimerDaemonMicroBreakMicroBreakControllerClass BreakTimerDaemonMicroBreakMicroBreakControllerClass;
typedef struct _BreakTimerDaemonMicroBreakMicroBreakControllerPrivate BreakTimerDaemonMicroBreakMicroBreakControllerPrivate;

#define BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE (break_timer_daemon_timer_break_timer_break_type_get_type ())
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE, BreakTimerDaemonTimerBreakTimerBreakType))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE, BreakTimerDaemonTimerBreakTimerBreakTypeClass))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_IS_TIMER_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_IS_TIMER_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_TYPE, BreakTimerDaemonTimerBreakTimerBreakTypeClass))

typedef struct _BreakTimerDaemonTimerBreakTimerBreakType BreakTimerDaemonTimerBreakTimerBreakType;
typedef struct _BreakTimerDaemonTimerBreakTimerBreakTypeClass BreakTimerDaemonTimerBreakTimerBreakTypeClass;
typedef struct _BreakTimerDaemonTimerBreakTimerBreakTypePrivate BreakTimerDaemonTimerBreakTimerBreakTypePrivate;

#define BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE (break_timer_daemon_micro_break_micro_break_type_get_type ())
#define BREAK_TIMER_DAEMON_MICRO_BREAK_MICRO_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE, BreakTimerDaemonMicroBreakMicroBreakType))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_MICRO_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE, BreakTimerDaemonMicroBreakMicroBreakTypeClass))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_IS_MICRO_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_IS_MICRO_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_MICRO_BREAK_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_TYPE, BreakTimerDaemonMicroBreakMicroBreakTypeClass))

typedef struct _BreakTimerDaemonMicroBreakMicroBreakType BreakTimerDaemonMicroBreakMicroBreakType;
typedef struct _BreakTimerDaemonMicroBreakMicroBreakTypeClass BreakTimerDaemonMicroBreakMicroBreakTypeClass;
typedef struct _BreakTimerDaemonMicroBreakMicroBreakTypePrivate BreakTimerDaemonMicroBreakMicroBreakTypePrivate;

#define BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_VIEW (break_timer_daemon_timer_break_timer_break_view_get_type ())
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_VIEW, BreakTimerDaemonTimerBreakTimerBreakView))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_VIEW, BreakTimerDaemonTimerBreakTimerBreakViewClass))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_IS_TIMER_BREAK_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_VIEW))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_IS_TIMER_BREAK_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_VIEW))
#define BREAK_TIMER_DAEMON_TIMER_BREAK_TIMER_BREAK_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_TIMER_BREAK_TYPE_TIMER_BREAK_VIEW, BreakTimerDaemonTimerBreakTimerBreakViewClass))

typedef struct _BreakTimerDaemonTimerBreakTimerBreakView BreakTimerDaemonTimerBreakTimerBreakView;
typedef struct _BreakTimerDaemonTimerBreakTimerBreakViewClass BreakTimerDaemonTimerBreakTimerBreakViewClass;
typedef struct _BreakTimerDaemonTimerBreakTimerBreakViewPrivate BreakTimerDaemonTimerBreakTimerBreakViewPrivate;

#define BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_VIEW (break_timer_daemon_micro_break_micro_break_view_get_type ())
#define BREAK_TIMER_DAEMON_MICRO_BREAK_MICRO_BREAK_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_VIEW, BreakTimerDaemonMicroBreakMicroBreakView))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_MICRO_BREAK_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_VIEW, BreakTimerDaemonMicroBreakMicroBreakViewClass))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_IS_MICRO_BREAK_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_VIEW))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_IS_MICRO_BREAK_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_VIEW))
#define BREAK_TIMER_DAEMON_MICRO_BREAK_MICRO_BREAK_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_MICRO_BREAK_TYPE_MICRO_BREAK_VIEW, BreakTimerDaemonMicroBreakMicroBreakViewClass))

typedef struct _BreakTimerDaemonMicroBreakMicroBreakView BreakTimerDaemonMicroBreakMicroBreakView;
typedef struct _BreakTimerDaemonMicroBreakMicroBreakViewClass BreakTimerDaemonMicroBreakMicroBreakViewClass;
typedef struct _BreakTimerDaemonMicroBreakMicroBreakViewPrivate BreakTimerDaemonMicroBreakMicroBreakViewPrivate;

#define BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_CONTROLLER (break_timer_daemon_rest_break_rest_break_controller_get_type ())
#define BREAK_TIMER_DAEMON_REST_BREAK_REST_BREAK_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_CONTROLLER, BreakTimerDaemonRestBreakRestBreakController))
#define BREAK_TIMER_DAEMON_REST_BREAK_REST_BREAK_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_CONTROLLER, BreakTimerDaemonRestBreakRestBreakControllerClass))
#define BREAK_TIMER_DAEMON_REST_BREAK_IS_REST_BREAK_CONTROLLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_CONTROLLER))
#define BREAK_TIMER_DAEMON_REST_BREAK_IS_REST_BREAK_CONTROLLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_CONTROLLER))
#define BREAK_TIMER_DAEMON_REST_BREAK_REST_BREAK_CONTROLLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_CONTROLLER, BreakTimerDaemonRestBreakRestBreakControllerClass))

typedef struct _BreakTimerDaemonRestBreakRestBreakController BreakTimerDaemonRestBreakRestBreakController;
typedef struct _BreakTimerDaemonRestBreakRestBreakControllerClass BreakTimerDaemonRestBreakRestBreakControllerClass;
typedef struct _BreakTimerDaemonRestBreakRestBreakControllerPrivate BreakTimerDaemonRestBreakRestBreakControllerPrivate;

#define BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_TYPE (break_timer_daemon_rest_break_rest_break_type_get_type ())
#define BREAK_TIMER_DAEMON_REST_BREAK_REST_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_TYPE, BreakTimerDaemonRestBreakRestBreakType))
#define BREAK_TIMER_DAEMON_REST_BREAK_REST_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_TYPE, BreakTimerDaemonRestBreakRestBreakTypeClass))
#define BREAK_TIMER_DAEMON_REST_BREAK_IS_REST_BREAK_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_TYPE))
#define BREAK_TIMER_DAEMON_REST_BREAK_IS_REST_BREAK_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_TYPE))
#define BREAK_TIMER_DAEMON_REST_BREAK_REST_BREAK_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_TYPE, BreakTimerDaemonRestBreakRestBreakTypeClass))

typedef struct _BreakTimerDaemonRestBreakRestBreakType BreakTimerDaemonRestBreakRestBreakType;
typedef struct _BreakTimerDaemonRestBreakRestBreakTypeClass BreakTimerDaemonRestBreakRestBreakTypeClass;
typedef struct _BreakTimerDaemonRestBreakRestBreakTypePrivate BreakTimerDaemonRestBreakRestBreakTypePrivate;

#define BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_VIEW (break_timer_daemon_rest_break_rest_break_view_get_type ())
#define BREAK_TIMER_DAEMON_REST_BREAK_REST_BREAK_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_VIEW, BreakTimerDaemonRestBreakRestBreakView))
#define BREAK_TIMER_DAEMON_REST_BREAK_REST_BREAK_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_VIEW, BreakTimerDaemonRestBreakRestBreakViewClass))
#define BREAK_TIMER_DAEMON_REST_BREAK_IS_REST_BREAK_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_VIEW))
#define BREAK_TIMER_DAEMON_REST_BREAK_IS_REST_BREAK_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_VIEW))
#define BREAK_TIMER_DAEMON_REST_BREAK_REST_BREAK_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_REST_BREAK_TYPE_REST_BREAK_VIEW, BreakTimerDaemonRestBreakRestBreakViewClass))

typedef struct _BreakTimerDaemonRestBreakRestBreakView BreakTimerDaemonRestBreakRestBreakView;
typedef struct _BreakTimerDaemonRestBreakRestBreakViewClass BreakTimerDaemonRestBreakRestBreakViewClass;
typedef struct _BreakTimerDaemonRestBreakRestBreakViewPrivate BreakTimerDaemonRestBreakRestBreakViewPrivate;

#define BREAK_TIMER_DAEMON_TYPE_SESSION_STATUS (break_timer_daemon_session_status_get_type ())
#define BREAK_TIMER_DAEMON_SESSION_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_TYPE_SESSION_STATUS, BreakTimerDaemonSessionStatus))
#define BREAK_TIMER_DAEMON_SESSION_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_TYPE_SESSION_STATUS, BreakTimerDaemonSessionStatusClass))
#define BREAK_TIMER_DAEMON_IS_SESSION_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_TYPE_SESSION_STATUS))
#define BREAK_TIMER_DAEMON_IS_SESSION_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_TYPE_SESSION_STATUS))
#define BREAK_TIMER_DAEMON_SESSION_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_TYPE_SESSION_STATUS, BreakTimerDaemonSessionStatusClass))

typedef struct _BreakTimerDaemonSessionStatus BreakTimerDaemonSessionStatus;
typedef struct _BreakTimerDaemonSessionStatusClass BreakTimerDaemonSessionStatusClass;
typedef struct _BreakTimerDaemonSessionStatusPrivate BreakTimerDaemonSessionStatusPrivate;
typedef struct _BreakTimerDaemonUtilSimpleFocusManagerPrivate BreakTimerDaemonUtilSimpleFocusManagerPrivate;
typedef struct _BreakTimerDaemonUIManagerPrivate BreakTimerDaemonUIManagerPrivate;
typedef struct _BreakTimerDaemonUtilCountdownPrivate BreakTimerDaemonUtilCountdownPrivate;
typedef struct _BreakTimerDaemonUtilPausableTimeoutPrivate BreakTimerDaemonUtilPausableTimeoutPrivate;
typedef void (*BreakTimerDaemonUtilPausableTimeoutTimeoutCB) (BreakTimerDaemonUtilPausableTimeout* timeout, gint delta_millisecs, gpointer user_data);

#define BREAK_TIMER_DAEMON_UTIL_TYPE_STATEFUL_TIMER (break_timer_daemon_util_stateful_timer_get_type ())
#define BREAK_TIMER_DAEMON_UTIL_STATEFUL_TIMER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_STATEFUL_TIMER, BreakTimerDaemonUtilStatefulTimer))
#define BREAK_TIMER_DAEMON_UTIL_STATEFUL_TIMER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BREAK_TIMER_DAEMON_UTIL_TYPE_STATEFUL_TIMER, BreakTimerDaemonUtilStatefulTimerClass))
#define BREAK_TIMER_DAEMON_UTIL_IS_STATEFUL_TIMER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_STATEFUL_TIMER))
#define BREAK_TIMER_DAEMON_UTIL_IS_STATEFUL_TIMER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BREAK_TIMER_DAEMON_UTIL_TYPE_STATEFUL_TIMER))
#define BREAK_TIMER_DAEMON_UTIL_STATEFUL_TIMER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BREAK_TIMER_DAEMON_UTIL_TYPE_STATEFUL_TIMER, BreakTimerDaemonUtilStatefulTimerClass))

typedef struct _BreakTimerDaemonUtilStatefulTimer BreakTimerDaemonUtilStatefulTimer;
typedef struct _BreakTimerDaemonUtilStatefulTimerClass BreakTimerDaemonUtilStatefulTimerClass;
typedef struct _BreakTimerDaemonUtilStatefulTimerPrivate BreakTimerDaemonUtilStatefulTimerPrivate;
typedef enum  {
	BREAK_TIMER_DAEMON_UTIL_STATEFUL_TIMER_STATE_STOPPED,
	BREAK_TIMER_DAEMON_UTIL_STATEFUL_TIMER_STATE_COUNTING
} BreakTimerDaemonUtilStatefulTimerState;

#define BREAK_TIMER_DAEMON_UTIL_STATEFUL_TIMER_TYPE_STATE (break_timer_daemon_util_stateful_timer_state_get_type ())

struct _BreakTimerDaemonActivityActivityMonitorBackend {
	GObject parent_instance;
	BreakTimerDaemonActivityActivityMonitorBackendPrivate * priv;
};

struct _BreakTimerDaemonActivityActivityMonitorBackendClass {
	GObjectClass parent_class;
	gboolean (*init) (BreakTimerDaemonActivityActivityMonitorBackend* self, GCancellable* cancellable, GError** error);
	JsonObject* (*serialize) (BreakTimerDaemonActivityActivityMonitorBackend* self);
	void (*deserialize) (BreakTimerDaemonActivityActivityMonitorBackend* self, JsonObject** json_root);
	guint64 (*time_since_last_event_ms) (BreakTimerDaemonActivityActivityMonitorBackend* self);
};

struct _BreakTimerDaemonActivityActivityMonitor {
	GObject parent_instance;
	BreakTimerDaemonActivityActivityMonitorPrivate * priv;
};

struct _BreakTimerDaemonActivityActivityMonitorClass {
	GObjectClass parent_class;
};

struct _BreakTimerDaemonActivityMutterActivityMonitorBackend {
	BreakTimerDaemonActivityActivityMonitorBackend parent_instance;
	BreakTimerDaemonActivityMutterActivityMonitorBackendPrivate * priv;
};

struct _BreakTimerDaemonActivityMutterActivityMonitorBackendClass {
	BreakTimerDaemonActivityActivityMonitorBackendClass parent_class;
};

struct _BreakTimerDaemonActivityUserActivity {
	BreakTimerDaemonActivityActivityType type;
	gint64 idle_time;
	gint64 time_since_active;
	gint64 time_correction;
};

struct _BreakTimerDaemonApplication {
	GtkApplication parent_instance;
	BreakTimerDaemonApplicationPrivate * priv;
};

struct _BreakTimerDaemonApplicationClass {
	GtkApplicationClass parent_class;
};

struct _BreakTimerDaemonBreakBreakController {
	GObject parent_instance;
	BreakTimerDaemonBreakBreakControllerPrivate * priv;
};

struct _BreakTimerDaemonBreakBreakControllerClass {
	GObjectClass parent_class;
	JsonObject* (*serialize) (BreakTimerDaemonBreakBreakController* self);
	void (*deserialize) (BreakTimerDaemonBreakBreakController* self, JsonObject** json_root);
};

struct _BreakTimerDaemonBreakBreakType {
	GObject parent_instance;
	BreakTimerDaemonBreakBreakTypePrivate * priv;
};

struct _BreakTimerDaemonBreakBreakTypeClass {
	GObjectClass parent_class;
	gboolean (*init) (BreakTimerDaemonBreakBreakType* self, GCancellable* cancellable, GError** error);
};

struct _BreakTimerDaemonUtilIFocusableIface {
	GTypeInterface parent_iface;
	void (*focus_started) (BreakTimerDaemonUtilIFocusable* self);
	void (*focus_stopped) (BreakTimerDaemonUtilIFocusable* self);
};

struct _BreakTimerDaemonUIFragment {
	GObject parent_instance;
	BreakTimerDaemonUIFragmentPrivate * priv;
	BreakTimerDaemonUIManager* ui_manager;
};

struct _BreakTimerDaemonUIFragmentClass {
	GObjectClass parent_class;
	void (*focus_started) (BreakTimerDaemonUIFragment* self);
	void (*focus_stopped) (BreakTimerDaemonUIFragment* self);
	BreakTimerDaemonUtilFocusPriority (*get_focus_priority) (BreakTimerDaemonUIFragment* self);
	gchar** (*get_notification_ids) (BreakTimerDaemonUIFragment* self, gint* result_length1);
};

struct _BreakTimerDaemonBreakBreakView {
	BreakTimerDaemonUIFragment parent_instance;
	BreakTimerDaemonBreakBreakViewPrivate * priv;
	BreakTimerDaemonBreakBreakController* break_controller;
};

struct _BreakTimerDaemonBreakBreakViewClass {
	BreakTimerDaemonUIFragmentClass parent_class;
	gchar* (*get_status_message) (BreakTimerDaemonBreakBreakView* self);
	void (*dismiss_break) (BreakTimerDaemonBreakBreakView* self);
};

struct _BreakTimerDaemonBreakManagerDBusObject {
	GObject parent_instance;
	BreakTimerDaemonBreakManagerDBusObjectPrivate * priv;
};

struct _BreakTimerDaemonBreakManagerDBusObjectClass {
	GObjectClass parent_class;
};

struct _BreakTimerDaemonBreakManager {
	GObject parent_instance;
	BreakTimerDaemonBreakManagerPrivate * priv;
};

struct _BreakTimerDaemonBreakManagerClass {
	GObjectClass parent_class;
};

struct _BreakTimerDaemonTimerBreakTimerBreakController {
	BreakTimerDaemonBreakBreakController parent_instance;
	BreakTimerDaemonTimerBreakTimerBreakControllerPrivate * priv;
	BreakTimerDaemonUtilCountdown* interval_countdown;
	BreakTimerDaemonUtilCountdown* duration_countdown;
	BreakTimerDaemonUtilPausableTimeout* countdowns_timeout;
	gint fuzzy_seconds;
};

struct _BreakTimerDaemonTimerBreakTimerBreakControllerClass {
	BreakTimerDaemonBreakBreakControllerClass parent_class;
};

struct _BreakTimerDaemonMicroBreakMicroBreakController {
	BreakTimerDaemonTimerBreakTimerBreakController parent_instance;
	BreakTimerDaemonMicroBreakMicroBreakControllerPrivate * priv;
};

struct _BreakTimerDaemonMicroBreakMicroBreakControllerClass {
	BreakTimerDaemonTimerBreakTimerBreakControllerClass parent_class;
};

struct _BreakTimerDaemonTimerBreakTimerBreakType {
	BreakTimerDaemonBreakBreakType parent_instance;
	BreakTimerDaemonTimerBreakTimerBreakTypePrivate * priv;
};

struct _BreakTimerDaemonTimerBreakTimerBreakTypeClass {
	BreakTimerDaemonBreakBreakTypeClass parent_class;
};

struct _BreakTimerDaemonMicroBreakMicroBreakType {
	BreakTimerDaemonTimerBreakTimerBreakType parent_instance;
	BreakTimerDaemonMicroBreakMicroBreakTypePrivate * priv;
};

struct _BreakTimerDaemonMicroBreakMicroBreakTypeClass {
	BreakTimerDaemonTimerBreakTimerBreakTypeClass parent_class;
};

struct _BreakTimerDaemonTimerBreakTimerBreakView {
	BreakTimerDaemonBreakBreakView parent_instance;
	BreakTimerDaemonTimerBreakTimerBreakViewPrivate * priv;
};

struct _BreakTimerDaemonTimerBreakTimerBreakViewClass {
	BreakTimerDaemonBreakBreakViewClass parent_class;
};

struct _BreakTimerDaemonMicroBreakMicroBreakView {
	BreakTimerDaemonTimerBreakTimerBreakView parent_instance;
	BreakTimerDaemonMicroBreakMicroBreakViewPrivate * priv;
};

struct _BreakTimerDaemonMicroBreakMicroBreakViewClass {
	BreakTimerDaemonTimerBreakTimerBreakViewClass parent_class;
};

struct _BreakTimerDaemonRestBreakRestBreakController {
	BreakTimerDaemonTimerBreakTimerBreakController parent_instance;
	BreakTimerDaemonRestBreakRestBreakControllerPrivate * priv;
};

struct _BreakTimerDaemonRestBreakRestBreakControllerClass {
	BreakTimerDaemonTimerBreakTimerBreakControllerClass parent_class;
};

struct _BreakTimerDaemonRestBreakRestBreakType {
	BreakTimerDaemonTimerBreakTimerBreakType parent_instance;
	BreakTimerDaemonRestBreakRestBreakTypePrivate * priv;
};

struct _BreakTimerDaemonRestBreakRestBreakTypeClass {
	BreakTimerDaemonTimerBreakTimerBreakTypeClass parent_class;
};

struct _BreakTimerDaemonRestBreakRestBreakView {
	BreakTimerDaemonTimerBreakTimerBreakView parent_instance;
	BreakTimerDaemonRestBreakRestBreakViewPrivate * priv;
};

struct _BreakTimerDaemonRestBreakRestBreakViewClass {
	BreakTimerDaemonTimerBreakTimerBreakViewClass parent_class;
};

struct _BreakTimerDaemonSessionStatus {
	GObject parent_instance;
	BreakTimerDaemonSessionStatusPrivate * priv;
};

struct _BreakTimerDaemonSessionStatusClass {
	GObjectClass parent_class;
};

struct _BreakTimerDaemonUtilSimpleFocusManager {
	GObject parent_instance;
	BreakTimerDaemonUtilSimpleFocusManagerPrivate * priv;
};

struct _BreakTimerDaemonUtilSimpleFocusManagerClass {
	GObjectClass parent_class;
};

struct _BreakTimerDaemonUIManager {
	BreakTimerDaemonUtilSimpleFocusManager parent_instance;
	BreakTimerDaemonUIManagerPrivate * priv;
};

struct _BreakTimerDaemonUIManagerClass {
	BreakTimerDaemonUtilSimpleFocusManagerClass parent_class;
};

struct _BreakTimerDaemonUtilCountdown {
	GObject parent_instance;
	BreakTimerDaemonUtilCountdownPrivate * priv;
};

struct _BreakTimerDaemonUtilCountdownClass {
	GObjectClass parent_class;
};

struct _BreakTimerDaemonUtilPausableTimeout {
	GObject parent_instance;
	BreakTimerDaemonUtilPausableTimeoutPrivate * priv;
};

struct _BreakTimerDaemonUtilPausableTimeoutClass {
	GObjectClass parent_class;
};

struct _BreakTimerDaemonUtilStatefulTimer {
	GObject parent_instance;
	BreakTimerDaemonUtilStatefulTimerPrivate * priv;
};

struct _BreakTimerDaemonUtilStatefulTimerClass {
	GObjectClass parent_class;
};

VALA_EXTERN GType break_timer_daemon_activity_activity_monitor_backend_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonActivityActivityMonitorBackend, g_object_unref)
VALA_EXTERN gboolean break_timer_daemon_activity_activity_monitor_backend_init (BreakTimerDaemonActivityActivityMonitorBackend* self,
                                                                    GCancellable* cancellable,
                                                                    GError** error);
VALA_EXTERN JsonObject* break_timer_daemon_activity_activity_monitor_backend_serialize (BreakTimerDaemonActivityActivityMonitorBackend* self);
VALA_EXTERN void break_timer_daemon_activity_activity_monitor_backend_deserialize (BreakTimerDaemonActivityActivityMonitorBackend* self,
                                                                       JsonObject** json_root);
VALA_EXTERN guint64 break_timer_daemon_activity_activity_monitor_backend_time_since_last_event_ms (BreakTimerDaemonActivityActivityMonitorBackend* self);
VALA_EXTERN gint64 break_timer_daemon_activity_activity_monitor_backend_get_idle_seconds (BreakTimerDaemonActivityActivityMonitorBackend* self);
VALA_EXTERN gint64 break_timer_daemon_activity_activity_monitor_backend_pop_sleep_time (BreakTimerDaemonActivityActivityMonitorBackend* self);
VALA_EXTERN BreakTimerDaemonActivityActivityMonitorBackend* break_timer_daemon_activity_activity_monitor_backend_construct (GType object_type);
VALA_EXTERN GType break_timer_daemon_activity_activity_monitor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonActivityActivityMonitor, g_object_unref)
VALA_EXTERN BreakTimerDaemonActivityActivityMonitor* break_timer_daemon_activity_activity_monitor_new (BreakTimerCommonISessionStatus* session_status,
                                                                                           BreakTimerDaemonActivityActivityMonitorBackend* backend);
VALA_EXTERN BreakTimerDaemonActivityActivityMonitor* break_timer_daemon_activity_activity_monitor_construct (GType object_type,
                                                                                                 BreakTimerCommonISessionStatus* session_status,
                                                                                                 BreakTimerDaemonActivityActivityMonitorBackend* backend);
VALA_EXTERN JsonObject* break_timer_daemon_activity_activity_monitor_serialize (BreakTimerDaemonActivityActivityMonitor* self);
VALA_EXTERN void break_timer_daemon_activity_activity_monitor_deserialize (BreakTimerDaemonActivityActivityMonitor* self,
                                                               JsonObject** json_root);
VALA_EXTERN void break_timer_daemon_activity_activity_monitor_start (BreakTimerDaemonActivityActivityMonitor* self);
VALA_EXTERN void break_timer_daemon_activity_activity_monitor_stop (BreakTimerDaemonActivityActivityMonitor* self);
VALA_EXTERN void break_timer_daemon_activity_activity_monitor_poll_activity (BreakTimerDaemonActivityActivityMonitor* self);
VALA_EXTERN GType break_timer_daemon_activity_mutter_activity_monitor_backend_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonActivityMutterActivityMonitorBackend, g_object_unref)
VALA_EXTERN BreakTimerDaemonActivityMutterActivityMonitorBackend* break_timer_daemon_activity_mutter_activity_monitor_backend_new (void);
VALA_EXTERN BreakTimerDaemonActivityMutterActivityMonitorBackend* break_timer_daemon_activity_mutter_activity_monitor_backend_construct (GType object_type);
VALA_EXTERN GType break_timer_daemon_activity_user_activity_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType break_timer_daemon_activity_activity_type_get_type (void) G_GNUC_CONST ;
VALA_EXTERN BreakTimerDaemonActivityUserActivity* break_timer_daemon_activity_user_activity_dup (const BreakTimerDaemonActivityUserActivity* self);
VALA_EXTERN void break_timer_daemon_activity_user_activity_free (BreakTimerDaemonActivityUserActivity* self);
VALA_EXTERN JsonObject* break_timer_daemon_activity_user_activity_serialize (BreakTimerDaemonActivityUserActivity *self);
VALA_EXTERN void break_timer_daemon_activity_user_activity_deserialize (JsonObject** json_root,
                                                            BreakTimerDaemonActivityUserActivity* result);
VALA_EXTERN gboolean break_timer_daemon_activity_user_activity_is_active (BreakTimerDaemonActivityUserActivity *self);
VALA_EXTERN gchar* break_timer_daemon_activity_user_activity_to_string (BreakTimerDaemonActivityUserActivity *self);
VALA_EXTERN gchar* break_timer_daemon_activity_activity_type_to_string (BreakTimerDaemonActivityActivityType self);
VALA_EXTERN GType break_timer_daemon_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonApplication, g_object_unref)
VALA_EXTERN BreakTimerDaemonApplication* break_timer_daemon_application_new (void);
VALA_EXTERN BreakTimerDaemonApplication* break_timer_daemon_application_construct (GType object_type);
VALA_EXTERN void break_timer_daemon_application_on_query_end_cb (BreakTimerDaemonApplication* self);
VALA_EXTERN GType break_timer_daemon_break_break_controller_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonBreakBreakController, g_object_unref)
VALA_EXTERN GType break_timer_daemon_break_break_controller_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType break_timer_daemon_break_break_controller_finished_reason_get_type (void) G_GNUC_CONST ;
VALA_EXTERN BreakTimerDaemonBreakBreakController* break_timer_daemon_break_break_controller_construct (GType object_type);
VALA_EXTERN JsonObject* break_timer_daemon_break_break_controller_serialize (BreakTimerDaemonBreakBreakController* self);
VALA_EXTERN void break_timer_daemon_break_break_controller_deserialize (BreakTimerDaemonBreakBreakController* self,
                                                            JsonObject** json_root);
VALA_EXTERN void break_timer_daemon_break_break_controller_set_enabled (BreakTimerDaemonBreakBreakController* self,
                                                            gboolean enable);
VALA_EXTERN gboolean break_timer_daemon_break_break_controller_is_enabled (BreakTimerDaemonBreakBreakController* self);
VALA_EXTERN gboolean break_timer_daemon_break_break_controller_is_active (BreakTimerDaemonBreakBreakController* self);
VALA_EXTERN gint break_timer_daemon_break_break_controller_get_seconds_since_start (BreakTimerDaemonBreakBreakController* self);
VALA_EXTERN void break_timer_daemon_break_break_controller_activate (BreakTimerDaemonBreakBreakController* self);
VALA_EXTERN void break_timer_daemon_break_break_controller_finish (BreakTimerDaemonBreakBreakController* self);
VALA_EXTERN void break_timer_daemon_break_break_controller_skip (BreakTimerDaemonBreakBreakController* self,
                                                     gboolean forget_start);
VALA_EXTERN BreakTimerDaemonBreakBreakControllerState break_timer_daemon_break_break_controller_get_state (BreakTimerDaemonBreakBreakController* self);
VALA_EXTERN GType break_timer_daemon_break_break_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonBreakBreakType, g_object_unref)
VALA_EXTERN GType break_timer_daemon_ui_fragment_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonUIFragment, g_object_unref)
VALA_EXTERN GType break_timer_daemon_break_break_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonBreakBreakView, g_object_unref)
VALA_EXTERN BreakTimerDaemonBreakBreakType* break_timer_daemon_break_break_type_construct (GType object_type,
                                                                               const gchar* id,
                                                                               BreakTimerDaemonBreakBreakController* break_controller,
                                                                               BreakTimerDaemonBreakBreakView* break_view);
VALA_EXTERN gboolean break_timer_daemon_break_break_type_init (BreakTimerDaemonBreakBreakType* self,
                                                   GCancellable* cancellable,
                                                   GError** error);
VALA_EXTERN const gchar* break_timer_daemon_break_break_type_get_id (BreakTimerDaemonBreakBreakType* self);
VALA_EXTERN BreakTimerDaemonBreakBreakController* break_timer_daemon_break_break_type_get_break_controller (BreakTimerDaemonBreakBreakType* self);
VALA_EXTERN BreakTimerDaemonBreakBreakView* break_timer_daemon_break_break_type_get_break_view (BreakTimerDaemonBreakBreakType* self);
VALA_EXTERN GType break_timer_daemon_util_ifocusable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonUtilIFocusable, g_object_unref)
VALA_EXTERN GType break_timer_daemon_util_focus_priority_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType break_timer_daemon_util_simple_focus_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonUtilSimpleFocusManager, g_object_unref)
VALA_EXTERN GType break_timer_daemon_ui_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonUIManager, g_object_unref)
VALA_EXTERN BreakTimerDaemonBreakBreakView* break_timer_daemon_break_break_view_construct (GType object_type,
                                                                               BreakTimerDaemonBreakBreakController* break_controller,
                                                                               BreakTimerDaemonUIManager* ui_manager);
VALA_EXTERN gchar* break_timer_daemon_break_break_view_get_status_message (BreakTimerDaemonBreakBreakView* self);
VALA_EXTERN void break_timer_daemon_break_break_view_dismiss_break (BreakTimerDaemonBreakBreakView* self);
VALA_EXTERN GType break_timer_daemon_break_manager_dbus_object_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonBreakManagerDBusObject, g_object_unref)
VALA_EXTERN guint break_timer_daemon_break_manager_dbus_object_register_object (void* object,
                                                                    GDBusConnection* connection,
                                                                    const gchar* path,
                                                                    GError** error);
VALA_EXTERN GType break_timer_daemon_break_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonBreakManager, g_object_unref)
VALA_EXTERN BreakTimerDaemonBreakManagerDBusObject* break_timer_daemon_break_manager_dbus_object_new (BreakTimerDaemonBreakManager* break_manager);
VALA_EXTERN BreakTimerDaemonBreakManagerDBusObject* break_timer_daemon_break_manager_dbus_object_construct (GType object_type,
                                                                                                BreakTimerDaemonBreakManager* break_manager);
VALA_EXTERN gboolean break_timer_daemon_break_manager_dbus_object_is_active (BreakTimerDaemonBreakManagerDBusObject* self,
                                                                 GError** error);
VALA_EXTERN BreakTimerDaemonBreakManager* break_timer_daemon_break_manager_new (BreakTimerDaemonUIManager* ui_manager,
                                                                    BreakTimerDaemonActivityActivityMonitor* activity_monitor);
VALA_EXTERN BreakTimerDaemonBreakManager* break_timer_daemon_break_manager_construct (GType object_type,
                                                                          BreakTimerDaemonUIManager* ui_manager,
                                                                          BreakTimerDaemonActivityActivityMonitor* activity_monitor);
VALA_EXTERN JsonObject* break_timer_daemon_break_manager_serialize (BreakTimerDaemonBreakManager* self);
VALA_EXTERN void break_timer_daemon_break_manager_deserialize (BreakTimerDaemonBreakManager* self,
                                                   JsonObject** json_root);
VALA_EXTERN GList* break_timer_daemon_break_manager_all_break_ids (BreakTimerDaemonBreakManager* self);
VALA_EXTERN GList* break_timer_daemon_break_manager_all_breaks (BreakTimerDaemonBreakManager* self);
VALA_EXTERN BreakTimerDaemonBreakBreakType* break_timer_daemon_break_manager_get_break_type_for_name (BreakTimerDaemonBreakManager* self,
                                                                                          const gchar* name);
VALA_EXTERN gint break_timer_daemon_break_manager_get_autostart_version (BreakTimerDaemonBreakManager* self);
VALA_EXTERN void break_timer_daemon_break_manager_set_autostart_version (BreakTimerDaemonBreakManager* self,
                                                             gint value);
VALA_EXTERN gboolean break_timer_daemon_break_manager_get_master_enabled (BreakTimerDaemonBreakManager* self);
VALA_EXTERN void break_timer_daemon_break_manager_set_master_enabled (BreakTimerDaemonBreakManager* self,
                                                          gboolean value);
VALA_EXTERN gchar** break_timer_daemon_break_manager_get_selected_break_ids (BreakTimerDaemonBreakManager* self,
                                                                 gint* result_length1);
VALA_EXTERN void break_timer_daemon_break_manager_set_selected_break_ids (BreakTimerDaemonBreakManager* self,
                                                              gchar** value,
                                                              gint value_length1);
VALA_EXTERN GType break_timer_daemon_timer_break_timer_break_controller_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonTimerBreakTimerBreakController, g_object_unref)
VALA_EXTERN GType break_timer_daemon_util_countdown_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonUtilCountdown, g_object_unref)
VALA_EXTERN GType break_timer_daemon_util_pausable_timeout_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonUtilPausableTimeout, g_object_unref)
VALA_EXTERN GType break_timer_daemon_micro_break_micro_break_controller_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonMicroBreakMicroBreakController, g_object_unref)
VALA_EXTERN BreakTimerDaemonMicroBreakMicroBreakController* break_timer_daemon_micro_break_micro_break_controller_new (BreakTimerDaemonActivityActivityMonitor* activity_monitor);
VALA_EXTERN BreakTimerDaemonMicroBreakMicroBreakController* break_timer_daemon_micro_break_micro_break_controller_construct (GType object_type,
                                                                                                                 BreakTimerDaemonActivityActivityMonitor* activity_monitor);
VALA_EXTERN GType break_timer_daemon_timer_break_timer_break_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonTimerBreakTimerBreakType, g_object_unref)
VALA_EXTERN GType break_timer_daemon_micro_break_micro_break_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonMicroBreakMicroBreakType, g_object_unref)
VALA_EXTERN BreakTimerDaemonMicroBreakMicroBreakType* break_timer_daemon_micro_break_micro_break_type_new (BreakTimerDaemonActivityActivityMonitor* activity_monitor,
                                                                                               BreakTimerDaemonUIManager* ui_manager);
VALA_EXTERN BreakTimerDaemonMicroBreakMicroBreakType* break_timer_daemon_micro_break_micro_break_type_construct (GType object_type,
                                                                                                     BreakTimerDaemonActivityActivityMonitor* activity_monitor,
                                                                                                     BreakTimerDaemonUIManager* ui_manager);
VALA_EXTERN GType break_timer_daemon_timer_break_timer_break_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonTimerBreakTimerBreakView, g_object_unref)
VALA_EXTERN GType break_timer_daemon_micro_break_micro_break_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonMicroBreakMicroBreakView, g_object_unref)
VALA_EXTERN BreakTimerDaemonMicroBreakMicroBreakView* break_timer_daemon_micro_break_micro_break_view_new (BreakTimerDaemonMicroBreakMicroBreakController* micro_break,
                                                                                               BreakTimerDaemonUIManager* ui_manager);
VALA_EXTERN BreakTimerDaemonMicroBreakMicroBreakView* break_timer_daemon_micro_break_micro_break_view_construct (GType object_type,
                                                                                                     BreakTimerDaemonMicroBreakMicroBreakController* micro_break,
                                                                                                     BreakTimerDaemonUIManager* ui_manager);
VALA_EXTERN BreakTimerDaemonMicroBreakMicroBreakController* break_timer_daemon_micro_break_micro_break_view_get_micro_break (BreakTimerDaemonMicroBreakMicroBreakView* self);
VALA_EXTERN GType break_timer_daemon_rest_break_rest_break_controller_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonRestBreakRestBreakController, g_object_unref)
VALA_EXTERN BreakTimerDaemonRestBreakRestBreakController* break_timer_daemon_rest_break_rest_break_controller_new (BreakTimerDaemonActivityActivityMonitor* activity_monitor);
VALA_EXTERN BreakTimerDaemonRestBreakRestBreakController* break_timer_daemon_rest_break_rest_break_controller_construct (GType object_type,
                                                                                                             BreakTimerDaemonActivityActivityMonitor* activity_monitor);
VALA_EXTERN gboolean break_timer_daemon_rest_break_rest_break_controller_get_lock_screen_enabled (BreakTimerDaemonRestBreakRestBreakController* self);
VALA_EXTERN void break_timer_daemon_rest_break_rest_break_controller_set_lock_screen_enabled (BreakTimerDaemonRestBreakRestBreakController* self,
                                                                                  gboolean value);
VALA_EXTERN GType break_timer_daemon_rest_break_rest_break_type_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonRestBreakRestBreakType, g_object_unref)
VALA_EXTERN BreakTimerDaemonRestBreakRestBreakType* break_timer_daemon_rest_break_rest_break_type_new (BreakTimerDaemonActivityActivityMonitor* activity_monitor,
                                                                                           BreakTimerDaemonUIManager* ui_manager);
VALA_EXTERN BreakTimerDaemonRestBreakRestBreakType* break_timer_daemon_rest_break_rest_break_type_construct (GType object_type,
                                                                                                 BreakTimerDaemonActivityActivityMonitor* activity_monitor,
                                                                                                 BreakTimerDaemonUIManager* ui_manager);
VALA_EXTERN GType break_timer_daemon_rest_break_rest_break_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonRestBreakRestBreakView, g_object_unref)
VALA_EXTERN BreakTimerDaemonRestBreakRestBreakView* break_timer_daemon_rest_break_rest_break_view_new (BreakTimerDaemonRestBreakRestBreakController* rest_break,
                                                                                           BreakTimerDaemonUIManager* ui_manager);
VALA_EXTERN BreakTimerDaemonRestBreakRestBreakView* break_timer_daemon_rest_break_rest_break_view_construct (GType object_type,
                                                                                                 BreakTimerDaemonRestBreakRestBreakController* rest_break,
                                                                                                 BreakTimerDaemonUIManager* ui_manager);
VALA_EXTERN BreakTimerDaemonRestBreakRestBreakController* break_timer_daemon_rest_break_rest_break_view_get_rest_break (BreakTimerDaemonRestBreakRestBreakView* self);
VALA_EXTERN GType break_timer_daemon_session_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonSessionStatus, g_object_unref)
VALA_EXTERN BreakTimerDaemonSessionStatus* break_timer_daemon_session_status_new (void);
VALA_EXTERN BreakTimerDaemonSessionStatus* break_timer_daemon_session_status_construct (GType object_type);
VALA_EXTERN BreakTimerDaemonTimerBreakTimerBreakController* break_timer_daemon_timer_break_timer_break_controller_construct (GType object_type,
                                                                                                                 BreakTimerDaemonActivityActivityMonitor* activity_monitor,
                                                                                                                 gint fuzzy_seconds);
VALA_EXTERN gint break_timer_daemon_timer_break_timer_break_controller_starts_in (BreakTimerDaemonTimerBreakTimerBreakController* self);
VALA_EXTERN gint break_timer_daemon_timer_break_timer_break_controller_get_time_remaining (BreakTimerDaemonTimerBreakTimerBreakController* self);
VALA_EXTERN void break_timer_daemon_timer_break_timer_break_controller_postpone (BreakTimerDaemonTimerBreakTimerBreakController* self,
                                                                     gint resume_after);
VALA_EXTERN gint break_timer_daemon_timer_break_timer_break_controller_get_current_duration (BreakTimerDaemonTimerBreakTimerBreakController* self);
VALA_EXTERN gint break_timer_daemon_timer_break_timer_break_controller_get_interval (BreakTimerDaemonTimerBreakTimerBreakController* self);
VALA_EXTERN void break_timer_daemon_timer_break_timer_break_controller_set_interval (BreakTimerDaemonTimerBreakTimerBreakController* self,
                                                                         gint value);
VALA_EXTERN gint break_timer_daemon_timer_break_timer_break_controller_get_duration (BreakTimerDaemonTimerBreakTimerBreakController* self);
VALA_EXTERN void break_timer_daemon_timer_break_timer_break_controller_set_duration (BreakTimerDaemonTimerBreakTimerBreakController* self,
                                                                         gint value);
VALA_EXTERN BreakTimerDaemonTimerBreakTimerBreakType* break_timer_daemon_timer_break_timer_break_type_construct (GType object_type,
                                                                                                     const gchar* id,
                                                                                                     BreakTimerDaemonBreakBreakController* break_controller,
                                                                                                     BreakTimerDaemonBreakBreakView* break_view);
VALA_EXTERN BreakTimerDaemonTimerBreakTimerBreakView* break_timer_daemon_timer_break_timer_break_view_construct (GType object_type,
                                                                                                     BreakTimerDaemonTimerBreakTimerBreakController* timer_break,
                                                                                                     BreakTimerDaemonUIManager* ui_manager);
VALA_EXTERN gint break_timer_daemon_timer_break_timer_break_view_get_lead_in_seconds (BreakTimerDaemonTimerBreakTimerBreakView* self);
VALA_EXTERN BreakTimerDaemonTimerBreakTimerBreakController* break_timer_daemon_timer_break_timer_break_view_get_timer_break (BreakTimerDaemonTimerBreakTimerBreakView* self);
VALA_EXTERN gboolean break_timer_daemon_ui_fragment_has_ui_focus (BreakTimerDaemonUIFragment* self);
VALA_EXTERN gboolean break_timer_daemon_ui_fragment_has_higher_focus_priority (BreakTimerDaemonUIFragment* self,
                                                                   BreakTimerDaemonUIFragment* other);
VALA_EXTERN void break_timer_daemon_ui_fragment_reset_ui (BreakTimerDaemonUIFragment* self);
VALA_EXTERN void break_timer_daemon_ui_fragment_request_ui_focus (BreakTimerDaemonUIFragment* self);
VALA_EXTERN void break_timer_daemon_ui_fragment_release_ui_focus (BreakTimerDaemonUIFragment* self);
VALA_EXTERN void break_timer_daemon_ui_fragment_play_sound_from_id (BreakTimerDaemonUIFragment* self,
                                                        const gchar* event_id);
VALA_EXTERN void break_timer_daemon_ui_fragment_lock_screen (BreakTimerDaemonUIFragment* self);
VALA_EXTERN void break_timer_daemon_ui_fragment_show_notification (BreakTimerDaemonUIFragment* self,
                                                       const gchar* id,
                                                       GNotification* notification);
VALA_EXTERN void break_timer_daemon_ui_fragment_show_transient_notification (BreakTimerDaemonUIFragment* self,
                                                                 const gchar* id,
                                                                 GNotification* notification);
VALA_EXTERN void break_timer_daemon_ui_fragment_hide_notification (BreakTimerDaemonUIFragment* self,
                                                       const gchar* id);
VALA_EXTERN void break_timer_daemon_ui_fragment_focus_started (BreakTimerDaemonUIFragment* self);
VALA_EXTERN void break_timer_daemon_ui_fragment_focus_stopped (BreakTimerDaemonUIFragment* self);
VALA_EXTERN BreakTimerDaemonUIFragment* break_timer_daemon_ui_fragment_construct (GType object_type);
VALA_EXTERN BreakTimerDaemonUtilFocusPriority break_timer_daemon_ui_fragment_get_focus_priority (BreakTimerDaemonUIFragment* self);
VALA_EXTERN gchar** break_timer_daemon_ui_fragment_get_notification_ids (BreakTimerDaemonUIFragment* self,
                                                             gint* result_length1);
VALA_EXTERN BreakTimerDaemonUIManager* break_timer_daemon_ui_manager_new (GtkApplication* application,
                                                              BreakTimerCommonISessionStatus* session_status);
VALA_EXTERN BreakTimerDaemonUIManager* break_timer_daemon_ui_manager_construct (GType object_type,
                                                                    GtkApplication* application,
                                                                    BreakTimerCommonISessionStatus* session_status);
VALA_EXTERN void break_timer_daemon_ui_manager_show_notification (BreakTimerDaemonUIManager* self,
                                                      const gchar* id,
                                                      GNotification* notification);
VALA_EXTERN void break_timer_daemon_ui_manager_show_transient_notification (BreakTimerDaemonUIManager* self,
                                                                const gchar* id,
                                                                GNotification* notification);
VALA_EXTERN void break_timer_daemon_ui_manager_hide_notification (BreakTimerDaemonUIManager* self,
                                                      const gchar* id);
VALA_EXTERN void break_timer_daemon_ui_manager_play_sound_from_id (BreakTimerDaemonUIManager* self,
                                                       const gchar* event_id);
VALA_EXTERN void break_timer_daemon_ui_manager_lock_screen (BreakTimerDaemonUIManager* self);
VALA_EXTERN void break_timer_daemon_ui_manager_add_break (BreakTimerDaemonUIManager* self,
                                              BreakTimerDaemonBreakBreakView* break_view);
VALA_EXTERN void break_timer_daemon_ui_manager_remove_break (BreakTimerDaemonUIManager* self,
                                                 BreakTimerDaemonBreakBreakView* break_view);
VALA_EXTERN BreakTimerDaemonUtilCountdown* break_timer_daemon_util_countdown_new (gint base_duration);
VALA_EXTERN BreakTimerDaemonUtilCountdown* break_timer_daemon_util_countdown_construct (GType object_type,
                                                                            gint base_duration);
VALA_EXTERN gchar* break_timer_daemon_util_countdown_serialize (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN void break_timer_daemon_util_countdown_deserialize (BreakTimerDaemonUtilCountdown* self,
                                                    const gchar* data,
                                                    gboolean persistent);
VALA_EXTERN void break_timer_daemon_util_countdown_reset (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN void break_timer_daemon_util_countdown_start (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN void break_timer_daemon_util_countdown_start_from (BreakTimerDaemonUtilCountdown* self,
                                                   gint start_offset);
VALA_EXTERN void break_timer_daemon_util_countdown_pause (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN void break_timer_daemon_util_countdown_continue (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN void break_timer_daemon_util_countdown_continue_from (BreakTimerDaemonUtilCountdown* self,
                                                      gint start_offset);
VALA_EXTERN void break_timer_daemon_util_countdown_cancel_pause (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN void break_timer_daemon_util_countdown_advance_time (BreakTimerDaemonUtilCountdown* self,
                                                     gint seconds_off);
VALA_EXTERN void break_timer_daemon_util_countdown_set_penalty (BreakTimerDaemonUtilCountdown* self,
                                                    gint penalty);
VALA_EXTERN gint break_timer_daemon_util_countdown_get_penalty (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN gboolean break_timer_daemon_util_countdown_is_counting (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN void break_timer_daemon_util_countdown_set_base_duration (BreakTimerDaemonUtilCountdown* self,
                                                          gint base_duration);
VALA_EXTERN gint break_timer_daemon_util_countdown_get_duration (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN gint break_timer_daemon_util_countdown_get_time_elapsed (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN gint break_timer_daemon_util_countdown_get_time_remaining (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN gboolean break_timer_daemon_util_countdown_is_finished (BreakTimerDaemonUtilCountdown* self);
VALA_EXTERN BreakTimerDaemonUtilPausableTimeout* break_timer_daemon_util_pausable_timeout_new (BreakTimerDaemonUtilPausableTimeoutTimeoutCB callback,
                                                                                   gpointer callback_target,
                                                                                   gint frequency);
VALA_EXTERN BreakTimerDaemonUtilPausableTimeout* break_timer_daemon_util_pausable_timeout_construct (GType object_type,
                                                                                         BreakTimerDaemonUtilPausableTimeoutTimeoutCB callback,
                                                                                         gpointer callback_target,
                                                                                         gint frequency);
VALA_EXTERN gchar* break_timer_daemon_util_pausable_timeout_serialize (BreakTimerDaemonUtilPausableTimeout* self);
VALA_EXTERN void break_timer_daemon_util_pausable_timeout_deserialize (BreakTimerDaemonUtilPausableTimeout* self,
                                                           const gchar* data);
VALA_EXTERN void break_timer_daemon_util_pausable_timeout_run_once (BreakTimerDaemonUtilPausableTimeout* self);
VALA_EXTERN void break_timer_daemon_util_pausable_timeout_start (BreakTimerDaemonUtilPausableTimeout* self);
VALA_EXTERN void break_timer_daemon_util_pausable_timeout_set_frequency (BreakTimerDaemonUtilPausableTimeout* self,
                                                             gint frequency);
VALA_EXTERN void break_timer_daemon_util_pausable_timeout_stop (BreakTimerDaemonUtilPausableTimeout* self);
VALA_EXTERN gboolean break_timer_daemon_util_pausable_timeout_is_running (BreakTimerDaemonUtilPausableTimeout* self);
VALA_EXTERN void break_timer_daemon_util_ifocusable_focus_started (BreakTimerDaemonUtilIFocusable* self);
VALA_EXTERN void break_timer_daemon_util_ifocusable_focus_stopped (BreakTimerDaemonUtilIFocusable* self);
VALA_EXTERN BreakTimerDaemonUtilSimpleFocusManager* break_timer_daemon_util_simple_focus_manager_new (void);
VALA_EXTERN BreakTimerDaemonUtilSimpleFocusManager* break_timer_daemon_util_simple_focus_manager_construct (GType object_type);
VALA_EXTERN void break_timer_daemon_util_simple_focus_manager_request_focus (BreakTimerDaemonUtilSimpleFocusManager* self,
                                                                 BreakTimerDaemonUtilIFocusable* focusable,
                                                                 BreakTimerDaemonUtilFocusPriority priority);
VALA_EXTERN void break_timer_daemon_util_simple_focus_manager_release_focus (BreakTimerDaemonUtilSimpleFocusManager* self,
                                                                 BreakTimerDaemonUtilIFocusable* focusable);
VALA_EXTERN gboolean break_timer_daemon_util_simple_focus_manager_is_focusing (BreakTimerDaemonUtilSimpleFocusManager* self,
                                                                   BreakTimerDaemonUtilIFocusable* focusable);
VALA_EXTERN GType break_timer_daemon_util_stateful_timer_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BreakTimerDaemonUtilStatefulTimer, g_object_unref)
VALA_EXTERN GType break_timer_daemon_util_stateful_timer_state_get_type (void) G_GNUC_CONST ;
VALA_EXTERN BreakTimerDaemonUtilStatefulTimer* break_timer_daemon_util_stateful_timer_new (void);
VALA_EXTERN BreakTimerDaemonUtilStatefulTimer* break_timer_daemon_util_stateful_timer_construct (GType object_type);
VALA_EXTERN gchar* break_timer_daemon_util_stateful_timer_serialize (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN void break_timer_daemon_util_stateful_timer_deserialize (BreakTimerDaemonUtilStatefulTimer* self,
                                                         const gchar* data);
VALA_EXTERN gboolean break_timer_daemon_util_stateful_timer_is_stopped (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN gboolean break_timer_daemon_util_stateful_timer_is_counting (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN void break_timer_daemon_util_stateful_timer_start (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN void break_timer_daemon_util_stateful_timer_stop (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN void break_timer_daemon_util_stateful_timer_continue (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN gdouble break_timer_daemon_util_stateful_timer_elapsed (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN void break_timer_daemon_util_stateful_timer_reset (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN void break_timer_daemon_util_stateful_timer_start_lap (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN gdouble break_timer_daemon_util_stateful_timer_lap_time (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN void break_timer_daemon_util_stateful_timer_freeze (BreakTimerDaemonUtilStatefulTimer* self);
VALA_EXTERN BreakTimerDaemonUtilStatefulTimerState break_timer_daemon_util_stateful_timer_get_state (BreakTimerDaemonUtilStatefulTimer* self);

G_END_DECLS

#endif
