/* IPortalBackground.c generated by valac 0.56.19, the Vala compiler
 * generated from IPortalBackground.vala, do not modify */

/* IPortalBackground.vala
 *
 * Copyright 2020 Dylan McCall <dylan@dylanmccall.ca>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "common.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gio/gio.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

typedef GDBusProxy BreakTimerCommonIPortalBackgroundProxy;
typedef GDBusProxyClass BreakTimerCommonIPortalBackgroundProxyClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

static GType break_timer_common_iportal_background_get_type_once (void);
static void break_timer_common_iportal_background_proxy_g_signal (GDBusProxy* proxy,
                                                           const gchar* sender_name,
                                                           const gchar* signal_name,
                                                           GVariant* parameters);
static char* break_timer_common_iportal_background_proxy_request_background (BreakTimerCommonIPortalBackground* self,
                                                                      const gchar* parent_window,
                                                                      GHashTable* options,
                                                                      GError** error);
static void break_timer_common_iportal_background_proxy_set_status (BreakTimerCommonIPortalBackground* self,
                                                             GHashTable* options,
                                                             GError** error);
static void break_timer_common_iportal_background_proxy_break_timer_common_iportal_background_interface_init (BreakTimerCommonIPortalBackgroundIface* iface);
static void _dbus_break_timer_common_iportal_background_request_background (BreakTimerCommonIPortalBackground* self,
                                                                     GVariant* _parameters_,
                                                                     GDBusMethodInvocation* invocation);
static void _dbus_break_timer_common_iportal_background_set_status (BreakTimerCommonIPortalBackground* self,
                                                             GVariant* _parameters_,
                                                             GDBusMethodInvocation* invocation);
static void break_timer_common_iportal_background_dbus_interface_method_call (GDBusConnection* connection,
                                                                       const gchar* sender,
                                                                       const gchar* object_path,
                                                                       const gchar* interface_name,
                                                                       const gchar* method_name,
                                                                       GVariant* parameters,
                                                                       GDBusMethodInvocation* invocation,
                                                                       gpointer user_data);
static GVariant* break_timer_common_iportal_background_dbus_interface_get_property (GDBusConnection* connection,
                                                                             const gchar* sender,
                                                                             const gchar* object_path,
                                                                             const gchar* interface_name,
                                                                             const gchar* property_name,
                                                                             GError** error,
                                                                             gpointer user_data);
static gboolean break_timer_common_iportal_background_dbus_interface_set_property (GDBusConnection* connection,
                                                                            const gchar* sender,
                                                                            const gchar* object_path,
                                                                            const gchar* interface_name,
                                                                            const gchar* property_name,
                                                                            GVariant* value,
                                                                            GError** error,
                                                                            gpointer user_data);
static void _break_timer_common_iportal_background_unregister_object (gpointer user_data);

static const GDBusArgInfo _break_timer_common_iportal_background_dbus_arg_info_request_background_parent_window = {-1, "parent_window", "s", NULL};
static const GDBusArgInfo _break_timer_common_iportal_background_dbus_arg_info_request_background_options = {-1, "options", "a{sv}", NULL};
static const GDBusArgInfo _break_timer_common_iportal_background_dbus_arg_info_request_background_result = {-1, "result", "o", NULL};
static const GDBusArgInfo * const _break_timer_common_iportal_background_dbus_arg_info_request_background_in[] = {&_break_timer_common_iportal_background_dbus_arg_info_request_background_parent_window, &_break_timer_common_iportal_background_dbus_arg_info_request_background_options, NULL};
static const GDBusArgInfo * const _break_timer_common_iportal_background_dbus_arg_info_request_background_out[] = {&_break_timer_common_iportal_background_dbus_arg_info_request_background_result, NULL};
static const GDBusMethodInfo _break_timer_common_iportal_background_dbus_method_info_request_background = {-1, "RequestBackground", (GDBusArgInfo **) (&_break_timer_common_iportal_background_dbus_arg_info_request_background_in), (GDBusArgInfo **) (&_break_timer_common_iportal_background_dbus_arg_info_request_background_out), NULL};
static const GDBusArgInfo _break_timer_common_iportal_background_dbus_arg_info_set_status_options = {-1, "options", "a{sv}", NULL};
static const GDBusArgInfo * const _break_timer_common_iportal_background_dbus_arg_info_set_status_in[] = {&_break_timer_common_iportal_background_dbus_arg_info_set_status_options, NULL};
static const GDBusArgInfo * const _break_timer_common_iportal_background_dbus_arg_info_set_status_out[] = {NULL};
static const GDBusMethodInfo _break_timer_common_iportal_background_dbus_method_info_set_status = {-1, "SetStatus", (GDBusArgInfo **) (&_break_timer_common_iportal_background_dbus_arg_info_set_status_in), (GDBusArgInfo **) (&_break_timer_common_iportal_background_dbus_arg_info_set_status_out), NULL};
static const GDBusMethodInfo * const _break_timer_common_iportal_background_dbus_method_info[] = {&_break_timer_common_iportal_background_dbus_method_info_request_background, &_break_timer_common_iportal_background_dbus_method_info_set_status, NULL};
static const GDBusSignalInfo * const _break_timer_common_iportal_background_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo * const _break_timer_common_iportal_background_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _break_timer_common_iportal_background_dbus_interface_info = {-1, "org.freedesktop.portal.Background", (GDBusMethodInfo **) (&_break_timer_common_iportal_background_dbus_method_info), (GDBusSignalInfo **) (&_break_timer_common_iportal_background_dbus_signal_info), (GDBusPropertyInfo **) (&_break_timer_common_iportal_background_dbus_property_info), NULL};
static const GDBusInterfaceVTable _break_timer_common_iportal_background_dbus_interface_vtable = {break_timer_common_iportal_background_dbus_interface_method_call, break_timer_common_iportal_background_dbus_interface_get_property, break_timer_common_iportal_background_dbus_interface_set_property};

char*
break_timer_common_iportal_background_request_background (BreakTimerCommonIPortalBackground* self,
                                                          const gchar* parent_window,
                                                          GHashTable* options,
                                                          GError** error)
{
	BreakTimerCommonIPortalBackgroundIface* _iface_;
	g_return_val_if_fail (self != NULL, NULL);
	_iface_ = BREAK_TIMER_COMMON_IPORTAL_BACKGROUND_GET_INTERFACE (self);
	if (_iface_->request_background) {
		return _iface_->request_background (self, parent_window, options, error);
	}
	return NULL;
}

void
break_timer_common_iportal_background_set_status (BreakTimerCommonIPortalBackground* self,
                                                  GHashTable* options,
                                                  GError** error)
{
	BreakTimerCommonIPortalBackgroundIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BREAK_TIMER_COMMON_IPORTAL_BACKGROUND_GET_INTERFACE (self);
	if (_iface_->set_status) {
		_iface_->set_status (self, options, error);
	}
}

static void
break_timer_common_iportal_background_default_init (BreakTimerCommonIPortalBackgroundIface * iface,
                                                    gpointer iface_data)
{
}

static GType
break_timer_common_iportal_background_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BreakTimerCommonIPortalBackgroundIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) break_timer_common_iportal_background_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType break_timer_common_iportal_background_type_id;
	break_timer_common_iportal_background_type_id = g_type_register_static (G_TYPE_INTERFACE, "BreakTimerCommonIPortalBackground", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (break_timer_common_iportal_background_type_id, G_TYPE_OBJECT);
	g_type_set_qdata (break_timer_common_iportal_background_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) break_timer_common_iportal_background_proxy_get_type);
	g_type_set_qdata (break_timer_common_iportal_background_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.freedesktop.portal.Background");
	g_type_set_qdata (break_timer_common_iportal_background_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_break_timer_common_iportal_background_dbus_interface_info));
	g_type_set_qdata (break_timer_common_iportal_background_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) break_timer_common_iportal_background_register_object);
	return break_timer_common_iportal_background_type_id;
}

GType
break_timer_common_iportal_background_get_type (void)
{
	static volatile gsize break_timer_common_iportal_background_type_id__once = 0;
	if (g_once_init_enter (&break_timer_common_iportal_background_type_id__once)) {
		GType break_timer_common_iportal_background_type_id;
		break_timer_common_iportal_background_type_id = break_timer_common_iportal_background_get_type_once ();
		g_once_init_leave (&break_timer_common_iportal_background_type_id__once, break_timer_common_iportal_background_type_id);
	}
	return break_timer_common_iportal_background_type_id__once;
}

G_DEFINE_TYPE_EXTENDED (BreakTimerCommonIPortalBackgroundProxy, break_timer_common_iportal_background_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (BREAK_TIMER_COMMON_TYPE_IPORTAL_BACKGROUND, break_timer_common_iportal_background_proxy_break_timer_common_iportal_background_interface_init) )
static void
break_timer_common_iportal_background_proxy_class_init (BreakTimerCommonIPortalBackgroundProxyClass* klass)
{
	G_DBUS_PROXY_CLASS (klass)->g_signal = break_timer_common_iportal_background_proxy_g_signal;
}

static void
break_timer_common_iportal_background_proxy_g_signal (GDBusProxy* proxy,
                                                      const gchar* sender_name,
                                                      const gchar* signal_name,
                                                      GVariant* parameters)
{
}

static void
break_timer_common_iportal_background_proxy_init (BreakTimerCommonIPortalBackgroundProxy* self)
{
	g_dbus_proxy_set_interface_info (G_DBUS_PROXY (self), (GDBusInterfaceInfo *) (&_break_timer_common_iportal_background_dbus_interface_info));
}

static char*
break_timer_common_iportal_background_proxy_request_background (BreakTimerCommonIPortalBackground* self,
                                                                const gchar* parent_window,
                                                                GHashTable* options,
                                                                GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GVariantBuilder _tmp69_;
	GHashTableIter _tmp70_;
	gpointer _tmp71_;
	gpointer _tmp72_;
	GDBusMessage *_reply_message;
	GVariant *_reply;
	GVariantIter _reply_iter;
	char* _result = NULL;
	GVariant* _tmp73_;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.freedesktop.portal.Background", "RequestBackground");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (parent_window));
	g_hash_table_iter_init (&_tmp70_, options);
	g_variant_builder_init (&_tmp69_, G_VARIANT_TYPE ("a{sv}"));
	while (g_hash_table_iter_next (&_tmp70_, &_tmp71_, &_tmp72_)) {
		gchar* _key;
		GVariant* _value;
		_key = (gchar*) _tmp71_;
		_value = (GVariant*) _tmp72_;
		g_variant_builder_add (&_tmp69_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp69_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return NULL;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return NULL;
	}
	_reply = g_dbus_message_get_body (_reply_message);
	g_variant_iter_init (&_reply_iter, _reply);
	_tmp73_ = g_variant_iter_next_value (&_reply_iter);
	_result = g_variant_dup_string (_tmp73_, NULL);
	g_variant_unref (_tmp73_);
	g_object_unref (_reply_message);
	return _result;
}

static void
break_timer_common_iportal_background_proxy_set_status (BreakTimerCommonIPortalBackground* self,
                                                        GHashTable* options,
                                                        GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GVariantBuilder _tmp74_;
	GHashTableIter _tmp75_;
	gpointer _tmp76_;
	gpointer _tmp77_;
	GDBusMessage *_reply_message;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.freedesktop.portal.Background", "SetStatus");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_hash_table_iter_init (&_tmp75_, options);
	g_variant_builder_init (&_tmp74_, G_VARIANT_TYPE ("a{sv}"));
	while (g_hash_table_iter_next (&_tmp75_, &_tmp76_, &_tmp77_)) {
		gchar* _key;
		GVariant* _value;
		_key = (gchar*) _tmp76_;
		_value = (GVariant*) _tmp77_;
		g_variant_builder_add (&_tmp74_, "{?*}", g_variant_new_string (_key), g_variant_new_variant (_value));
	}
	g_variant_builder_add_value (&_arguments_builder, g_variant_builder_end (&_tmp74_));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
break_timer_common_iportal_background_proxy_break_timer_common_iportal_background_interface_init (BreakTimerCommonIPortalBackgroundIface* iface)
{
	iface->request_background = break_timer_common_iportal_background_proxy_request_background;
	iface->set_status = break_timer_common_iportal_background_proxy_set_status;
}

static void
_dbus_break_timer_common_iportal_background_request_background (BreakTimerCommonIPortalBackground* self,
                                                                GVariant* _parameters_,
                                                                GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	gchar* parent_window = NULL;
	GVariant* _tmp78_;
	GHashTable* options = NULL;
	GVariant* _tmp79_;
	GHashTable* _tmp80_;
	GVariantIter _tmp81_;
	GVariant* _tmp82_;
	GVariant* _tmp83_;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	char* result;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp78_ = g_variant_iter_next_value (&_arguments_iter);
	parent_window = g_variant_dup_string (_tmp78_, NULL);
	g_variant_unref (_tmp78_);
	_tmp79_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp80_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) g_variant_unref);
	g_variant_iter_init (&_tmp81_, _tmp79_);
	while (g_variant_iter_loop (&_tmp81_, "{?*}", &_tmp82_, &_tmp83_)) {
		g_hash_table_insert (_tmp80_, g_variant_dup_string (_tmp82_, NULL), g_variant_get_variant (_tmp83_));
	}
	options = _tmp80_;
	g_variant_unref (_tmp79_);
	result = break_timer_common_iportal_background_request_background (self, parent_window, options, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_reply_builder, g_variant_new_object_path (result));
	_g_free0 (result);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	_g_free0 (parent_window);
	_g_hash_table_unref0 (options);
	;
}

static void
_dbus_break_timer_common_iportal_background_set_status (BreakTimerCommonIPortalBackground* self,
                                                        GVariant* _parameters_,
                                                        GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GHashTable* options = NULL;
	GVariant* _tmp84_;
	GHashTable* _tmp85_;
	GVariantIter _tmp86_;
	GVariant* _tmp87_;
	GVariant* _tmp88_;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp84_ = g_variant_iter_next_value (&_arguments_iter);
	_tmp85_ = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) g_variant_unref);
	g_variant_iter_init (&_tmp86_, _tmp84_);
	while (g_variant_iter_loop (&_tmp86_, "{?*}", &_tmp87_, &_tmp88_)) {
		g_hash_table_insert (_tmp85_, g_variant_dup_string (_tmp87_, NULL), g_variant_get_variant (_tmp88_));
	}
	options = _tmp85_;
	g_variant_unref (_tmp84_);
	break_timer_common_iportal_background_set_status (self, options, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		goto _error;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
	_error:
	_g_hash_table_unref0 (options);
	;
}

static void
break_timer_common_iportal_background_dbus_interface_method_call (GDBusConnection* connection,
                                                                  const gchar* sender,
                                                                  const gchar* object_path,
                                                                  const gchar* interface_name,
                                                                  const gchar* method_name,
                                                                  GVariant* parameters,
                                                                  GDBusMethodInvocation* invocation,
                                                                  gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "RequestBackground") == 0) {
		_dbus_break_timer_common_iportal_background_request_background (object, parameters, invocation);
	} else if (strcmp (method_name, "SetStatus") == 0) {
		_dbus_break_timer_common_iportal_background_set_status (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}

static GVariant*
break_timer_common_iportal_background_dbus_interface_get_property (GDBusConnection* connection,
                                                                   const gchar* sender,
                                                                   const gchar* object_path,
                                                                   const gchar* interface_name,
                                                                   const gchar* property_name,
                                                                   GError** error,
                                                                   gpointer user_data)
{
	return NULL;
}

static gboolean
break_timer_common_iportal_background_dbus_interface_set_property (GDBusConnection* connection,
                                                                   const gchar* sender,
                                                                   const gchar* object_path,
                                                                   const gchar* interface_name,
                                                                   const gchar* property_name,
                                                                   GVariant* value,
                                                                   GError** error,
                                                                   gpointer user_data)
{
	return FALSE;
}

guint
break_timer_common_iportal_background_register_object (gpointer object,
                                                       GDBusConnection* connection,
                                                       const gchar* path,
                                                       GError** error)
{
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_break_timer_common_iportal_background_dbus_interface_info), &_break_timer_common_iportal_background_dbus_interface_vtable, data, _break_timer_common_iportal_background_unregister_object, error);
	if (!result) {
		return 0;
	}
	return result;
}

static void
_break_timer_common_iportal_background_unregister_object (gpointer user_data)
{
	gpointer* data;
	data = user_data;
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}

