/* IGnomeScreenSaver.c generated by valac 0.56.19, the Vala compiler
 * generated from IGnomeScreenSaver.vala, do not modify */

/* IGnomeScreenSaver.vala
 *
 * Copyright 2020 Dylan McCall <dylan@dylanmccall.ca>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include "common.h"
#include <glib.h>
#include <gio/gio.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	BREAK_TIMER_COMMON_IGNOME_SCREEN_SAVER_ACTIVE_CHANGED_SIGNAL,
	BREAK_TIMER_COMMON_IGNOME_SCREEN_SAVER_NUM_SIGNALS
};
static guint break_timer_common_ignome_screen_saver_signals[BREAK_TIMER_COMMON_IGNOME_SCREEN_SAVER_NUM_SIGNALS] = {0};
typedef GDBusProxy BreakTimerCommonIGnomeScreenSaverProxy;
typedef GDBusProxyClass BreakTimerCommonIGnomeScreenSaverProxyClass;

static GType break_timer_common_ignome_screen_saver_get_type_once (void);
static void break_timer_common_ignome_screen_saver_proxy_g_signal (GDBusProxy* proxy,
                                                            const gchar* sender_name,
                                                            const gchar* signal_name,
                                                            GVariant* parameters);
static void _dbus_handle_break_timer_common_ignome_screen_saver_active_changed (BreakTimerCommonIGnomeScreenSaver* self,
                                                                         GVariant* parameters);
static gboolean break_timer_common_ignome_screen_saver_proxy_get_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                                  GError** error);
static guint32 break_timer_common_ignome_screen_saver_proxy_get_active_time (BreakTimerCommonIGnomeScreenSaver* self,
                                                                      GError** error);
static void break_timer_common_ignome_screen_saver_proxy_lock (BreakTimerCommonIGnomeScreenSaver* self,
                                                        GError** error);
static void break_timer_common_ignome_screen_saver_proxy_set_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                              gboolean active,
                                                              GError** error);
static void break_timer_common_ignome_screen_saver_proxy_break_timer_common_ignome_screen_saver_interface_init (BreakTimerCommonIGnomeScreenSaverIface* iface);
static void _dbus_break_timer_common_ignome_screen_saver_get_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                              GVariant* _parameters_,
                                                              GDBusMethodInvocation* invocation);
static void _dbus_break_timer_common_ignome_screen_saver_get_active_time (BreakTimerCommonIGnomeScreenSaver* self,
                                                                   GVariant* _parameters_,
                                                                   GDBusMethodInvocation* invocation);
static void _dbus_break_timer_common_ignome_screen_saver_lock (BreakTimerCommonIGnomeScreenSaver* self,
                                                        GVariant* _parameters_,
                                                        GDBusMethodInvocation* invocation);
static void _dbus_break_timer_common_ignome_screen_saver_set_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                              GVariant* _parameters_,
                                                              GDBusMethodInvocation* invocation);
static void break_timer_common_ignome_screen_saver_dbus_interface_method_call (GDBusConnection* connection,
                                                                        const gchar* sender,
                                                                        const gchar* object_path,
                                                                        const gchar* interface_name,
                                                                        const gchar* method_name,
                                                                        GVariant* parameters,
                                                                        GDBusMethodInvocation* invocation,
                                                                        gpointer user_data);
static GVariant* break_timer_common_ignome_screen_saver_dbus_interface_get_property (GDBusConnection* connection,
                                                                              const gchar* sender,
                                                                              const gchar* object_path,
                                                                              const gchar* interface_name,
                                                                              const gchar* property_name,
                                                                              GError** error,
                                                                              gpointer user_data);
static gboolean break_timer_common_ignome_screen_saver_dbus_interface_set_property (GDBusConnection* connection,
                                                                             const gchar* sender,
                                                                             const gchar* object_path,
                                                                             const gchar* interface_name,
                                                                             const gchar* property_name,
                                                                             GVariant* value,
                                                                             GError** error,
                                                                             gpointer user_data);
static void _dbus_break_timer_common_ignome_screen_saver_active_changed (GObject* _sender,
                                                                  gboolean active,
                                                                  gpointer* _data);
static void _break_timer_common_ignome_screen_saver_unregister_object (gpointer user_data);

static const GDBusArgInfo _break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_result = {-1, "result", "b", NULL};
static const GDBusArgInfo * const _break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_in[] = {NULL};
static const GDBusArgInfo * const _break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_out[] = {&_break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_result, NULL};
static const GDBusMethodInfo _break_timer_common_ignome_screen_saver_dbus_method_info_get_active = {-1, "GetActive", (GDBusArgInfo **) (&_break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_in), (GDBusArgInfo **) (&_break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_out), NULL};
static const GDBusArgInfo _break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_time_result = {-1, "result", "u", NULL};
static const GDBusArgInfo * const _break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_time_in[] = {NULL};
static const GDBusArgInfo * const _break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_time_out[] = {&_break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_time_result, NULL};
static const GDBusMethodInfo _break_timer_common_ignome_screen_saver_dbus_method_info_get_active_time = {-1, "GetActiveTime", (GDBusArgInfo **) (&_break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_time_in), (GDBusArgInfo **) (&_break_timer_common_ignome_screen_saver_dbus_arg_info_get_active_time_out), NULL};
static const GDBusArgInfo * const _break_timer_common_ignome_screen_saver_dbus_arg_info_lock_in[] = {NULL};
static const GDBusArgInfo * const _break_timer_common_ignome_screen_saver_dbus_arg_info_lock_out[] = {NULL};
static const GDBusMethodInfo _break_timer_common_ignome_screen_saver_dbus_method_info_lock = {-1, "Lock", (GDBusArgInfo **) (&_break_timer_common_ignome_screen_saver_dbus_arg_info_lock_in), (GDBusArgInfo **) (&_break_timer_common_ignome_screen_saver_dbus_arg_info_lock_out), NULL};
static const GDBusArgInfo _break_timer_common_ignome_screen_saver_dbus_arg_info_set_active_active = {-1, "active", "b", NULL};
static const GDBusArgInfo * const _break_timer_common_ignome_screen_saver_dbus_arg_info_set_active_in[] = {&_break_timer_common_ignome_screen_saver_dbus_arg_info_set_active_active, NULL};
static const GDBusArgInfo * const _break_timer_common_ignome_screen_saver_dbus_arg_info_set_active_out[] = {NULL};
static const GDBusMethodInfo _break_timer_common_ignome_screen_saver_dbus_method_info_set_active = {-1, "SetActive", (GDBusArgInfo **) (&_break_timer_common_ignome_screen_saver_dbus_arg_info_set_active_in), (GDBusArgInfo **) (&_break_timer_common_ignome_screen_saver_dbus_arg_info_set_active_out), NULL};
static const GDBusMethodInfo * const _break_timer_common_ignome_screen_saver_dbus_method_info[] = {&_break_timer_common_ignome_screen_saver_dbus_method_info_get_active, &_break_timer_common_ignome_screen_saver_dbus_method_info_get_active_time, &_break_timer_common_ignome_screen_saver_dbus_method_info_lock, &_break_timer_common_ignome_screen_saver_dbus_method_info_set_active, NULL};
static const GDBusArgInfo _break_timer_common_ignome_screen_saver_dbus_arg_info_active_changed_active = {-1, "active", "b", NULL};
static const GDBusArgInfo * const _break_timer_common_ignome_screen_saver_dbus_arg_info_active_changed[] = {&_break_timer_common_ignome_screen_saver_dbus_arg_info_active_changed_active, NULL};
static const GDBusSignalInfo _break_timer_common_ignome_screen_saver_dbus_signal_info_active_changed = {-1, "ActiveChanged", (GDBusArgInfo **) (&_break_timer_common_ignome_screen_saver_dbus_arg_info_active_changed), NULL};
static const GDBusSignalInfo * const _break_timer_common_ignome_screen_saver_dbus_signal_info[] = {&_break_timer_common_ignome_screen_saver_dbus_signal_info_active_changed, NULL};
static const GDBusPropertyInfo * const _break_timer_common_ignome_screen_saver_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _break_timer_common_ignome_screen_saver_dbus_interface_info = {-1, "org.gnome.ScreenSaver", (GDBusMethodInfo **) (&_break_timer_common_ignome_screen_saver_dbus_method_info), (GDBusSignalInfo **) (&_break_timer_common_ignome_screen_saver_dbus_signal_info), (GDBusPropertyInfo **) (&_break_timer_common_ignome_screen_saver_dbus_property_info), NULL};
static const GDBusInterfaceVTable _break_timer_common_ignome_screen_saver_dbus_interface_vtable = {break_timer_common_ignome_screen_saver_dbus_interface_method_call, break_timer_common_ignome_screen_saver_dbus_interface_get_property, break_timer_common_ignome_screen_saver_dbus_interface_set_property};

gboolean
break_timer_common_ignome_screen_saver_get_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                   GError** error)
{
	BreakTimerCommonIGnomeScreenSaverIface* _iface_;
	g_return_val_if_fail (self != NULL, FALSE);
	_iface_ = BREAK_TIMER_COMMON_IGNOME_SCREEN_SAVER_GET_INTERFACE (self);
	if (_iface_->get_active) {
		return _iface_->get_active (self, error);
	}
	return FALSE;
}

guint32
break_timer_common_ignome_screen_saver_get_active_time (BreakTimerCommonIGnomeScreenSaver* self,
                                                        GError** error)
{
	BreakTimerCommonIGnomeScreenSaverIface* _iface_;
	g_return_val_if_fail (self != NULL, 0U);
	_iface_ = BREAK_TIMER_COMMON_IGNOME_SCREEN_SAVER_GET_INTERFACE (self);
	if (_iface_->get_active_time) {
		return _iface_->get_active_time (self, error);
	}
	return 0U;
}

void
break_timer_common_ignome_screen_saver_lock (BreakTimerCommonIGnomeScreenSaver* self,
                                             GError** error)
{
	BreakTimerCommonIGnomeScreenSaverIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BREAK_TIMER_COMMON_IGNOME_SCREEN_SAVER_GET_INTERFACE (self);
	if (_iface_->lock) {
		_iface_->lock (self, error);
	}
}

void
break_timer_common_ignome_screen_saver_set_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                   gboolean active,
                                                   GError** error)
{
	BreakTimerCommonIGnomeScreenSaverIface* _iface_;
	g_return_if_fail (self != NULL);
	_iface_ = BREAK_TIMER_COMMON_IGNOME_SCREEN_SAVER_GET_INTERFACE (self);
	if (_iface_->set_active) {
		_iface_->set_active (self, active, error);
	}
}

static void
break_timer_common_ignome_screen_saver_default_init (BreakTimerCommonIGnomeScreenSaverIface * iface,
                                                     gpointer iface_data)
{
	break_timer_common_ignome_screen_saver_signals[BREAK_TIMER_COMMON_IGNOME_SCREEN_SAVER_ACTIVE_CHANGED_SIGNAL] = g_signal_new ("active-changed", BREAK_TIMER_COMMON_TYPE_IGNOME_SCREEN_SAVER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__BOOLEAN, G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
}

static GType
break_timer_common_ignome_screen_saver_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (BreakTimerCommonIGnomeScreenSaverIface), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) break_timer_common_ignome_screen_saver_default_init, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
	GType break_timer_common_ignome_screen_saver_type_id;
	break_timer_common_ignome_screen_saver_type_id = g_type_register_static (G_TYPE_INTERFACE, "BreakTimerCommonIGnomeScreenSaver", &g_define_type_info, 0);
	g_type_interface_add_prerequisite (break_timer_common_ignome_screen_saver_type_id, G_TYPE_OBJECT);
	g_type_set_qdata (break_timer_common_ignome_screen_saver_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) break_timer_common_ignome_screen_saver_proxy_get_type);
	g_type_set_qdata (break_timer_common_ignome_screen_saver_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.gnome.ScreenSaver");
	g_type_set_qdata (break_timer_common_ignome_screen_saver_type_id, g_quark_from_static_string ("vala-dbus-interface-info"), (void*) (&_break_timer_common_ignome_screen_saver_dbus_interface_info));
	g_type_set_qdata (break_timer_common_ignome_screen_saver_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) break_timer_common_ignome_screen_saver_register_object);
	return break_timer_common_ignome_screen_saver_type_id;
}

GType
break_timer_common_ignome_screen_saver_get_type (void)
{
	static volatile gsize break_timer_common_ignome_screen_saver_type_id__once = 0;
	if (g_once_init_enter (&break_timer_common_ignome_screen_saver_type_id__once)) {
		GType break_timer_common_ignome_screen_saver_type_id;
		break_timer_common_ignome_screen_saver_type_id = break_timer_common_ignome_screen_saver_get_type_once ();
		g_once_init_leave (&break_timer_common_ignome_screen_saver_type_id__once, break_timer_common_ignome_screen_saver_type_id);
	}
	return break_timer_common_ignome_screen_saver_type_id__once;
}

G_DEFINE_TYPE_EXTENDED (BreakTimerCommonIGnomeScreenSaverProxy, break_timer_common_ignome_screen_saver_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (BREAK_TIMER_COMMON_TYPE_IGNOME_SCREEN_SAVER, break_timer_common_ignome_screen_saver_proxy_break_timer_common_ignome_screen_saver_interface_init) )
static void
break_timer_common_ignome_screen_saver_proxy_class_init (BreakTimerCommonIGnomeScreenSaverProxyClass* klass)
{
	G_DBUS_PROXY_CLASS (klass)->g_signal = break_timer_common_ignome_screen_saver_proxy_g_signal;
}

static void
_dbus_handle_break_timer_common_ignome_screen_saver_active_changed (BreakTimerCommonIGnomeScreenSaver* self,
                                                                    GVariant* parameters)
{
	GVariantIter _arguments_iter;
	gboolean active = FALSE;
	GVariant* _tmp49_;
	g_variant_iter_init (&_arguments_iter, parameters);
	_tmp49_ = g_variant_iter_next_value (&_arguments_iter);
	active = g_variant_get_boolean (_tmp49_);
	g_variant_unref (_tmp49_);
	g_signal_emit_by_name (self, "active-changed", active);
}

static void
break_timer_common_ignome_screen_saver_proxy_g_signal (GDBusProxy* proxy,
                                                       const gchar* sender_name,
                                                       const gchar* signal_name,
                                                       GVariant* parameters)
{
	if (strcmp (signal_name, "ActiveChanged") == 0) {
		_dbus_handle_break_timer_common_ignome_screen_saver_active_changed ((BreakTimerCommonIGnomeScreenSaver*) proxy, parameters);
	}
}

static void
break_timer_common_ignome_screen_saver_proxy_init (BreakTimerCommonIGnomeScreenSaverProxy* self)
{
	g_dbus_proxy_set_interface_info (G_DBUS_PROXY (self), (GDBusInterfaceInfo *) (&_break_timer_common_ignome_screen_saver_dbus_interface_info));
}

static gboolean
break_timer_common_ignome_screen_saver_proxy_get_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                         GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	GVariant *_reply;
	GVariantIter _reply_iter;
	gboolean _result = FALSE;
	GVariant* _tmp52_;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.ScreenSaver", "GetActive");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		gboolean _tmp50_ = FALSE;
		return _tmp50_;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		gboolean _tmp51_ = FALSE;
		g_object_unref (_reply_message);
		return _tmp51_;
	}
	_reply = g_dbus_message_get_body (_reply_message);
	g_variant_iter_init (&_reply_iter, _reply);
	_tmp52_ = g_variant_iter_next_value (&_reply_iter);
	_result = g_variant_get_boolean (_tmp52_);
	g_variant_unref (_tmp52_);
	g_object_unref (_reply_message);
	return _result;
}

static guint32
break_timer_common_ignome_screen_saver_proxy_get_active_time (BreakTimerCommonIGnomeScreenSaver* self,
                                                              GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	GVariant *_reply;
	GVariantIter _reply_iter;
	guint32 _result = 0U;
	GVariant* _tmp55_;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.ScreenSaver", "GetActiveTime");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		guint32 _tmp53_ = 0U;
		return _tmp53_;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		guint32 _tmp54_ = 0U;
		g_object_unref (_reply_message);
		return _tmp54_;
	}
	_reply = g_dbus_message_get_body (_reply_message);
	g_variant_iter_init (&_reply_iter, _reply);
	_tmp55_ = g_variant_iter_next_value (&_reply_iter);
	_result = g_variant_get_uint32 (_tmp55_);
	g_variant_unref (_tmp55_);
	g_object_unref (_reply_message);
	return _result;
}

static void
break_timer_common_ignome_screen_saver_proxy_lock (BreakTimerCommonIGnomeScreenSaver* self,
                                                   GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.ScreenSaver", "Lock");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
break_timer_common_ignome_screen_saver_proxy_set_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                         gboolean active,
                                                         GError** error)
{
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	GDBusMessage *_reply_message;
	G_DBUS_ERROR;
	G_IO_ERROR;
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.gnome.ScreenSaver", "SetActive");
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (active));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_message_set_body (_message, _arguments);
	_reply_message = g_dbus_connection_send_message_with_reply_sync (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, error);
	g_object_unref (_message);
	if (!_reply_message) {
		return;
	}
	if (g_dbus_message_to_gerror (_reply_message, error)) {
		g_object_unref (_reply_message);
		return;
	}
	g_object_unref (_reply_message);
}

static void
break_timer_common_ignome_screen_saver_proxy_break_timer_common_ignome_screen_saver_interface_init (BreakTimerCommonIGnomeScreenSaverIface* iface)
{
	iface->get_active = break_timer_common_ignome_screen_saver_proxy_get_active;
	iface->get_active_time = break_timer_common_ignome_screen_saver_proxy_get_active_time;
	iface->lock = break_timer_common_ignome_screen_saver_proxy_lock;
	iface->set_active = break_timer_common_ignome_screen_saver_proxy_set_active;
}

static void
_dbus_break_timer_common_ignome_screen_saver_get_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                         GVariant* _parameters_,
                                                         GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	gboolean result;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	result = break_timer_common_ignome_screen_saver_get_active (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_reply_builder, g_variant_new_boolean (result));
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_break_timer_common_ignome_screen_saver_get_active_time (BreakTimerCommonIGnomeScreenSaver* self,
                                                              GVariant* _parameters_,
                                                              GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	guint32 result;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	result = break_timer_common_ignome_screen_saver_get_active_time (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_reply_builder, g_variant_new_uint32 (result));
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_break_timer_common_ignome_screen_saver_lock (BreakTimerCommonIGnomeScreenSaver* self,
                                                   GVariant* _parameters_,
                                                   GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	break_timer_common_ignome_screen_saver_lock (self, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
_dbus_break_timer_common_ignome_screen_saver_set_active (BreakTimerCommonIGnomeScreenSaver* self,
                                                         GVariant* _parameters_,
                                                         GDBusMethodInvocation* invocation)
{
	GError* error = NULL;
	GVariantIter _arguments_iter;
	gboolean active = FALSE;
	GVariant* _tmp56_;
	GDBusMessage* _reply_message = NULL;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	g_variant_iter_init (&_arguments_iter, _parameters_);
	_tmp56_ = g_variant_iter_next_value (&_arguments_iter);
	active = g_variant_get_boolean (_tmp56_);
	g_variant_unref (_tmp56_);
	break_timer_common_ignome_screen_saver_set_active (self, active, &error);
	if (error) {
		g_dbus_method_invocation_take_error (invocation, error);
		return;
	}
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
	_reply = g_variant_builder_end (&_reply_builder);
	g_dbus_message_set_body (_reply_message, _reply);
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
	g_object_unref (invocation);
	g_object_unref (_reply_message);
}

static void
break_timer_common_ignome_screen_saver_dbus_interface_method_call (GDBusConnection* connection,
                                                                   const gchar* sender,
                                                                   const gchar* object_path,
                                                                   const gchar* interface_name,
                                                                   const gchar* method_name,
                                                                   GVariant* parameters,
                                                                   GDBusMethodInvocation* invocation,
                                                                   gpointer user_data)
{
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
	if (strcmp (method_name, "GetActive") == 0) {
		_dbus_break_timer_common_ignome_screen_saver_get_active (object, parameters, invocation);
	} else if (strcmp (method_name, "GetActiveTime") == 0) {
		_dbus_break_timer_common_ignome_screen_saver_get_active_time (object, parameters, invocation);
	} else if (strcmp (method_name, "Lock") == 0) {
		_dbus_break_timer_common_ignome_screen_saver_lock (object, parameters, invocation);
	} else if (strcmp (method_name, "SetActive") == 0) {
		_dbus_break_timer_common_ignome_screen_saver_set_active (object, parameters, invocation);
	} else {
		g_object_unref (invocation);
	}
}

static GVariant*
break_timer_common_ignome_screen_saver_dbus_interface_get_property (GDBusConnection* connection,
                                                                    const gchar* sender,
                                                                    const gchar* object_path,
                                                                    const gchar* interface_name,
                                                                    const gchar* property_name,
                                                                    GError** error,
                                                                    gpointer user_data)
{
	return NULL;
}

static gboolean
break_timer_common_ignome_screen_saver_dbus_interface_set_property (GDBusConnection* connection,
                                                                    const gchar* sender,
                                                                    const gchar* object_path,
                                                                    const gchar* interface_name,
                                                                    const gchar* property_name,
                                                                    GVariant* value,
                                                                    GError** error,
                                                                    gpointer user_data)
{
	return FALSE;
}

static void
_dbus_break_timer_common_ignome_screen_saver_active_changed (GObject* _sender,
                                                             gboolean active,
                                                             gpointer* _data)
{
	GDBusConnection * _connection;
	const gchar * _path;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
	_connection = _data[1];
	_path = _data[2];
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_boolean (active));
	_arguments = g_variant_builder_end (&_arguments_builder);
	g_dbus_connection_emit_signal (_connection, NULL, _path, "org.gnome.ScreenSaver", "ActiveChanged", _arguments, NULL);
}

guint
break_timer_common_ignome_screen_saver_register_object (gpointer object,
                                                        GDBusConnection* connection,
                                                        const gchar* path,
                                                        GError** error)
{
	guint result;
	gpointer *data;
	data = g_new (gpointer, 3);
	data[0] = g_object_ref (object);
	data[1] = g_object_ref (connection);
	data[2] = g_strdup (path);
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_break_timer_common_ignome_screen_saver_dbus_interface_info), &_break_timer_common_ignome_screen_saver_dbus_interface_vtable, data, _break_timer_common_ignome_screen_saver_unregister_object, error);
	if (!result) {
		return 0;
	}
	g_signal_connect (object, "active-changed", (GCallback) _dbus_break_timer_common_ignome_screen_saver_active_changed, data);
	return result;
}

static void
_break_timer_common_ignome_screen_saver_unregister_object (gpointer user_data)
{
	gpointer* data;
	data = user_data;
	g_signal_handlers_disconnect_by_func (data[0], _dbus_break_timer_common_ignome_screen_saver_active_changed, data);
	g_object_unref (data[0]);
	g_object_unref (data[1]);
	g_free (data[2]);
	g_free (data);
}

